<?php
namespace Teknisa\SM\Service;

use Teknisa\Libs\Util\NewCode;
use Teknisa\SM\Factory\Sm00005000ParametrizacoesServicesFactory;
use Teknisa\Libs\Util\Environment;

class Sm00005000ParametrizacoesServicesService {
    
    protected $RelacElementoFactory;
    protected $Environment;
    protected $newCode;
    protected $parametrogeral;
    
    public function __construct (Sm00005000ParametrizacoesServicesFactory $factoryParamSm, Environment $Environment,NewCode $newCode){
        $this->factoryParamSm  = $factoryParamSm;
        $this->Environment  = $Environment;
        $this->newCode          = $newCode;
    }
    
    /**
    * A função "buscaNovoCodigo" busca os códigos para validação
    */
     
    public function buscaNovoCodigo($cdContador){
    
        $params = array(
            "CDCONTADOR" => $cdContador,
            "NRORG"      => $this->Environment->getNrOrg()
        );
        
        return $this->factoryParamSm->buscaNovoCodigo($params);
    }
    
    
    /**
     * A função "atualizaNovoCodigo" atualiza o novo codigo do contrato ou da proposta
     */
     
    public function atualizaNovoCodigo($cdContador, $nrSequencial){
    
        $params = array(
            "NRSEQUENCIAL" => $nrSequencial,
            "NRORG"        => $this->Environment->getNrOrg(),
            "OPERADOR"     => $this->Environment->getCdOperador(),
            "CDCONTADOR"   => $cdContador
        );
        
        $this->factoryParamSm->atualizaNovoCodigo($params);
    }
    
     /**
     * A função "insereNovoCodigo" insere o novo codigo do contrato ou da proposta
     */
     
    public function insereNovoCodigo($cdContador, $nrSequencial){
    
        $params = array(
            "CDCONTADOR"   => $cdContador,
            "NRSEQUENCIAL" => $nrSequencial,
            "NRORG"        => $this->Environment->getNrOrg(),
            "OPERADOR"     => $this->Environment->getCdOperador()
        );
        
        $this->factoryParamSm->insereNovoCodigo($params);
    }
    
    /**
     * Busca o id que define se o sistema possui ou não hierarquia de operadores 
    **/
    public function getIdUtilizaHierarquiaOper($nrorg){
        $params = array(
            "NRORG" => $nrorg
        );
        
        $result = $this->factoryParamSm->getIdUtilizaHierarquiaOper($params);
        return (count($result) > 0) ? $result[0]["IDUTILIZAHIEROPER"] : null; 
    }

    public function buscarperfilacesso($nrorg, $perfilDerivado){
        $params = array(
            "NRORG" => $nrorg
        );
        $result = array();
        if($perfilDerivado == "C") {
            $result = $this->factoryParamSm->buscarperfilacessoContrato($params);
        }else if($perfilDerivado == "P"){
            $result = $this->factoryParamSm->buscarperfilacessoProposta($params);
        }
        return $result;
    }

    public function saveperfilacesso($perfilacesso,$nrorg,$nrorginclusao,$cdoperinclusao,$cdoperultatu,$nrorgultatu,$dtinclusao,$dtultatu,$idativo, $proposta, $contrato ){
        $nraltcontraprovperf = $this->newCode->getCodeByTableName("NRALTCONTRAPROVPERF", $nrorg, 1, 10, true);

        $params = array(
            "NRALTCONTRAPROVPERF"  =>  $nraltcontraprovperf,
            "NRPERFILACESSO"  => $perfilacesso,
            "NRORG"          => $nrorg,
            "NRORGINCLUSAO"  => $nrorginclusao,
            "CDOPERINCLUSAO"  => $cdoperinclusao,
            "CDOPERULTATU"  => $cdoperultatu,
            "NRORGULTATU" => $nrorgultatu,
            "DTINCLUSAO"  => $dtinclusao,
            "DTULTATU"  => $dtultatu,
            "IDATIVO"  =>  $idativo
        );
        if($proposta) {
            $result = $this->factoryParamSm->saveperfilacessoProposta($params);
        }
        if($contrato){
            $result = $this->factoryParamSm->saveperfilacessoContrato($params);
        }

        return $result;


    }
    public function validarperfilacesso($params){
        $params = array(
            "NRPARCNEGOCIO"  => $params
        );
        return $this->factoryParamSm->validarperfilacesso($params);
    }

    public function deleteperfilacesso($perfilacesso, $proposta, $contrato){
        $params = array(
            "NRPERFILACESSO"  => $perfilacesso
        );
        if($proposta) {
            $result = $this->factoryParamSm->deleteperfilacessoProposta($params);
        }
        if($contrato){
            $result = $this->factoryParamSm->deleteperfilacessoContrato($params);
        }

        return $result;


    }
    
     /**
     * A função "completaPercentual" verifica qual o percentual faltante para inserção na página "índices Financeiros Padrões"
     */
    
    public function completaPercentual(){
        $nrorg = $this->Environment->getNrOrg();
        $params = array(
            "NRORG"    => $nrorg,
            "CDINDICE" => null
        );
        
        $valida = $this->factoryParamSm->validaPercentual($params);
        if (!empty($valida[0])){
           $result = 100 - $valida[0]["TOTPERCENT"];
        } else {
           $result =  100; 
        }
        
        return $result;
    }
    
    
     /**
     * A função "validaPercentual" valida o percentual para inserção na página "índices Financeiros Padrões"
     */
    
    public function validaPercentual($nrpercentindice, $cdindice){
        $nrorg = $this->Environment->getNrOrg();
        $params = array (
            "NRORG"    => $nrorg,
            "CDINDICE" => $cdindice
        );
        
        $valida = $this->factoryParamSm->validaPercentual($params);
        if (!empty($valida[0])){
           $result = $valida[0]["TOTPERCENT"] + $nrpercentindice;
        } else {
           $result =  $nrpercentindice; 
        }
        
        return $result;
    }
    
    /**
     * A função "cadAutoSignatPadr" realiza o cadastramento automático dos signatários padrões da parametrização SM
     */
    public function cadAutoSignatPadr($row){
        try {
            
            $nrorg = $this->Environment->getNrOrg();
            $operador = $this->Environment->getCdOperador();
            
            $params = array(
                "NRORG" => $nrorg
            );
            
            $certsign = $this->factoryParamSm->validaTokenCertsign($params);
            
            if(count($certsign) > 0) {
                
                $idtipoassinatura = $row["IDTIPOASSINATURA"]; 
                $idtestemunha = $row["IDTESTEMUNHA"];
                $nrordenacao = $row["NRORDENACAO"];
                $idinsercaoauto = $row["IDINSERCAOAUTO"];
                $signatarios = $row["NRPARCNEGOCIO"];
                
                if (isset($row["DSEMAILNOTSIGNENV"])){
                    
                    $dsemailnotsigenv = implode('_', $row["DSEMAILNOTSIGNENV"]);
                }
                else{
                    
                    $dsemailnotsigenv = null;
                }
                
                if (isset($row["CDOPERADORES"])){
                    
                    $operadores = $row["CDOPERADORES"];
                }
                else {
                    
                    $operadores = null;   
                }
                
                if (isset($row["DSEMAILNOTIFOUTROS"])){
                    
                    $dsemailnotifoutros = $row["DSEMAILNOTIFOUTROS"];
                }
                else {
                    
                    $dsemailnotifoutros = null;
                }
                
                
                if(count($signatarios) > 0) {
                
                    foreach($signatarios as $signatario){
                      
                        $params = array(
                            "NRPARCNEGOCIO"  => $signatario,
                            "IDTPSIGNATARIO" => "SE",
                            "NRORG"          => $nrorg
                        );
                      
                        $valida = $this->factoryParamSm->validaSignatCadastrados($params);
                      
                        if ($valida == 0) {
                      
                            $nrsignatariospadr = $this->newCode->getCodeByTableName("FCT_SIGNATARIOSPADR", $nrorg, 1, 10, true);
                            $params= array(
                                "NRSIGNATARIOSPADR"  => $nrsignatariospadr,
                                "NRPARCNEGOCIO"      => $signatario, 
                                "IDTIPOASSINATURA"   => $idtipoassinatura, 
                                "IDTESTEMUNHA"       => $idtestemunha, 
                                "NRORDENACAO"        => $nrordenacao, 
                                "IDINSERCAOAUTO"     => $idinsercaoauto,
                                "DSEMAILNOTSIGNENV"  => $dsemailnotsigenv,
                                "DSEMAILNOTIFOUTROS" => $dsemailnotifoutros,
                                "NRORG"              => $nrorg,  
                                "OPERADOR"           => $operador
                            );
                          
                            $signatarios = $this->factoryParamSm->insereSignatariosPadroesCadAuto($params);
                          
                            if ($operadores != null){
                                
                                foreach($operadores as $cdoperador){
                                 
                                    $nrrelopernotifassele = $this->newCode->getCodeByTableName("FCT_RELACOPERNOTIFASSELE", $nrorg, 1, 10, true);
               
                                    $params = array(
                                       "NRRELOPERNOTIFASSELE" => $nrrelopernotifassele,
                                       "NRSIGNATARIOSPADR"    => $nrsignatariospadr,
                                       "CDOPERADOR"           => $cdoperador, 
                                       "NRORG"                => $nrorg,  
                                       "OPERADOR"             => $operador
                                    );
                                    
                                    $this->factoryParamSm->insereOperadoresNotifica($params);
                                }
                            }
                        }
                    }  
                }
            }
            
            $retorno = 'OK';
            
        } catch(\Exception $e) {
            $retorno = $e->getMessage();
            //throw $e;
        }
        
         return $retorno;
    }
    
    /**
     * A função "validaSignatPadr" realiza a validação dos signatários padrões para evitar a inclusão repetida de um parceiro.
     */
    public function validaSignatPadr($row){
        try {
            
           $nrorg = $this->Environment->getNrOrg();
           
           $nrparcnegocio  = $row["NRPARCNEGOCIO"];
           $idtpsignatatio = $row["IDTPSIGNATARIO"];
           
           $params = array(
              "NRPARCNEGOCIO"  => $nrparcnegocio,
              "IDTPSIGNATARIO" => $idtpsignatatio,
              "NRORG"          => $nrorg
           );
          
           $valida = $this->factoryParamSm->validaSignatCadastrados($params);
        
           return $valida;    
        
        } catch(\Exception $e) {
            throw $e;
        }   
        
    }
    
    /**
     * A função "insereOperadoresNotifica" realiza a inserção dos operadores do sistema que devem ser notificados.
     */
    public function insereOperadoresNotifica($nrsignatariospadr, $operadores){
        try {
            
           $nrorg = $this->Environment->getNrOrg();
           $operador = $this->Environment->getCdOperador();
           
           /* -- Deleta os registros antigos -- */
           $params = array(
              "NRSIGNATARIOSPADR" => $nrsignatariospadr,
              "NRORG"             => $nrorg
           );
          
           $this->factoryParamSm->deletaOperadoresNotifica($params);
           
           
           /* -- Insere os novos registros -- */
           $operadoresAux = explode('_', $operadores);
            
           foreach ($operadoresAux as $cdoperdor) {
                
                $nrrelopernotifassele = $this->newCode->getCodeByTableName("FCT_RELACOPERNOTIFASSELE", $nrorg, 1, 10, true);
               
                $params = array(
                   "NRRELOPERNOTIFASSELE" => $nrrelopernotifassele,
                   "NRSIGNATARIOSPADR"    => $nrsignatariospadr,
                   "CDOPERADOR"           => $cdoperdor,
                   "NRORG"                => $nrorg,
                   "OPERADOR"             => $operador
                );
              
                $this->factoryParamSm->insereOperadoresNotifica($params);
           }
        
        } catch(\Exception $e) {
            throw $e;
        }   
        
    }
    
    public function pegarIdControleCarencia(){
        $nrorg = $this->Environment->getNrOrg();
        $params = array(
            "NRORG" => $nrorg
        );
        $resposta = $this->factoryParamSm->pegarIdControleCarencia($params);
        $resposta = $resposta[0]["IDBLOQCARENCMAXI"];
        return (isset($resposta)) ? $resposta : "N";
    }
    
    public function atualizarIdControleCarencia(){
        $id = $this->pegarIdControleCarencia();
        $nrorg = $this->Environment->getNrOrg();
        $id = ($id == "N") ? "S" : "N";
        $params = array(
            "ID"    => $id,
            "NRORG" => $nrorg
        );
        $resposta = $this->factoryParamSm->atualizarIdControleCarencia($params);
        return $id;
    }

    public function pegarValidacaoCPF(){
        try {
           $nrorg = $this->Environment->getNrOrg();
           $params = array(
              "NRORG" => $nrorg
           );
           $retorno = $this->factoryParamSm->pegarValidacaoCPF($params);
           return (count($retorno) >0) ? $retorno[0] : 'N';
        } catch(\Exception $e) {
            throw $e;
        }   
        
    }

}

?>