<?php

namespace Teknisa\SM\Service;

use Doctrine\ORM\EntityManager;
use Teknisa\SM\Util\Procedure\FctCopiaVersionaContrato;
use Teknisa\SM\Util\Procedure\FctEncerraContrato;
use Teknisa\SM\Util\Procedure\FctVencPrevCont;
use Teknisa\SM\Util\Procedure\CriaMnemonico;
use Teknisa\SM\Util\Procedure\FctSubMneDoc;
use Teknisa\SM\Util\Procedure\FctGerarParcelasFatura;
use Teknisa\SM\Util\Procedure\FctExcluirParcelasFatura;
use Teknisa\SM\Factory\Sm00004000ContratoFactory as ContratoFactory;
//use Teknisa\SM\Factory\Sm00001000LancamentoPropostaFactory as PropostaFactory;
use Teknisa\SM\Util\Utilities;
use Teknisa\Libs\Util\Environment;
//use Zeedhi\Framework\Remote\FileUploader\Server;
use Teknisa\Libs\Util\NewCode;
use Teknisa\SM\Service\IntegracaoOmService;
use Teknisa\Libs\Util\DateUtil;
//use Teknisa\SM\Service\Sm00001000LancamentoPropostaService as PropostaService;
use Zeedhi\Framework\Session\Session;
use Teknisa\SM\Service\SmDocumentosService;
//use Teknisa\SM\Service\SmAssinaturaDigitalService;
//use Teknisa\SM\Service\Sm00004000DocumentoContratoService;
use Teknisa\SM\Util\Procedure\FctSuspenderParcelasFatura;
//use Teknisa\SM\Factory\Sm00004109NegociacaoContratoFactory as NegociacaoContratoFactory;
//use Teknisa\SM\Factory\ParceiroNegocioFactory;
//use Teknisa\SM\Service\IntegracaoFmService;
//use Teknisa\SM\Service\IntegracaoTecfoodService;
use Zeedhi\Framework\DTO\Row;


class Sm00004000ContratoService {
    
    protected $connection;
    protected $zhFileUploader;
    protected $environment;
    protected $fileServerBaseUrl;
    protected $validaReajusteFatu;
    protected $contratoFactory;
    protected $propostaFactory;
    protected $newCode;
    protected $integracaoOmService;
    protected $propostaService;
    protected $session;
    protected $smDocumentosService;
    protected $assinaturaDigital;
    protected $docContratoService;
    protected $negociacaoContratoFactory;
    protected $parceiroNegocioFactory;
    protected $codigoEscopoFaturamentoContratoGerado;
    protected $codigoModeloContratoFaturamentoContratoGerado;
    protected $integracaoFmService;
    protected $integracaoTecfoodService;
    
    /*
    O tipo das variáveis abaixo foram comentadas porque, na job do jenkins de renovação automática com reajuste,
    eu preciso instanciar essa classe passando 'null' em alguns parâmetros, e se tiver o tipo da classe na 
    variável vai dar erro no sistema.
    Ex: parametro 4 esperava um objeto da classe Zeedhi\Framework\Remote\FileUploader\Server, mas foi passado 'null'.
    Eu deixei comentado ao invés de apagar só para ficar mais fácil de saber de que tipo é o parâmetro.
    */
    public function __construct(EntityManager $entityManager, ContratoFactory $contratoFactory, Environment $environment, /*Server*/ $zhFileUploader, $fileServerBaseUrl, $validaReajusteFatu, /*PropostaFactory*/ $propostaFactory, NewCode $newCode, IntegracaoOmService $integracaoOmService, /*PropostaService*/ $propostaService, Session $session, SmDocumentosService $smDocumentosService = null, /*SmAssinaturaDigitalService*/ $assinaturaDigital = null, /*DocumentoContratoService*/ $docContratoService = null, /*NegociacaoContratoFactory*/ $negociacaoContratoFactory = null, $parceiroNegocioFactory = null, $codigoEscopo = null, $codigoModelo = null, $integracaoFmService = null, $integracaoTecfoodService = null) {
        $this->connection                = $entityManager->getConnection();
        $this->contratoFactory           = $contratoFactory;
        $this->environment               = $environment;
        $this->zhFileUploader            = $zhFileUploader; // Zeedhi\Framework\Remote\FileUploader\Server
        $this->fileServerBaseUrl         = $fileServerBaseUrl;
        $this->validaReajusteFatu        = $validaReajusteFatu;
        $this->propostaFactory           = $propostaFactory; // Teknisa\SM\Factory\Sm00001000LancamentoPropostaFactory
        $this->newCode                   = $newCode;
        $this->integracaoOmService       = $integracaoOmService;
        $this->propostaService           = $propostaService; // Teknisa\SM\Service\Sm00001000LancamentoPropostaService
        $this->session                   = $session;
        $this->smDocumentosService       = $smDocumentosService;  // Teknisa\SM\Service\SmDocumentosService
        $this->assinaturaDigital         = $assinaturaDigital;    // Teknisa\SM\Service\SmAssinaturaDigitalService
        $this->docContratoService        = $docContratoService;
        $this->negociacaoContratoFactory = $negociacaoContratoFactory; // Teknisa\SM\Factory\Sm00004109NegociacaoContratoFactory
        $this->parceiroNegocioFactory    = $parceiroNegocioFactory; // Teknisa\SM\Factory\ParceiroNegocioFactory
        
        $this->tempDir = sys_get_temp_dir();
        
        $this->codigoEscopoFaturamentoContratoGerado = $codigoEscopo;
        $this->codigoModeloContratoFaturamentoContratoGerado = $codigoModelo;

        $this->integracaoFmService = $integracaoFmService; // Teknisa\SM\Service\IntegracaoFmService
        $this->integracaoTecfoodService = $integracaoTecfoodService; // Teknisa\SM\Service\IntegracaoTecfoodService
    }
    
    /**
     * A função "executarProcedureFctCopiaVersionaContrato" executa a procedure
     * "FCT_COPIA_VERSIONA_CONTRATO".
     */
    public function executarProcedureFctCopiaVersionaContrato($nrseqcontrato, $idCopiaVersiona, $operador, $nrorg, $adcAgrupamento, $idParcelaConsiderada, $idReplicarNegociacao, $dtRenegociaCont,$dtFimContrato) {
        $procedure = new FctCopiaVersionaContrato($this->connection);
        return $procedure->executar($nrseqcontrato, $idCopiaVersiona, $operador, $nrorg, $adcAgrupamento, $idParcelaConsiderada, $idReplicarNegociacao, $dtRenegociaCont,$dtFimContrato);
    }
    
    /**
     * A função "executarProcedureFctEncerraContrato" executa a procedure
     * "FCT_ENCERRA_CONTRATO".
     */
    public function executarProcedureFctEncerraContrato($nrseqcontrato, $operador, $nrorg, $dtrecisao, $idtpexclusaoparcela) {

        $procedure = new FctEncerraContrato($this->connection);
        $procedure->executar($nrseqcontrato, $operador, $nrorg, $dtrecisao, $idtpexclusaoparcela);
    }
    
    /**
     * A função "executarProcedureFctVencPrevCont" executa a procedure
     * "FCT_VENCPREV_CONT".
     */
    public function executarProcedureFctVencPrevCont($nrseqcontrato, $nrorg) {
        $procedure = new FctVencPrevCont($this->connection);
        $procedure->executar($nrseqcontrato, $nrorg);
    }
    
    /**
     * A função "executarProcedureFctExcluirParcelasFatura" executa a procedure
     * "FCT_EXCLUIR_PARCELAS_FATURA".
     */
    public function executarProcedureFctExcluirParcelasFatura($nrseqcontrato, $nrorg) {
        $procedure = new FctExcluirParcelasFatura($this->connection);
        $procedure->executar($nrseqcontrato, $nrorg);
    }
    
    
    
    /**
     * A função "executarProcedureFctGerarParcelasFatura" executa a procedure
     * "FCT_GERAR_PARCELAS_FATURA".
     */
    public function executarProcedureFctGerarParcelasFatura($nrseqcontrato, $nrorg, $operador) {
        $procedure = new FctGerarParcelasFatura($this->connection);
        $procedure->executar($nrseqcontrato, $nrorg, $operador);
    }
    
    /**
     * Busca o código dos contratos que foram gerados pelas propostas informadas.
     * 
     * @param mixed[] $nrseqcontrato
     * @param number $nrorg
     */
    public function getCodigoContratosDasPropostas(array $nrseqcontrato, $nrorg) {
        $nrseqcontrato = implode(",", $nrseqcontrato);
        $dataset = $this->contratoFactory->getContratosDasPropostas($nrseqcontrato, $nrorg);
        if (count($dataset) > 0) {
            $contratos = array();
            foreach ($dataset as $linha) {
                $contratos[] = $linha["NRSEQCONTRATO"];
            }
            return $contratos;
        }
        else {
            return null;
        }
    }
    
    /**
     * Verifica se algum dos contratos informados está aprovado.
     * 
     * @param mixed[] $nrseqcontrato
     * @param number $nrorg
     */
    public function existeContratoDiferentesPR(array $nrseqcontrato, $nrorg) {
        $nrseqcontrato = implode(",", $nrseqcontrato);
        $dataset = $this->contratoFactory->existeContratoDiferentesPR($nrseqcontrato, $nrorg);
        return count($dataset) > 0 ? true : false;
    }
    
    /**
     * Exclui os contratos informados.
     * 
     * @param mixed[] $nrseqcontrato
     * @param number $nrorg
     */
    public function reprovarContratos(array $nrseqcontrato, $nrorg) {
        try{
            $nrseqcontrato = implode(",", $nrseqcontrato);
            $this->contratoFactory->deletaDocumentosContrato($nrseqcontrato, array("NRORG" => $nrorg));
            $this->contratoFactory->reprovarContratos($nrseqcontrato, $nrorg);
        } catch(\Exception $e){
            throw $e;
        }
    }
    
     /**
      * A função "recebeParamFatModCont" recebe os dados de Faturamento do Modelo de Contrato
      */
    public function recebeParamFatModCont($seqModContrato, $nrorg){
        $paramsParamFatModCont = array(
            "NRSEQMODCONTRA" => $seqModContrato,
            "NRORG"  => $nrorg
        );
        
        $returnParamFatModCont = $this->contratoFactory->recebeParamFatModCont($paramsParamFatModCont);
        return $returnParamFatModCont;    
    }
    
    /**
     * A função "recebeModReajustContr" recebe os dados de Reajuste do Modelo de Contrato
     */
    public function recebeModReajustContr($seqModContrato, $nrorg){
    
        $paramsModReajustContr = array(
            "NRSEQMODCONTRA" => $seqModContrato,
            "NRORG"  => $nrorg
        );
        
      $returnModReajustContr = $this->contratoFactory->recebeModReajustContr($paramsModReajustContr);
    
      return $returnModReajustContr;    
        
    }
    
     /**
     * A função "recebeModIndContr" recebe os dados de Indice de Reajuste do Modelo de Contrato
     */
    public function recebeModIndContr($seqModContrato, $seqModReajus, $nrorg){
    
        $paramsModIndContr = array(
            "NRSEQMODCONTRA" => $seqModContrato,
            "NRSEQMODREAJUS" => $seqModReajus,
            "NRORG"  => $nrorg
        );
        
      $returnModIndContr = $this->contratoFactory->recebeModIndContr($paramsModIndContr);
    
      return $returnModIndContr;    
        
    }
    
     /**
     * A função "recebeModeloDocContr" recebe os dados de Documento do Modelo de Contrato
     */
    public function recebeModeloDocContr($seqModContrato, $nrorg){
    
        $paramsModeloDocContr = array(
            "NRSEQMODCONTRA" => $seqModContrato,
            "NRORG"  => $nrorg
        );
        
      $returnModeloDocContr = $this->contratoFactory->recebeModeloDocContr($paramsModeloDocContr);
    
      return $returnModeloDocContr;    
        
    }
    
    /**
     * A função "executarProcedureCriaMnemonico" executa a procedure
     * "CRIA_MNEMONICO".
     */
    public function executarProcedureCriaMnemonico($seqContrato, $nrorg) {
        $procedure = new CriaMnemonico($this->connection);
        return $procedure->executar($nrorg, 'C', $seqContrato);
    }
    
    /**
     * A função "executarProcedureFctSubMneDoc" executa a procedure
     * "FCT_SUB_MNE_DOC".
     */
    public function executarProcedureFctSubMneDoc($seqContrato, $nrSeqDocCont, $nrorg) {
        $procedure = new FctSubMneDoc($this->connection);
        $procedure->executar($seqContrato, $nrSeqDocCont, $nrorg, 'C', 'S');
    }
    
    public function anexarDocumentosContrato($caminhoArquivos) {
        $links = array();
        $customFolder = "anexo_documento_contrato";
        
        $nrorg = $this->environment->getNrOrg();
        
        foreach ($caminhoArquivos as $chave => $caminho) {
            $file = Utilities::uploadArquivoFileServer($this->zhFileUploader, $customFolder, $caminho);
            $links[] = $file["path"];
            
            $caminhoDocumentoGeradoPDF = $this->getCaminhoDocumentoGeradoPDFContrato($chave, $nrorg);
            if (!empty($caminhoDocumentoGeradoPDF)) {
                $this->zhFileUploader->deleteFile($caminhoDocumentoGeradoPDF);
            }
            
            //atualizar o link PDF no documento
            $params = array(
                "DSCAMINHODOCGERADOPDF" => $file["path"],
                "NRSEQCONTDOC"          => $chave,
                "NRORG"                 => $nrorg
            );
            
            $this->contratoFactory->atualizarCaminhoDocumentoGeradoPDFContrato($params);
        }
        
        return $links;
    }
    
    /**
     * Anexa um documento a um contrato copiado
     * @params{String} $nrseqContrato
     * @params{String} $nrorg
     */
    public function anexarDocumentosContratosCopiados($nrseqContrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqContrato,
            "NRORG" => $nrorg
        );
        
        $dataset = $this->contratoFactory->getDocumentosContratosGerados($params);
        foreach ($dataset as $row) {
            $nomeArquivo   = $row["NMARQUIVO"];
            $tipo          = $row["DSTIPO"];
            $tamanhoBytes  = $row["VRTAMANHO"] * 1024;
            $urlFileServer = $row["DSCAMINHOARQ"];
            
            if (!empty($urlFileServer)) {
                //$conteudo = @file_get_contents($this->fileServerBaseUrl . $urlFileServer);
                $conteudo = $this->smDocumentosService->getDocumentoFileServer($this->fileServerBaseUrl . $urlFileServer, $nrorg);
                if ($conteudo !== false) {
                    $file = Utilities::uploadFileServer($this->zhFileUploader, "anexo_documento_contrato", $nomeArquivo, $conteudo, $tamanhoBytes, $tipo);
                    $caminhoNovo = $file["path"];
    
                    $params = array(
                        "DSCAMINHOARQ"  => $caminhoNovo,
                        "NRSEQCONTDOC"  => $row["NRSEQCONTDOC"],
                        "NRSEQCONTRATO" => $row["NRSEQCONTRATO"],
                        "NRORG"         => $nrorg
                    );
                    
                    $this->contratoFactory->atualizarCaminhoDocumentoContrato($params);
                }
            }
        }
    }
    
    public function getCaminhoDocumentoGeradoPDFContrato($nrseqcontdoc, $nrorg) {
        $params = array(
            "NRSEQCONTDOC" => $nrseqcontdoc,
            "NRORG"        => $nrorg
        );
        
        $dataset = $this->contratoFactory->getCaminhoDocumentoGeradoPDFContrato($params);
        if (count($dataset) > 0) {
            return $dataset[0]["DSCAMINHODOCGERADOPDF"];
        }
        else {
            return null;
        }
    }
    
    /**
     * Deleta da tabela de agendamentos pendentes os itens
     * quando o contrato é encerrado
    **/
    public function DeletaAgendPendenteContratoEncerrado($nrseqcontrato, $nrorg){
        $params = array(
            "NRSEQCONTRATO"   => $nrseqcontrato,
            "NRORG"           => $nrorg
        );
        
        $this->contratoFactory->DeletaAgendPendenteContratoEncerrado($params);
    }
    
    /**
     * Salva o novo operador responsável dos contratos selecionados
     */
    /*public function salvaAlteracaoOperContrato($nrseqcontrato, $operador, $nrorg){
        $nrseqcontrato = implode(",", $nrseqcontrato);
        $params = array(
            "CDOPERRESPONSAVEL" => $operador,
            "NRORG"             => $nrorg
        );
        
        
        $this->contratoFactory->salvaAlteracaoOperContrato($params, $nrseqcontrato);
    }*/

    /**
     * Retorna o parametro validação para a geração de 
     * documentos em pdf
    **/
    public function getParametroExtensaoDoc($nrseqcontrato, $nrorg){
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );

        $result = $this->contratoFactory->getParametroExtensaoDoc($params);
        
        return isset($result) ? $result : null;
    }
    
   /**
    * Retorna os dados de faturamento do modelo de contrato
   */
    public function getParamVencimentos($nrseqmodcontra, $nrorg){
        $params = array(
            "NRSEQMODCONTRA" => $nrseqmodcontra,
            "NRORG"         => $nrorg
        );

        $result = $this->contratoFactory->getParamVencimentos($params);
        return isset($result) ? $result : null;
    }
    
     /**
      * Retorna os produto de faturamento do serviço
     */
    public function getProdServico($cdServOrca, $nrorg){
        $params = array(
            "CDSERVORCA" => $cdServOrca,
            "NRORG"      => $nrorg
        );

        $result = $this->contratoFactory->getProdServico($params);
        return isset($result) ? $result : null;
    }
    
    /*
     * Pega dados da tabela FCT_FATURACONT 
     * O numero da fatura é o único parâmetro necessário para acessar a tabela, por ser PK.
    */
    public function getDadosUmaParcela($nrFaturaCont){
        $params = array (
            "NRFATURACONT" => $nrFaturaCont
        );
        $result =  $this->contratoFactory->getDadosUmaParcela($params);
        return $result;
    }
    
    /**
     * Atualiza o valor da parcela de Faturamento ao alterar os itens
     */
    public function AtulizaValorFaturamento($nrFaturaCont, $nrSeqContrato, $nrorg, $operador){
        
        $params = array(
            "NRFATURACONT"  => $nrFaturaCont,
            "NRSEQCONTRATO" => $nrSeqContrato,
            "NRORG"         => $nrorg
        );

        $somaValorItens = $this->contratoFactory->getSomaValorItens($params);
        
        $somaValorItens = $somaValorItens[0]["SOMAVRVENC"];
        
        try{
            $params = array(
                "NRFATURACONT"  => $nrFaturaCont,
                "VRSOMAITENS"   => $somaValorItens,
                "NRORG"         => $nrorg,
                "CDOPERADOR"    => $operador
            );
            $somaValorItens = $this->contratoFactory->AtulizaValorFaturamento($params);
        } catch(\Exception $e){
            throw $e;
        }

    }
    
    /**
     * Retorna o documento de acordo com a situação indicada
    **/
    public function getDocumentosSituacao($nrseqcontrato, $nrorg, $idsituacao){
        $params = array(
            "NRORG"              => $nrorg,
            "NRSEQCONTRATO"      => $nrseqcontrato,
            "IDSITUACAOCONTRATO" => $idsituacao
        );
        return $this->contratoFactory->getDocumentosSituacao($params);
    }
    
    /**
     * Atualiza na tabela de documento do contrato o documento
     * de acordo com a situação
    **/
    public function atualizaDocumentoSituacao($nrseqcontrato, $nrorg, $idsituacao){
        $dadosDocumento = $this->getDocumentosSituacao($nrseqcontrato, $nrorg, $idsituacao);
        foreach($dadosDocumento as $dadoDoc){
            $params = array(
                "NMARQUIVO"          => $dadoDoc["NMARQUIVO"],
                "DSCAMINHOARQ"       => $dadoDoc["DSCAMINHOARQ"],
                "DSTIPO"             => $dadoDoc["DSTIPO"],
                "VRTAMANHO"          => $dadoDoc["VRTAMANHO"],
                "NRSEQMODDOCFCT"     => $dadoDoc["NRSEQMODDOCFCT"],
                "NRORG"              => $nrorg,
                "NRSEQCONTRATO"      => $nrseqcontrato,
                "IDSITUACAOCONTRATO" => $idsituacao
            );
            $this->contratoFactory->atualizaDocumentoSituacao($params);
        }
    }
    
    public function retornaIntervaloDatas($dtInicio, $dtFinal){

        $result = $this->contratoFactory->retornaIntervaloDatas($dtInicio, $dtFinal);
        return isset($result) ? $result : null;
    }
    
    /**
     * Atualiza os operadores responsaveis através da ação de 
     * alterar operadores das telas de contrato e prospect
    **/
    public function atualizaOperadorResponsavel($sql, $newcdoperador, $nrorg){
        try{
            $params = array(
                "NEWCDOPERADOR"     => $newcdoperador,
                "NRORG"             => $nrorg
            );
            $this->contratoFactory->atualizaOperadorResponsavel($params, $sql);
        } catch(\Exception $e){
            throw $e;
        }
    }
    
    /**
     * A função "buscaFilialHierarquia" busca a filial vinculado ao operador
     * na hierarquiia de operadores (CRM_HIERARQUIAOPER)
     */
     
    public function buscaFilialHierarquia($operador, $nrorg){
        
        try{ 
            $params = array(
                "CDOPERADOR"  => $operador,
                "NRORG"       => $nrorg
            );
                
            $result = $this->contratoFactory->buscaFilialHierarquia($params);
            return isset($result) ? $result : null;
        } catch(\Exception $e){
            throw $e;
        }
    }
    
     /* Retorna os dados de faturamento da parametrização  de contrato
     */
    public function getParamFatCont($nrseqcontrato, $nrorg){
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );

        $result = $this->contratoFactory->getParamFatCont($params);
        return isset($result) ? $result : null;
    }
    
   /* Valida se o orçamento foi realizado através de Composição de Serviços.
     */
    public function validaCompServico($nrseqcontrato, $nrorg){
        $params = array(
            "NRSEQORCAMENTO" => $nrseqcontrato,
            "NRORG"          => $nrorg
        );
        return $this->contratoFactory->validaCompServico($params);
    }
    /**
     * Manda buscar as informações do modelo da proposta e monta a row que será inserida
     * (Utilizada apenas na inserção de contratos com composição de serviço e medidas)
    **/
    public function getInfoModeloPropostaInserindo($rowContrato, $nrorg){
        $nrtipoorcamento = implode(",", $rowContrato["NRTIPOORCAMENTO"]);
        $params = array(
            "NRORCAMENTOMODELO" => $rowContrato["NRORCAMENTOMODELO"],
            "NRORG"             => $nrorg
        );
        $infoModelo  = $this->contratoFactory->getInfoModeloPropostaInserindo($params, $nrtipoorcamento);
        $rowProposta = array(
            "NRSEQORCAMENTO"       => null,
            "NRORCAMENTO"          => null,
            "NRPARCNEGOCIO"        => $rowContrato["NRPARCNEGOCIO"],
            "NRVERSAOORCAMENTO"    => 1,
            "IDSITUACAOORCAMENTO"  => 'CONCLUIDO',
            "IDPROPALIMENTICIA"    => "N",
            "IDGERACONTRATO"       => "NOVO",
            "CDOPERRESPONSAVEL"    => $rowContrato["CDOPERRESPONSAVEL"],
            "DTREFORCAMENTO"       => $rowContrato["DTINICIOCONTRATO"],
            "QTDIASVALIDADE"       => $infoModelo[0]["QTDIASVALIDADE"],
            "QTDIASCONTRATO"       => $infoModelo[0]["QTDIASCONTRATO"],
            "DSOBSERVACAOORCA"     => $infoModelo[0]["DSOBSERVACAOORCA"],
            "DSREFERENCIAORCA"     => $infoModelo[0]["DSREFERENCIAORCA"],
            "CDMINEMORCA"          => $infoModelo[0]["CDMINEMORCA"],
            "NRDIASCARENCIA"       => $infoModelo[0]["NRDIASCARENCIA"],
            "NRGRUPOFATURA"        => $infoModelo[0]["NRGRUPOFATURA"],
            "NRDIAVENCPARCELASFATU"=> $infoModelo[0]["NRDIAVENCPARCELASFATU"],
            "NRTIPOORCAMENTO"      => $rowContrato["NRTIPOORCAMENTO"],
            "NRORCAMENTOMODELO"    => $rowContrato["NRORCAMENTOMODELO"],
            "NRVENDEDOR"           => null,
            "__is_new"             => true,
            "__columns_to_return"  => array(
                "NRSEQORCAMENTO",
                "NRORG",
                "NRORCAMENTO"
            )
        );
        return $rowProposta;
    }
    /**
     * Altera as informações da refencia, data e observação dos contratos 
     * com composição de serviço e medida
    **/
    public function alterarInformacoesContrato($rowContrato, $nrseqcontrato, $nrorg){
        $nrcontrato     = array();
        $contReferencia = array();
        $params = array(
            "NRSEQORCAMENTO"   => $nrseqcontrato,
            "NRORG"            => $nrorg
        );
        $contratos  = $this->contratoFactory->getContratosRefeOrcaCont($params);
        $observacao = "Referente ao(s) contrato(s)";
        foreach ($contratos as $contrato) {
            array_push($contReferencia, $contrato["NRCONTRATOFCT"]);
            array_push($nrcontrato, $contrato["NRSEQCONTRATO"]);
        }
        $contReferencia = implode(", ", $contReferencia);
        $observacao = $observacao.": ".$contReferencia;
        if(count($contratos) == 0){
            throw new \Exception("Operação bloqueada!<br>Falha ao gerar o contrato.");
        } else {
            if($contratos[0]["DSOBSERVACAOORCA"])
                $observacao = nl2br($observacao."\n".$contratos[0]["DSOBSERVACAOORCA"]);
                
            $this->contratoFactory->alterarObservacaoProposta($params, $observacao);
            $params = array(
                "DSREFERENCIACONT" => $rowContrato["DSREFERENCIACONT"],
                "DTINICIOCONTRATO" => $rowContrato["DTINICIOCONTRATO"],
                "DTFIMCONTRATO"    => $rowContrato["DTFIMCONTRATO"],
                "NRDIASPRAZOCONT"  => $rowContrato["NRDIASPRAZOCONT"],
                "NRORG"            => $nrorg
            );
            $nrcontrato = implode(",", $nrcontrato);
            $this->contratoFactory->alterarInformacoesContrato($params, $nrcontrato);
        }
        
        return (count($contratos) == 1) ? $nrcontrato : null;
    }

    public function parcelarNegociacaoPorIgual($nrnegociacaocontrato, $nrnegociacaoproposta, $qtparcelas, $qtdiasintervalo, $nrdiavencimento, $qtcarenciadias, $vrtotitemcomdesc, $idAlteraProposta = false) {
        $cdoperador = $this->environment->getCdOperador();
        $nrorg      = $this->environment->getNrOrg();

        $params = array (
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "NRORG"                => $nrorg
        );
        $this->contratoFactory->excluirParcelasNegociacao($params);
        
        if($idAlteraProposta) {
            $params = array(
                "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
                "NRORG"                => $nrorg
            );
            $this->propostaFactory->excluirParcelasNegociacao($params);
        }

        $vrParcela   = round((float) $vrtotitemcomdesc / $qtparcelas, 2);
        $sumParcelas = 0;
        $params      = array (
            "NRPARCELANEGOCONT"    => null,
            "NRPARCELANEGOPROP"    => null,
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "QTDIASFATURAMENTO"    => null,
            "NRPARCELA"            => null,
            "NRDIAVENCIMENTO"      => $nrdiavencimento,
            "VRPARCELA"            => null,
            "IDATIVO"              => "S",
            "NRORG"                => $nrorg,
            "NRORGINCLUSAO"        => $nrorg,
            "CDOPERINCLUSAO"       => $cdoperador,
        );
        
        if ((empty($qtcarenciadias)) || ($qtcarenciadias == null)){
            
            $qtcarenciadias = 0;
        }
        
        $diasintervalo = 0;
        for ($i = 1; $i <= $qtparcelas; $i++) {
            
            if ($i == $qtparcelas) {
                $vrParcela = $vrtotitemcomdesc - $sumParcelas;
            }
            
            $params["NRPARCELANEGOCONT"] = $this->newCode->getCodeByTableName("FCT_PARCELANEGOCONT", $nrorg, 1, 10, true);
            $params["VRPARCELA"]         = $vrParcela;
            
            if ($i == 1) {
                $diasintervalo = $qtdiasintervalo + $qtcarenciadias;
            }
            else {
                $diasintervalo += $qtdiasintervalo;
            }
            
            $params["QTDIASFATURAMENTO"] = $diasintervalo;
            $params["NRPARCELA"] = $i;
            
            if($idAlteraProposta)
                $params["NRPARCELANEGOPROP"] = $this->replicarInformacoesParcelasParaProposta($nrnegociacaoproposta, $params);
            
            $this->contratoFactory->inserirParcelaNegociacao($params);
            $sumParcelas += $vrParcela;
        }
    }
    
    public function validarNegociacaoValores($nrseqcontrato) {
        $nrorg = $this->environment->getNrOrg();
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        
        $dataset = $this->contratoFactory->getNegociacaoValoresComSomaDasParcelas($params);
        foreach ($dataset as $row) {
            if ((float)$row["VRTOTITEMCOMDESC"] !== (float)$row["SOMA_PARCELAS"]) {
                return false;
            }
        }
        return true;
    }

    public function desagruparItemNegociacao($nrseqcontrato, $negociacao, $itemNegociacao, $idGeradoPor, $nrseqcontratopai = null) {
        $this->connection->beginTransaction();
        try {
            $nrorg      = $this->environment->getNrOrg();
            $cdoperador = $this->environment->getCdOperador();

            //verifica se o contrato foi feito direto pela tela de contrato para replicar as alterações na proposta
            if ($idGeradoPor == "CONTRATO" && !$nrseqcontratopai) {
                //1- exclui o item da negociacao de valores (proposta)
                $params = array(
                    "NRNEGOCIACAOPROPOSTA" => $itemNegociacao["NRNEGOCIACAOPROPOSTA"],
                    "NRITEMORCAMENTO"      => $itemNegociacao["NRITEMORCAMENTO"],
                    "NRORG"                => $nrorg
                );
                $this->propostaFactory->excluirItemNegociacaoComFilhos($params);
            }

            //1- exclui o item da negociacao de valores (contrato)
            $params = array(
                "NRNEGOCIACAOCONTRATO" => $itemNegociacao["NRNEGOCIACAOCONTRATO"],
                "NRITEMORCAMENTO"      => $itemNegociacao["NRITEMORCAMENTO"],
                "NRORG"                => $nrorg
            );
            $this->contratoFactory->excluirItemNegociacaoComFilhos($params);

            $nrnegociacaoproposta = null;
            if ($idGeradoPor == "CONTRATO" && !$nrseqcontratopai) {
                //2- insere a nova negociacao (proposta)
                $nrnegociacaoproposta = $this->newCode->getCodeByTableName("FCT_NEGOCIACAOPROPOSTA", $nrorg, 1, 10, true);
                $params = array(
                    "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
                    "NRSEQORCAMENTO"       => $nrseqcontrato,
                    "NRTIPOORCAMENTO"      => $negociacao["NRTIPOORCAMENTO"],
                    "IDTPFATURA"           => $negociacao["IDTPFATURA"],
                    "CDFILIALFATURA"       => $negociacao["CDFILIALFATURA"],
                    "NRPARCFATURA"         => $itemNegociacao["NRPARCFATURA"],
                    "CDTIPOOPERFATURA"     => $negociacao["CDTIPOOPERFATURA"],
                    "CDSERIENF"            => $negociacao["CDSERIENF"],
                    "CDEMPRESA"            => $negociacao["CDEMPRESA"],
                    "CDINSCESTA"           => $negociacao["CDINSCESTA"],
                    "CDINSCMUNI"           => $negociacao["CDINSCMUNI"],
                    "VRTOTITEM"            => 0,
                    "VRPERCDESCITEM"       => null,
                    "VRDESCITEM"           => null,
                    "VRTOTITEMCOMDESC"     => 0,
                    "IDATIVO"              => "S",
                    "NRORG"                => $nrorg,
                    "NRORGINCLUSAO"        => $nrorg,
                    "CDOPERINCLUSAO"       => $cdoperador,
                    "IDPREVCOBRFUT"        => $negociacao["IDPREVCOBRFUT"],
                    "CDTRIBPRODPADR"       => $negociacao["CDTRIBPRODPADR"]
                );
                $this->propostaFactory->inserirNegociacaoProposta($params);
            }
            //2- insere a nova negociacao (contrato)
            $nrnegociacaocontrato = $this->inserirDadosNegociacaoContrato($negociacao, $itemNegociacao["NRPARCFATURA"], $nrorg, $cdoperador, $nrnegociacaoproposta);

            $nritnegociacaoproposta = null;
            if ($idGeradoPor == "CONTRATO" && !$nrseqcontratopai) {
                //3- insere o item na nova negociacao (proposta)
                $nritnegociacaoproposta = $this->newCode->getCodeByTableName("FCT_ITNEGOCIACAOPROPOSTA", $nrorg, 1, 10, true);
                $params = array(
                    "NRITNEGOCIACAOPROPOSTA" => $nritnegociacaoproposta,
                    "NRNEGOCIACAOPROPOSTA"   => $nrnegociacaoproposta,
                    "NRITEMORCAMENTO"        => $itemNegociacao["NRITEMORCAMENTO"],
                    "NRITEMORCAMENTOPAI"     => $itemNegociacao["NRITEMORCAMENTOPAI"],
                    "VRTOTITEM"              => $itemNegociacao["VRTOTITEMCOMDESC"],
                    "VRPERCDESCITEM"         => $itemNegociacao["VRPERCDESCITEM"],
                    "VRDESCITEM"             => $itemNegociacao["VRDESCITEM"],
                    "VRTOTITEMCOMDESC"       => $itemNegociacao["VRTOTITEMCOMDESC"],
                    "CDSERVORCA"             => $itemNegociacao["CDSERVORCA"],
                    "CDPRODFATURA"           => $itemNegociacao["CDPRODFATURA"],
                    "NRPARCFATURA"           => $itemNegociacao["NRPARCFATURA"],
                    "IDATIVO"                => "S",
                    "NRORG"                  => $nrorg,
                    "NRORGINCLUSAO"          => $nrorg,
                    "CDOPERINCLUSAO"         => $cdoperador
                );
                $this->propostaFactory->inserirItemNegociacaoProposta($params);
            }
            
            //3- insere o item na nova negociacao (contrato)
            $this->inserirItemNegociacaoContrato($itemNegociacao, $nrnegociacaocontrato, $itemNegociacao, $nritnegociacaoproposta, $nrorg, $cdoperador);
            
            //4- pega os elementos filhos do item para inserir na nova negociacao
            $params = array(
                "NRSEQORCAMENTO"     => $nrseqcontrato,
                "NRITEMORCAMENTOPAI" => $itemNegociacao["NRITEMORCAMENTO"],
                "NRORG"              => $nrorg
            );
            $itensFilhos = $this->propostaFactory->getItensFilhosItemProposta($params);
            
            foreach ($itensFilhos as $filho) {
                $nritnegociacaoproposta = null;
                if ($idGeradoPor == "CONTRATO") {
                    $nritnegociacaoproposta = $this->newCode->getCodeByTableName("FCT_ITNEGOCIACAOPROPOSTA", $nrorg, 1, 10, true);
                    $params = array(
                        "NRITNEGOCIACAOPROPOSTA" => $nritnegociacaoproposta,
                        "NRNEGOCIACAOPROPOSTA"   => $nrnegociacaoproposta,
                        "NRITEMORCAMENTO"        => $filho["NRITEMORCAMENTO"],
                        "NRITEMORCAMENTOPAI"     => $filho["NRITEMORCAMENTOPAI"],
                        "VRTOTITEM"              => $filho["VRTOTALITEMORCA"],
                        "VRPERCDESCITEM"         => null,
                        "VRDESCITEM"             => null,
                        "VRTOTITEMCOMDESC"       => $filho["VRTOTALITEMORCA"],
                        "CDSERVORCA"             => $filho["CDSERVORCA"],
                        "CDPRODFATURA"           => $itemNegociacao["CDPRODFATURA"],
                        "NRPARCFATURA"           => $itemNegociacao["NRPARCFATURA"],
                        "IDATIVO"                => "S",
                        "NRORG"                  => $nrorg,
                        "NRORGINCLUSAO"          => $nrorg,
                        "CDOPERINCLUSAO"         => $cdoperador
                    );
                    $this->propostaFactory->inserirItemNegociacaoProposta($params);
                }

                $this->inserirItemNegociacaoContrato($filho, $nrnegociacaocontrato, $itemNegociacao, $nritnegociacaoproposta, $nrorg, $cdoperador);
            }
            
            if ($idGeradoPor == "CONTRATO" && !$nrseqcontratopai) {
                //5- pega a soma do valor dos itens da negociacao nova para atualizar seu valor (proposta)
                $this->propostaService->atualizarValorNegociacaoComSomaDosItens($nrnegociacaoproposta, $nrorg, $cdoperador);

                //6- pega a soma do valor dos itens da negociacao antiga para atualizar seu valor (proposta)
                $this->propostaService->atualizarValorNegociacaoComSomaDosItens($itemNegociacao["NRNEGOCIACAOPROPOSTA"], $nrorg, $cdoperador);
            }
            
            //5- pega a soma do valor dos itens da negociacao nova para atualizar seu valor (contrato)
            $this->atualizarValoresNegociacaoContrato($nrnegociacaocontrato, $nrorg, $cdoperador);
            
            //6- pega a soma do valor dos itens da negociacao antiga para atualizar seu valor (contrato)
            $valor = $this->atualizarValoresNegociacaoContrato($itemNegociacao["NRNEGOCIACAOCONTRATO"], $nrorg, $cdoperador);
            
            $this->connection->commit();
            return $valor;
        } catch (\Exception $e) {
            $this->connection->rollBack();
            throw $e;
        }
    }

    public function atualizarValoresNegociacaoAoEditarElemento($nrnegociacaocontrato, $nritemcontratopai) {
        $nrorg      = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        
        //1- retorna a soma do valor dos elementos filhos do item
        $params = array(
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "NRITEMOCONTRATO"      => $nritemcontratopai,
            "NRORG"                => $nrorg
        );
        $dataset = $this->contratoFactory->getSomaValorElementosItemNegociacao($params);
        $somaValoresItem = (float)$dataset[0]["VRTOTAL"];
        //2- atualiza o item pai com a soma dos filhos
        $params = array(
            "VRTOTITEM"            => $somaValoresItem,
            "CDOPERULTATU"         => $cdoperador,
            "NRORGULTATU"          => $nrorg,
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "NRITEMOCONTRATO"      => $nritemcontratopai,
            "NRORG"                => $nrorg
        );
        $this->contratoFactory->atualizarValorItemNegociacao($params);

        //3- retorna a soma dos itens da negociacao de valores
        $valor = $this->atualizarValoresNegociacaoContrato($nrnegociacaocontrato, $nrorg, $cdoperador);

        return $valor;
    }

    public function atualizarValoresDescontoPorPeriodoDaNegociacao($valorNegociacao, $nrnegociacaocontrato, $nrorg, $cdoperador) {
        $params = array(
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "NRORG"                => $nrorg
        );

        $dataset = $this->contratoFactory->getDescontosPorPeriodoDaNegociacao($params);
        foreach ($dataset as $row) {
            $params = array(
                "VRTOTITEM"             => $valorNegociacao,
                "CDOPERULTATU"          => $cdoperador,
                "NRORGULTATU"           => $nrorg,
                "NRDESCPERIODONEGOCONT" => $row["NRDESCPERIODONEGOCONT"],
                "NRORG"                 => $nrorg
            );
            $this->contratoFactory->atualizarValorDescontoPorPeriodoDaNegociacao($params);
        }
    }

    public function IntegracaoOM($nrseqcontrato, $nrseqorcamento, $idUtilizaComp, $nrorg, $suspension = false, $extendDate = false) {
        if ($idUtilizaComp == 'S') {
            //Envia os Elementos para o OM
            $this->integracaoOmService->integracaoOM($nrseqorcamento, $nrorg, $idUtilizaComp, $extendDate, $nrseqcontrato, $suspension); 
        }
    }

    public function getQuantidadeItensNegociacaoContrato($nrnegociacaocontrato, $nrorg) {
        $params = array(
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "NRORG"                => $nrorg
        );
        $dataset = $this->contratoFactory->getQuantidadeItensNegociacaoContrato($params);
        return (int)$dataset[0]["QTDE"];
    }

    public function salvarDataFinalValidadeNegociacao($nrnegociacaocontrato, $nrdescperiodonegocont, $nrorg, $dataAtual = null) {
        $dataRowAtual = null;
        
        if(!$dataAtual) {
            $dataAtual = date_create()->format("d/m/Y");
        }
        else if (strpos($dataAtual, " ") !== false) {
            $dataAtual = explode(" ", $dataAtual);
            $dataAtual = $dataAtual[0];
        }
            
        $params = array(
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "NRORG"                => $nrorg
        );
        $descontos    = $this->contratoFactory->getDescontosPorPeriodoDaNegociacao($params);
        $competencias = $this->contratoFactory->getCompetenciaNegociacaoContrato($params);
        
        $dataFinal           = null;
        $dataInicialProxDesc = null;
        
        foreach($descontos as $desconto) {
            $qtdParcelas = $desconto["QTMESESDESC"];
            $contador    = 1;
            
            while ($contador <= $qtdParcelas) {
                foreach ($competencias as $comp) {
                    if ($dataFinal == null) { 
                        $dataAux = explode("/", $dataAtual);
                    } else {
                        if($dataInicialProxDesc == null) 
                            $dataAux = explode("/", $dataFinal->format("d/m/Y"));
                        else 
                            $dataAux = explode("/", $dataInicialProxDesc->format("d/m/Y"));
                    }
                    
                    if (checkdate($dataAux[1], $comp["NRDIACOMPETFIN"], $dataAux[2])) {
                        $dataFinal = DateUtil::getDataDeString(str_pad($comp["NRDIACOMPETFIN"], 2, "0", STR_PAD_LEFT) . "/" . $dataAux[1] . "/" . $dataAux[2]);
                    } else {
                        $dataFinal = DateUtil::getDataDeString("01/" . $dataAux[1] . "/" . $dataAux[2]);
                        $dataFinal = DateUtil::getUltimoDiaDoMes($dataFinal);
                    }
    
                    if ($contador == 1 && $comp["IDMESCOMPETFIN"] == "3") {
                        if (checkdate($dataFinal->format("d"), $dataFinal->format("m")+1, $dataFinal->format("Y"))) {
                            $dataFinal = DateUtil::getDataDeString($dataFinal->format("d") . "/" . str_pad((int)$dataFinal->format("m")+1, 2, "0", STR_PAD_LEFT) . "/" . $dataFinal->format("Y"));
                        } else {
                            $dataFinal = DateUtil::getDataDeString("01/" . str_pad((int)$dataFinal->format("m")+1, 2, "0", STR_PAD_LEFT) . "/" . $dataFinal->format("Y"));
                            $dataFinal = DateUtil::getUltimoDiaDoMes($dataFinal);
                        }
                    }
    
                    $contador++;
                }
                
                if (checkdate($dataFinal->format("d"), $dataFinal->format("m")+1, $dataFinal->format("Y"))) {
                    $dataFinal = DateUtil::getDataDeString($dataFinal->format("d") . "/" . str_pad((int)$dataFinal->format("m")+1, 2, "0", STR_PAD_LEFT) . "/" . $dataFinal->format("Y"));
                } else {
                    $dataFinal = DateUtil::getDataDeString("01/" . str_pad((int)$dataFinal->format("m")+1, 2, "0", STR_PAD_LEFT) . "/" . $dataFinal->format("Y"));
                    $dataFinal = DateUtil::getUltimoDiaDoMes($dataFinal);
                }
                
                $dataInicialProxDesc = DateUtil::getDataDeString($dataFinal->format("d/m/Y"), DateUtil::FORMATO_BRASILEIRO);
            }
    
            if (checkdate($dataFinal->format("d"), $dataFinal->format("m")-1, $dataFinal->format("Y"))) {
                $dataFinal = DateUtil::getDataDeString($dataFinal->format("d") . "/" . str_pad((int)$dataFinal->format("m")-1, 2, "0", STR_PAD_LEFT) . "/" . $dataFinal->format("Y"));
            } else {
                $dataFinal = DateUtil::getDataDeString("01/" . str_pad((int)$dataFinal->format("m")-1, 2, "0", STR_PAD_LEFT) . "/" . $dataFinal->format("Y"));
                $dataFinal = DateUtil::getUltimoDiaDoMes($dataFinal);
            }
            
            if($desconto["NRDESCPERIODONEGOCONT"] == $nrdescperiodonegocont)
                $dataRowAtual = $dataFinal->format("d/m/Y");
                
            //update negociacao com data final
            $params = array(
                "DTFINALVALIDADEDESC"   => $dataFinal->format("d/m/Y"),
                "NRDESCPERIODONEGOCONT" => $desconto["NRDESCPERIODONEGOCONT"],
                "NRORG"                 => $nrorg
            );
            $this->contratoFactory->atualizarDataFinalValidadeDescontoPorPeriodo($params);
        }
        
        return $dataRowAtual;
    }
    /**
     * aplica as informações dos parametros de faturamento
     * as parcelas do período.
    **/
    public function alterarSituacaoParcelasEMedicoes($nrseqcontrato, $dtInicio, $dtFinal, $idsituacao, $nrorg, $cdoperador) {
        $this->connection->beginTransaction();
        try {
            $params = array(
                "NRSEQCONTRATO" => $nrseqcontrato,
                "NRORG"         => $nrorg,
                "DTINICOMPET"   => $dtInicio,
                "DTFINCOMPET"   => $dtFinal
            );
            
            if ($idsituacao == "1") {
                $situacoesMedicao = "'5'";
                $situacoesParcela = "'5'";
            }
            else {
                $situacoesMedicao = "'1', '2', '3'";
                $situacoesParcela = "'1'";
            }
            
            $medicoesCont = $this->contratoFactory->getMedicoesPorPeriodo($params, $situacoesMedicao);
            $medicoesCont = $medicoesCont[0]["NRMEDICAOFATURA"];
            if(!empty($medicoesCont)) {
                $paramsUpdate = array(
                    "CDOPERADOR"    => $cdoperador,
                    "IDSITUACAO"    => $idsituacao,
                    "NRSEQCONTRATO" => $nrseqcontrato,
                    "NRORG"         => $nrorg,
                );
                $this->contratoFactory->alterarStatusMedicao($paramsUpdate, $medicoesCont);
                $this->contratoFactory->alterarStatusMedicaoItens($paramsUpdate, $medicoesCont);
            }
            
            $parcelasCont = $this->contratoFactory->getParcelasPorPeriodo($params, $situacoesParcela);
            $parcelasCont = $parcelasCont[0]["NRFATURACONT"];
            if(!empty($parcelasCont)) {
                $paramsUpdate = array(
                    "CDOPERADOR" => $cdoperador,
                    "IDSITUACAO" => $idsituacao,
                    "NRORG"      => $nrorg,
                );
                $this->contratoFactory->alterarStatusParcelas($paramsUpdate, $parcelasCont);
                $this->contratoFactory->alterarStatusParcelasItens($paramsUpdate, $parcelasCont);
            }
            
            if (empty($medicoesCont) && empty($parcelasCont)) {
                throw new \Exception("SEM_MEDICAO_PARCELA");
            }
            
            $this->connection->commit();
        }
        catch (\Exception $e) {
            $this->connection->rollBack();
            throw $e;
        }
    }
    /**
     * Retoma o faturamento do contrato a partir de determinada data
    **/
    public function retormarFaturamentoContrato($nrseqcontrato, $dsmotivo, $nrparalisacao, $nrorg, $cdoperador) {
        $this->connection->beginTransaction();
        try {
            $dataAtual = date_create();
            $dataAtual = $dataAtual->format("d/m/Y");
            
            $params = array(
                "NRSEQCONTRATO"    => $nrseqcontrato,
                "NRPARAMPARALISAO" => $nrparalisacao,
                "NRORG"            => $nrorg
            );
            $paralisacao = $this->contratoFactory->getParamParalisacao($params);
            
            if(!empty($paralisacao)) {
                $paralisacao = $paralisacao[0];
                $dsmotivo = empty($dsmotivo) ? "." : (". Motivo: " . $dsmotivo);
                $dsmotivo = "Data de retomada alterada de " . $paralisacao["DTRETOMADAFATURA"] . " para " . $dataAtual . $dsmotivo;
                $params = array(
                    "DSMOTIVORETOMADA" => $dsmotivo,
                    "CDOPERADOR"       => $cdoperador,
                    "NRSEQCONTRATO"    => $nrseqcontrato,
                    "NRPARAMPARALISAO" => $nrparalisacao,
                    "NRORG"            => $nrorg
                );
                $this->contratoFactory->alterarDtRetomadaParalisacao($params);
                $this->alterarSituacaoParcelasEMedicoes($nrseqcontrato, $paralisacao["DTINIPARALISACAO"], $paralisacao["DTRETOMADAFATURA"], '1', $nrorg, $cdoperador);
            }
            
            $this->connection->commit();
        }
        catch (\Exception $e) {
            $this->connection->rollBack();
            throw $e;
        }
    }

    public function atualizarNegociacaoProposta($negociacao) {
        $params = array(
            "IDTPFATURA"           => $negociacao["IDTPFATURA"],
            "CDFILIALFATURA"       => $negociacao["CDFILIALFATURA"],
            "NRPARCFATURA"         => $negociacao["NRPARCFATURA"],
            "CDTIPOOPERFATURA"     => $negociacao["CDTIPOOPERFATURA"],
            "CDSERIENF"            => $negociacao["CDSERIENF"],
            "CDEMPRESA"            => $negociacao["CDEMPRESA"],
            "CDINSCESTA"           => $negociacao["CDINSCESTA"],
            "CDINSCMUNI"           => $negociacao["CDINSCMUNI"],
            "VRTOTITEM"            => $negociacao["VRTOTITEM"],
            "VRPERCDESCITEM"       => $negociacao["VRPERCDESCITEM"],
            "VRDESCITEM"           => $negociacao["VRDESCITEM"],
            "VRTOTITEMCOMDESC"     => $negociacao["VRTOTITEMCOMDESC"],
            "NRNEGOCIACAOPROPOSTA" => $negociacao["NRNEGOCIACAOPROPOSTA"],
            "NRORG"                => $negociacao["NRORG"]
        );

        $this->propostaFactory->atualizarNegociacaoProposta($params);
    }
    
    public function atualizarItemNegociacaoProposta($nrnegociacaoproposta, $itemNegociacao, $nrorg = null, $cdoperador = null) {
        if(!$itemNegociacao["VRTOTITEM"]) $itemNegociacao["VRTOTITEM"] = $itemNegociacao["VRTOTITEMCOMDESC"];
        if(is_string($itemNegociacao["VRTOTITEM"])) $itemNegociacao["VRTOTITEM"] = (float) str_replace(',', '.', str_replace(".", "", (string) $itemNegociacao["VRTOTITEM"]));
        
        $params = array(
            "VRTOTITEM"              => $itemNegociacao["VRTOTITEM"],
            "VRPERCDESCITEM"         => $itemNegociacao["VRPERCDESCITEM"],
            "VRDESCITEM"             => $itemNegociacao["VRDESCITEM"],
            "VRTOTITEMCOMDESC"       => $itemNegociacao["VRTOTITEMCOMDESC"],
            "NRPARCFATURA"           => $itemNegociacao["NRPARCFATURA"],
            "NRITNEGOCIACAOPROPOSTA" => $itemNegociacao["NRITNEGOCIACAOPROPOSTA"],
            "NRORG"                  => $itemNegociacao["NRORG"]
        );
        $this->propostaFactory->atualizarItemNegociacaoProposta($params);

        if ($itemNegociacao["NRITEMCONTRATOPAI"] != null) {
            $this->propostaService->atualizarValoresNegociacaoAoEditarElemento($nrnegociacaoproposta, $itemNegociacao["NRITEMORCAMENTOPAI"]);
        }

        $valorNegociacao = $this->atualizarValoresNegociacaoAoEditarElemento($itemNegociacao["NRNEGOCIACAOCONTRATO"], $itemNegociacao["NRITEMCONTRATOPAI"]);
        return $valorNegociacao;
    }
    /**
     * Insere todas as alterações nos elementos, composições e tipos de medida de uma proposta
    **/
    public function inserirTudoContrato($nrseqcontrato, $nrtipoorcamento, $nrmodelocontrato, $medidas, $itens) {
        $nrorg      = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        $arrayItensPai = array();
        $this->connection->beginTransaction();
        try {
            $this->inserirTipoDeMedidaContrato($medidas, $nrseqcontrato, $nrtipoorcamento);
            
            $elementos = $this->session->get("inserir_elementos_proposta");
            if (!empty($elementos)) 
                $this->inserirElementosContrato($elementos, $nrseqcontrato);
            
            $composicoes = $this->session->get("inserir_composicoes_proposta");
            if (!empty($composicoes)) 
                $this->inserirComposicoesContrato($composicoes, $nrseqcontrato);
            
            $servicosVariaveis = $this->session->get("inserir_medidas_variaveis_servicos");
            foreach ($servicosVariaveis as &$row) {
                $row["NRSEQCONTRATO"]  = $nrseqcontrato;
                $row["QTMEDIDACONTR"]  = $row["QTMEDIDAORCA"];
                $this->inserirOuAtualizarMedidaVariavelServico($row, $nrorg, $cdoperador);
            }
            unset($row);
            
            $itensElemento = $this->session->get("inserir_itens_tipo_elementos_proposta");
            $itens         = $this->propostaService->getItensTipoIParaInserir($itens);
            $arrayItensPai = $this->inserirItensContrato($itens, $nrseqcontrato, array());
            $this->inserirItensContrato($itensElemento, $nrseqcontrato, $arrayItensPai);
            
            $this->inserirNegociacaoContrato($nrtipoorcamento, $nrmodelocontrato, $itens, $nrseqcontrato, $nrorg, $cdoperador);

            $this->session->set("inserir_itens_tipo_elementos_proposta", "");
            $this->session->set("inserir_elementos_proposta", "");
            $this->session->set("inserir_composicoes_proposta", "");
            $this->session->set("inserir_medidas_variaveis_servicos", "");
            
            $this->inserirAssinaturasContr($nrmodelocontrato, $nrseqcontrato, $nrorg, $cdoperador);
            
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
    /**
     * Atualiza os itens do contrato após modificações nos elementos ou tipos de medida
    **/
    public function atualizarItensContrato($contrato, $elementos, $composicoes, $nrorg, $cdoperador, $idMantemDescAcres = 'N', $alteraMedida = false) {
        $this->connection->beginTransaction();
        try {
            $mensagem        = null;
            $nrseqcontrato   = $contrato["NRSEQCONTRATO"];
            $itensContrato   = $this->getItensContratos($nrseqcontrato, $nrorg);
            $medidasProposta = $this->getVariacoesPrecoContrato($nrseqcontrato, $nrorg);
            
            $params = array(
                "NRSEQCONTRATO"  => $nrseqcontrato,
                "NRORG"          => $nrorg
            );
            $negociacoes  = $this->contratoFactory->getParametrosFaturaNegociacoesContrato($params);
            $parcelas     = $this->contratoFactory->getParcelasContrato($params);

            if($idMantemDescAcres == 'S')
                $descontos = $this->getDescontosContrato($nrseqcontrato, $nrorg);
            
            $this->deletarTiposMedidaContrato($nrseqcontrato, $nrorg);
            $this->excluirElementosContrato($nrseqcontrato, $nrorg);
            $this->excluirComposicoesContrato($nrseqcontrato, $nrorg);
            $this->excluirItensContrato($nrseqcontrato, $nrorg);
            $this->excluirNegociacaoDeValoresContrato($nrseqcontrato, $nrorg);
            
            $idelementos = array();
            foreach ($elementos as $elemento) {
                array_push($idelementos, $elemento["IDELEMENTO"]);
            }
            
            $tiposMedida = array();
            if(count($medidasProposta) > 0) {
                $nrtipoorcamento = $this->getEscopoContrato($nrseqcontrato, $nrorg);
                $tiposMedida = $this->propostaService->getTiposMedidaVariaveisDosElementos(null, $idelementos, array($nrtipoorcamento), $nrorg);
                foreach($tiposMedida as &$tpMedida) {
                    foreach ($medidasProposta as $medidaProp) {
                        if ($tpMedida["CDTPMEDIDASERV"] == $medidaProp["CDTPMEDIDASERV"] && $tpMedida["IDELEMENTORAIZ"] == $medidaProp["IDELEMENTORAIZ"]) {
                            $tpMedida["QUANTIDADE"] = $medidaProp["QUANTIDADE"];
                        }
                    }
                }
                unset($tpMedida);
            }

            $itens = $this->propostaService->getItensPropostaParaInserir($contrato, $elementos, $composicoes, $tiposMedida, null, "S");

            $this->inserirTudoContrato($contrato["NRSEQCONTRATO"], $contrato["NRTIPOORCAMENTO"], $contrato["NRSEQMODCONTRA"], $tiposMedida, $itens);
            $this->atualizarNomeContratualItens($itensContrato, $contrato["NRSEQCONTRATO"], $nrorg);

            $possuiAlteracaoValor = false;
            foreach($itensContrato as $item) {
                if($item["VRACRESCIMOITEM"] > 0) {
                    $possuiAlteracaoValor = true;
                    break;
                }
            }

            if($idMantemDescAcres == 'S' && (count($descontos) > 0 || $possuiAlteracaoValor)) {
                $this->atualizarDescontosAcrescimosContrato($itensContrato, $descontos, $nrseqcontrato, $nrorg, $negociacoes, $alteraMedida, $contrato["IDSITUACAOCONTRATO"], $parcelas);
            }
            
            $this->atualizarParcelasContrato($negociacoes, $nrseqcontrato, $parcelas, $nrorg); 
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
        return $mensagem;
    }

    /**
     * Altera o nome contratual do item
    **/
    public function atualizarNomeContratualItens($itens, $nrseqcontrato, $nrorg){
        $cdservorcas = array();
        foreach($itens as $item){
            if($item["IDELEMENTO"]){
                $params = array(
                    "NRORG"                => $nrorg, 
                    "NRSEQCONTRATO"        => $nrseqcontrato,
                    "IDELEMENTO"           => $item['IDELEMENTO'],
                    "NMCONTRATUALITEMCONT" => $item["NMCONTRATUALITEMCONT"]
                );
                $this->contratoFactory->atualizarNomeContratualItens($params);
            }
        }
    }
    /**
     * Busca os itens de um determinado contrato
    **/
    public function getItensContratos($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO"   => $nrseqcontrato,
            "NRORG"           => $nrorg
        );
        
        return $this->contratoFactory->getItensContratos($params);
    }
    /**
     * Busca todas as variações de preço ligadas aos elementos e escopos do contrato
    **/
    public function getVariacoesPrecoContrato($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        
        return $this->contratoFactory->getVariacoesPrecoContrato($params);
    }
    /**
     * Deleta os tipos de medida ligados a um contrato
    **/
    public function deletarTiposMedidaContrato($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        
        $this->contratoFactory->deletarTiposMedidaContrato($params);
    }
    /**
     * Deleta os elementos de um determinado contrato
    **/
    public function excluirElementosContrato($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        
        $this->contratoFactory->excluirElementosContrato($params);
    }
    /**
     * As composições de serviços ligadas a um contrato 
    **/
    public function excluirComposicoesContrato($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        
        $this->contratoFactory->excluirComposicoesContrato($params);
    }
    /**
     * exclui os itens do contrato
    **/
    public function excluirItensContrato($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        
        $this->contratoFactory->excluirItensContrato($params);
    }
    /**
     * exclui a negociação de valores
    **/
    public function excluirNegociacaoDeValoresContrato($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        
        $this->contratoFactory->excluirNegociacaoDeValoresContrato($params);
    }
    /**
     * Manda inserir os tipos de medida de um contrato
    **/
    public function inserirTipoDeMedidaContrato($medidas, $nrseqcontrato, $nrtipoorcamento = null, $idApareceProposta = "S") {
        $nrorg      = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        
        foreach ($medidas as $medida) {
            $novoCodigo = $this->newCode->getCodeByTableName("FCT_RELACMEDIDACONTRATO", $nrorg, 1, 10, true);
            $params = array(
                "NRMEDIDACONTRATO"   => $novoCodigo,
                "NRSEQCONTRATO"      => $nrseqcontrato,
                "CDTPMEDIDAVARIAVEL" => $medida["CDTPMEDIDASERV"],
                "QTMEDIDAVARIAVEL"   => $medida["QUANTIDADE"],
                "NRORG"              => $nrorg,
                "NRORGINCLUSAO"      => $nrorg,
                "CDOPERINCLUSAO"     => $cdoperador,
                "IDATIVO"            => "S",
                "IDELEMENTORAIZ"     => $medida["IDELEMENTORAIZ"],
                "QTFRANQUIA"         => $medida["QTFRANQUIA"],
                "NRTIPOORCAMENTO"    => array_key_exists("NRTIPOORCAMENTO", $medidas) ? $medida["NRTIPOORCAMENTO"] : $nrtipoorcamento,
                "IDAPARECEPROPOSTA"  => $idApareceProposta
            );
            
            $this->contratoFactory->inserirTipoDeMedidaContrato($params);
        }
    }
    /**
     * Manda salvar os elementos de um contrato
    **/
    public function inserirElementosContrato($elementos, $nrseqcontrato) {
        $nrorg      = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        foreach ($elementos as $row) {
            $nrtrabservcont = $this->newCode->getCodeByTableName("FCT_TRABSERVCONTRATO", $nrorg, 1, 10, true);
            $params = array(
                "NRTRABSERVCONT"    => $nrtrabservcont,
                "NRSEQCONTRATO"     => $nrseqcontrato,
                "NRTIPOORCAMENTO"   => $row["NRTIPOORCAMENTO"],
                "NRCOMPSERVICO"     => isset($row["NRCOMPSERVICO"]) ? $row["NRCOMPSERVICO"] : null,
                "NRITCOMPSERVICO"   => isset($row["NRITCOMPSERVICO"]) ? $row["NRITCOMPSERVICO"] : null,
                "IDELEMENTO"        => $row["IDELEMENTO"],
                "IDELEMENTOPAI"     => $row["IDELEMENTOPAI"],
                "IDTIPOELEMENTO"    => $row["IDTIPOELEMENTO"],
                "IDESCOLHIDO"       => $row["IDESCOLHIDO"],
                "CDSERVORCA"        => $row["CDSERVORCARELAC"],
                "QTSERVORCA"        => 1,
                "CDTPMEDIDASERV"    => $row["CDTPMEDIDAVARIAVEL"],
                "QTMEDSERVORCA"     => $row["QTMEDIDASERV"],
                "VRUNITSERVORCA"    => (float)$row["VRPRECO"],
                "VRTOTSERVORCA"     => (float)$row["VRPRECO"] * $row["QTMEDIDASERV"],
                "IDATIVO"           => "S",
                "NRORG"             => $nrorg,
                "CDOPERINCLUSAO"    => $cdoperador,
                "NRORGINCLUSAO"     => $nrorg,
                "IDSERVOBRIGCOMP"   => $row["IDSERVOBRIGCOMP"],
                "QTMEDIDAVARIAVEL"  => $row["QTMEDIDAVARIAVEL"],
                "QTMEDIDACALC"      => $row["QTMEDIDASERV"],
                "IDAPARECEPROPOSTA" => isset($row["IDAPARECEPROPOSTA"]) ? $row["IDAPARECEPROPOSTA"] : "S",
                "CDCENTCUST"        => $row["CDCENTCUST"]
            );
            
            $this->contratoFactory->inserirElementosContrato($params);
        }
    }
    /**
     * Manda salvar as composições de serviço de um contrato
    **/
    public function inserirComposicoesContrato($composicoes, $nrseqcontrato) {
        $nrorg      = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        
        foreach ($composicoes as $comp) {
            $nrcompservcontrato = $this->newCode->getCodeByTableName("FCT_COMPSERVCONTRATO", $nrorg, 1, 10, true);
            $params = array(
                "NRCOMPSERVCONT"      => $nrcompservcontrato,
                "NRSEQCONTRATO"       => $nrseqcontrato,
                "NRCOMPSERVICO"       => $comp["NRCOMPSERVICO"],
                "NMCOMPSERVICO"       => $comp["NMCOMPSERVICO"],
                "NRCOMPSERVICOPAI"    => $comp["NRCOMPSERVICOPAI"],
                "IDCOMPOBRIGATORIA"   => $comp["IDCOMPOBRIGATORIA"],
                "IDESCOLHIDO"         => $comp["IDESCOLHIDO"],
                "IDATIVO"             => "S",
                "NRORG"               => $nrorg,
                "CDOPERINCLUSAO"      => $cdoperador,
                "NRORGINCLUSAO"       => $nrorg,
                "CDCENTCUST"          => $comp["CDCENTCUST"]
            );
            
            $this->contratoFactory->inserirComposicoesContrato($params);
        }
    }
    /**
     * Manda inserir os itens de um contrato
    **/
    public function inserirItensContrato($dataset, $nrseqcontrato, $itensServOrca){
        $nrorg         = $this->environment->getNrOrg();
        $cdoperador    = $this->environment->getCdOperador();
        $arrayItensPai = array();

        $dadosContrato = $this->getDadosContrato($nrseqcontrato, $nrorg);
        $nrmoeda = $dadosContrato["NRMOEDA"];
        
        foreach ($dataset as &$row) {
            if(count($itensServOrca) == 0 || array_key_exists((string)$row["CDSERVORCA"], $itensServOrca)){
                $nritemocontrato = $this->newCode->getCodeByTableName("FCT_ITEMCONTRATO", $nrorg, 1, 10, true);
                $arrayItensPai[(string)$row["CDSERVORCA"]] = $nritemocontrato;

                if($row["IDTIPO"] == "I") {
                    $row["VRUNITITEMORCA"] = $row["VRTOTALITEMORCA"];
                } else {
                    if (is_string($row["VRUNITITEMORCA"])) {
                        if (strpos($row["VRUNITITEMORCA"], ',') !== false) {
                            $row["VRUNITITEMORCA"] = (float)str_replace(",", ".", str_replace(".", "", $row["VRUNITITEMORCA"]));
                        }
                        else {
                            $row["VRUNITITEMORCA"] = (float)$row["VRUNITITEMORCA"];
                        }
                    }
                    if (is_string($row["QTMEDIDASERV"])) {
                        if (strpos($row["QTMEDIDASERV"], ',') !== false) {
                            $row["QTMEDIDASERV"] = (float)str_replace(",", ".", str_replace(".", "", $row["QTMEDIDASERV"]));
                        }
                        else {
                            $row["QTMEDIDASERV"] = (float)$row["QTMEDIDASERV"];
                        }
                    }
                }
                
                $vritemsemdesc = $row["QTITEMORCAMENTO"] * $row["VRUNITITEMORCA"];
                if ($row["QTMEDIDASERV"] != null && $row["QTMEDIDASERV"] != 0) 
                    $vritemsemdesc = $vritemsemdesc * (float)$row["QTMEDIDASERV"];
                    
                $params = array(
                    "NRORG"                  => $nrorg,
                    "NRITEMOCONTRATO"        => $nritemocontrato,
                    "NRITEMCONTRATOPAI"      =>  count($itensServOrca) == 0 ? null : $itensServOrca[(string)$row["CDSERVORCA"]],
                    "NRSEQCONTRATO"          => $nrseqcontrato,
                    "CDSERVORCA"             => $row["CDSERVORCA"],
                    "NMITEMCONTRATO"         => $row["NMSERVORCA"],
                    "IDELEMENTO"             => $row["IDELEMENTO"],
                    "QTITEMCONTRATO"         => $row["QTITEMORCAMENTO"],
                    "CDTPMEDIDASERV"         => $row["CDTPMEDIDASERV"],
                    "QTMEDIDACONTR"          => $row["QTMEDIDASERV"],
                    "QTPARCELASFATU"         => $row["QTPARCELASFATU"],
                    "NRDIAVENCPARCELASFATU"  => $row["NRDIAVENCPARCELASFATU"],
                    "VRUNITITEMCONT"         => $row["VRUNITITEMORCA"],
                    "VRUNITITEMCONTTBLPRECO" => $row["VRUNITITEMORCA"],
                    "VRTOTITEMCONT"          => $row["VRTOTALITEMORCA"],
                    "CDTPMEDIDAVARIAVEL"     => $row["CDTPMEDIDAVARIAVEL"],
                    "NRITEMORCAMENTO"        => isset($row["NRITEMORCAMENTO"]) ? $row["NRITEMORCAMENTO"] : null,
                    "CDPRODUTO"              => null,
                    "SGUNIDADE"              => null,
                    "IDUNIDTEMPOSERV"        => null,
                    "QTTEMPOSERV"            => null,
                    "DTINICFATCONTR"         => null,
                    "IDITEMATIVO"            => 'S',
                    "IDMULTMEDVRTOT"         => 'S',
                    "IDADICITEMCONT"         => 'N',
                    "IDADICCOBRCONT"         => 'N',
                    "IDFATURAITEM"           => 'SIM',
                    "VRDESCONTO"             => 0,
                    "IDTPDESCONTO"           => 'S',
                    "QTMEDIDACALCULADA"      => $row["QTMEDIDASERV"],
                    "IDAPARECEPROPOSTA"      => isset($row["IDAPARECEPROPOSTA"]) ? $row["IDAPARECEPROPOSTA"] : "S",
                    "NRMOEDA"                => $nrmoeda
                );

                $this->contratoFactory->inserirItensContrato($params);
            }
        }
        unset($row);
        return $arrayItensPai;
    }
    /**
     * Busca as composições, elementos e manda atualizar os itens do 
     * contrato depois de uma alteração no tipo de medida
    **/
    public function atualizarTipoDeMedidaContrato($contrato, $nrorg, $cdoperador, $tptratamento){
        $nrseqcontrato = $contrato["NRSEQCONTRATO"];
        $elementos     = $this->getElementosEscolhidos($nrseqcontrato, $nrorg);
        $composicoes   = $this->getComposicoesContrato($nrseqcontrato, $nrorg);
        $this->atualizarItensContrato($contrato, $elementos, $composicoes, $nrorg, $cdoperador, $tptratamento, true);
    }
    /**
     * Retorna os Elementos escolhidos em um contrato.
     */
    public function getElementosEscolhidos($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        return $this->contratoFactory->getElementosEscolhidos($params);
    }
    /**
     * Retorna as composições de um contrato
    **/
    public function getComposicoesContrato($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        
        return $this->contratoFactory->getComposicoesContrato($params);
    }
    /**
     * Atualiza o parceiro de negócio da negociação caso o parceiro do contrato seja atualizado
    **/
    public function atualizarParceiroNegociacoesContrato($nrseqcontrato, $nrparcnegocio) {
        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();

        $params = array(
            "NRPARCFATURA"  => $nrparcnegocio,
            "NRORGULTATU"   => $nrorg,
            "CDOPERULTATU"  => $cdoperador,
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        
        $this->contratoFactory->atualizarParceiroNegociacoesContrato($params);
        $this->contratoFactory->atualizarParceiroItensNegociacoesContrato($params);
    }
    /**
     * Insere a negociação de valores apos uma edição nos elementos ou 
     * tipo de medida do contrato
    **/
    public function inserirNegociacaoContrato($escopos, $nrmodelocontrato, $itens, $nrseqcontrato, $nrorg, $cdoperador){
        $servicos = "";
        for($i = 0; $i < count($itens); $i++) 
            $servicos .= ($servicos == "" ? "" : ",") . $itens[$i]["CDSERVORCA"];
        
        $params = array(
            "NRSEQMODCONTRA" => $nrmodelocontrato,
            "NRSEQCONTRATO"  => $nrseqcontrato,
            "NRORG"          => $nrorg
        );
        $itensNegociacao = $this->contratoFactory->getParametrosFaturamentoItensNegociacaoContrato($params, $escopos, $servicos);
        $cdNegociacoesInseridas = array();
        $itemAnterior           = array();
        
        if(count($itensNegociacao) == 0)
            throw new \Exception('Operação bloqueada. <br/><br/>Não foi possível inserir a Negociação de Valores. Certifique-se que o modelo de contrato esteja ligado a um escopo de faturamento, que os parâmetros de faturamento estejam cadastrados e tente novamente.');
        
        foreach($itensNegociacao as $item) {
            if ($item["CDFILIALFATURA"] == null) 
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Unidade para Faturamento" não foi encontrado para o item "' . $item["NMITEMORCAMENTO"] . '". Favor conferir a parametrização de faturamento do Escopo.');
            
            if ($item["CDTIPOOPERFATURA"] == null)
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Tipo de Operação da Nota Fiscal" não foi encontrado para o item "' . $item["NMITEMORCAMENTO"] . '". Favor conferir a parametrização de faturamento do Escopo.');
            
            if ($item["CDSERIENF"] == null) 
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Série da Nota Fiscal" não foi encontrado para o item "' . $item["NMITEMORCAMENTO"] . '". Favor conferir a parametrização de faturamento do Escopo.');
    
            $competencia = array();
            if ($item["IDTPFATURA"] != "P") {
                $params = array(
                    "NRTIPOORCAMENTO" => $item["NRTIPOORCAMENTO"],
                    "CDSERVORCA"      => $item["CDSERVORCA"],
                    "NRORG"           => $nrorg,
                );
                $competencia = $this->propostaFactory->getCompetenciaItemNegociacao($params);
            }
            
            $item["COMPETENCIA"] = print_r($competencia, true);
            if ($this->propostaService->itensNegociacaoSaoDiferentes($item, $itemAnterior)) {
                $nrnegociacaocontrato     = $this->inserirDadosNegociacaoContrato($item, $item["NRPARCFATURA"], $nrorg, $cdoperador, null);
                $cdNegociacoesInseridas[] = $nrnegociacaocontrato;
                foreach ($competencia as $comp) 
                    $this->inserirCompetenciaNegociacaoContrato($comp, $nrnegociacaocontrato, $nrorg, $cdoperador);
            }
            $this->inserirItemNegociacaoContrato($item, $nrnegociacaocontrato, $item, null, $nrorg, $cdoperador);
            $params = array(
                "NRSEQCONTRATO"     => $nrseqcontrato,
                "NRITEMCONTRATOPAI" => $item["NRITEMOCONTRATO"],
                "NRORG"             => $nrorg
            );
            $itensFilhos = $this->contratoFactory->getItensFilhosItemContrato($params);
            foreach ($itensFilhos as $itemFilho) {
                $this->inserirItemNegociacaoContrato($itemFilho, $nrnegociacaocontrato, $item, null, $nrorg, $cdoperador);
            }
            
            $itemAnterior = $item;
        }
        
        foreach ($cdNegociacoesInseridas as $cod) {
            $this->atualizarValoresNegociacaoContrato($cod, $nrorg, $cdoperador);
        }
    }
    /**aqui
     * Insere as competencias de uma negociação do contrato
    **/
    public function inserirCompetenciaNegociacaoContrato($competencia, $nrnegociacaocontrato, $nrorg, $cdoperador) {
        $nrcompetencianego = $this->newCode->getCodeByTableName("FCT_COMPETENCIANEGOCONT", $nrorg, 1, 10, true);
        $params = array(
            "NRCOMPETENCIANEGOCONT" => $nrcompetencianego,
            "NRNEGOCIACAOCONTRATO"  => $nrnegociacaocontrato,
            "NRDIACOMPETINI"        => $competencia["NRDIACOMPETINI"],
            "NRDIACOMPETFIN"        => $competencia["NRDIACOMPETFIN"],
            "IDMESCOMPETINI"        => $competencia["IDMESCOMPETINI"],
            "IDMESCOMPETFIN"        => $competencia["IDMESCOMPETFIN"],
            "QTDIASAPURACAO"        => $competencia["QTDIASAPURACAO"],
            "IDTPCALCVENC"          => $competencia["IDTPCALCVENC"],
            "NRDIACALCVENC"         => $competencia["NRDIACALCVENC"],
            "IDMESCALCVENC"         => $competencia["IDMESCALCVENC"],
            "QTDIASFATUVENC"        => $competencia["QTDIASFATUVENC"],
            "NRCOMPETENCIANEGOPROP" => isset($competencia["NRCOMPETENCIANEGOPROP"]) ? $competencia["NRCOMPETENCIANEGOPROP"] : null,
            "IDATIVO"               => "S",
            "NRORG"                 => $nrorg,
            "NRORGINCLUSAO"         => $nrorg,
            "CDOPERINCLUSAO"        => $cdoperador
        );
        $this->contratoFactory->inserirCompetenciaNegociacaoContrato($params);
    }
    /**
     * Insere as informações da negociação de valores 
    **/
    public function inserirDadosNegociacaoContrato($negociacao, $nrparcfatura, $nrorg, $cdoperador, $nrnegociacaoproposta) {
        $nrnegociacaocontrato = $this->newCode->getCodeByTableName("FCT_NEGOCIACAOCONTRATO", $nrorg, 1, 10, true);
        $params = array(
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "NRSEQCONTRATO"        => $negociacao["NRSEQCONTRATO"],
            "NRTIPOORCAMENTO"      => $negociacao["NRTIPOORCAMENTO"],
            "IDTPFATURA"           => $negociacao["IDTPFATURA"],
            "CDFILIALFATURA"       => $negociacao["CDFILIALFATURA"],
            "CDTIPOOPERFATURA"     => $negociacao["CDTIPOOPERFATURA"],
            "CDSERIENF"            => $negociacao["CDSERIENF"],
            "CDEMPRESA"            => $negociacao["CDEMPRESA"],
            "CDINSCESTA"           => $negociacao["CDINSCESTA"],
            "CDINSCMUNI"           => $negociacao["CDINSCMUNI"],
            "NRPARCFATURA"         => $nrparcfatura,
            "VRTOTITEM"            => 0,
            "VRPERCDESCITEM"       => isset($negociacao["VRPERCDESCITEM"]) ? $negociacao["VRPERCDESCITEM"] : null,
            "VRDESCITEM"           => isset($negociacao["VRDESCITEM"])     ? $negociacao["VRDESCITEM"] : null,
            "VRTOTITEMCOMDESC"     => 0,
            "IDATIVO"              => "S",
            "NRORG"                => $nrorg,
            "NRORGINCLUSAO"        => $nrorg,
            "CDOPERINCLUSAO"       => $cdoperador,
            "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
            "NRESTRUTURAM"         => null,
            "IDPREVCOBRFUT"        => $negociacao["IDPREVCOBRFUT"],
            "CDTRIBPRODPADR"       => $negociacao["CDTRIBPRODPADR"],
            "CDPAISFAT"            => null,
            "SGESTADOFAT"          => null,
            "CDMUNICIPIOFAT"       => null,
            "IDNATUOPER"           => null,
            "NRTIPOESTRUTURA"      => null,
            "DSLOTEFATURAMENTO"    => null
        );
        $this->contratoFactory->inserirNegociacaoContrato($params);
        return $nrnegociacaocontrato;
    }
    /**
     * manda inserir um item da negociação de valores
    **/
    public function inserirItemNegociacaoContrato($item, $nrnegociacaocontrato, $itemNegociacao, $nritnegociacaoproposta, $nrorg, $cdoperador){
        $nritnegociacaocontrato = $this->newCode->getCodeByTableName("FCT_ITNEGOCIACAOCONTRATO", $nrorg, 1, 10, true);
        $params = array(
            "NRITNEGOCIACAOCONTRATO" => $nritnegociacaocontrato,
            "NRNEGOCIACAOCONTRATO"   => $nrnegociacaocontrato,
            "NRITEMOCONTRATO"        => $item["NRITEMOCONTRATO"],
            "NRITEMCONTRATOPAI"      => $item["NRITEMCONTRATOPAI"],
            "VRTOTITEM"              => $item["VRTOTITEMCONT"],
            "CDSERVORCA"             => $item["CDSERVORCA"],
            "CDPRODFATURA"           => $itemNegociacao["CDPRODFATURA"],
            "NRPARCFATURA"           => $itemNegociacao["NRPARCFATURA"],
            "VRTOTITEMCOMDESC"       => $item["VRTOTITEMCONT"],
            "NRITEMORCAMENTO"        => isset($item["NRITEMORCAMENTO"]) ? $item["NRITEMORCAMENTO"] : null,
            "IDATIVO"                => "S",
            "NRITEMORCAMENTOPAI"     => null,
            "VRPERCDESCITEM"         => null,
            "VRDESCITEM"             => null,
            "NRORG"                  => $nrorg,
            "NRORGINCLUSAO"          => $nrorg,
            "CDOPERINCLUSAO"         => $cdoperador,
            "NRITNEGOCIACAOPROPOSTA" => $nritnegociacaoproposta
        );
        //Salvar na tabela HR de itens negociacao contrato
        $this->contratoFactory->inserirItemNegociacaoContrato($params);
    }
    
    /**
     * Atualiza o valor da negociação na tabela do contrato
    **/
    public function atualizarValoresNegociacaoContrato($nrnegociacaocontrato, $nrorg, $cdoperador) {
        $params = array(
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "NRORG"                => $nrorg
        );
        $dataset = $this->contratoFactory->getSomaValorItensNegociacao($params);
        $valor = $dataset[0]["VRTOTAL"];

        if (is_null($valor)) {
            $this->contratoFactory->excluirNegociacaoContrato($params);
        }
        else {
            $params = array(
                "VRTOTAL"              => $valor,
                "CDOPERULTATU"         => $cdoperador,
                "NRORGULTATU"          => $nrorg,
                "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
                "NRORG"                => $nrorg
            );
            $this->contratoFactory->atualizarValorNegociacaoComSomaDosItens($params);
            
            // Busca o valor total com desconto novo da negociação
            $dadosNegociacao = $this->getDadosNegociacaoValoresContrato($nrnegociacaocontrato, $nrorg);
            $valorTotalComDesc = (float)$dadosNegociacao["VRTOTITEMCOMDESC"];
    
            // Atualiza os registros da aba de Desconto por Periodo com o valor novo
            $this->atualizarValoresDescontoPorPeriodoDaNegociacao($valorTotalComDesc, $nrnegociacaocontrato, $nrorg, $cdoperador);
        }

        return $valor;
    }
    /**
     * Busca todas as variações de preço ligadas a um contrato
    **/
    public function getVariacaoPrecoBaseContrato($nrseqcontrato, $nrorg, $nrmoeda = null) {
        $variacoes = array();
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRMOEDA"       => $nrmoeda,
            "NRORG"         => $nrorg
        );
        
        $variacoes          = $this->contratoFactory->getVariacaoPresoBaseServicos($params);
        $variacoesElementos = $this->contratoFactory->getVariacaoPrecoBaseContrato($params);
        
        if(count($variacoes) <= 0) {
            return $variacoesElementos;
        } else {
            $servicos = array();
            foreach($variacoes as $medida) {
                if(array_search($medida["CDSERVORCA"], $servicos) === false)
                    array_push($servicos, $medida["CDSERVORCA"]);
            }
            
            foreach($variacoesElementos as $variacao) {
                if(array_search($variacao["CDSERVORCA"], $servicos) === false)
                    array_push($variacoes, $variacao);
            }
        }
        
        return $variacoes;
    }
    /**
     * Salva numa tabela de backup as informações do serviço e da 
     * variação de preço ligada ao contrato
    **/
    public function salvarDadosMedidaContrato($nrseqcontrato, $nrorg, $cdoperador, $nrmoeda = null) {
        if ($this->getValorVariacoesPrecoContrato($nrseqcontrato, $nrorg) == 0) {
            $variacoes = $this->getVariacaoPrecoBaseContrato($nrseqcontrato, $nrorg, $nrmoeda);
            foreach($variacoes as $variacao) {
                $nrvarprecobasecont = $this->newCode->getCodeByTableName("FCT_VARPRECBASESERVCONT", $nrorg, 1, 10, true);
                $params = array(
                    "NRVARPRECBASESERVCONT" => $nrvarprecobasecont,
                    "NRSEQCONTRATO"         => $nrseqcontrato,
                    "CDSERVORCA"            => $variacao["CDSERVORCA"],
                    "CDTPMEDIDASERV"        => $variacao["CDTPMEDIDASERV"],
                    "CDTPMEDIDAVARIAVEL"    => $variacao["CDTPMEDIDAVARIAVEL"],
                    "QTMEDIDAINIVARIACAO"   => $variacao["QTMEDIDAINIVARIACAO"],
                    "QTMEDIDAFIMVARIACAO"   => $variacao["QTMEDIDAFIMVARIACAO"],
                    "QTFRANQUIA"            => $variacao["QTFRANQUIA"],
                    "VRPRECOVARIACAO"       => $variacao["VRPRECOVARIACAO"],
                    "IDMULTIPVARIACAO"      => $variacao["IDMULTIPVARIACAO"],
                    "NRORG"                 => $nrorg,
                    "NRORGINCLUSAO"         => $nrorg,
                    "IDATIVO"               => "S",
                    "CDOPERINCLUSAO"        => $cdoperador
                );
                $this->contratoFactory->inserirDadosVariacaoPrecoBaseContrato($params);
            }
            
            $this->atualizarValoresVariacaoPrecoContratoComServicosComMedicao($nrseqcontrato, $nrorg, $cdoperador);
        }
    }
    
    public function atualizarValoresVariacaoPrecoContratoComServicosComMedicao($nrseqcontrato, $nrorg, $cdoperador) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        $servicosComMedicao = $this->contratoFactory->getServicosComMedicao($params);
        $servicosPesquisados = array();
        
        foreach ($servicosComMedicao as $serv) {
            
            $params = array(
                "CDTPMEDIDAVARIAVEL" => $serv["CDTPMEDIDAVARIAVEL"],
                "CDOPERULTATU"       => $cdoperador,
                "NRORGULTATU"        => $nrorg,
                "NRSEQCONTRATO"      => $nrseqcontrato,
                "NRORG"              => $nrorg,
                "CDSERVORCA"         => $serv["CDSERVORCA"]
            );
            
            $medidaIsNotNull = false;
            
            if (!in_array($serv["CDSERVORCA"], $servicosPesquisados)) {
                $qtd = $this->getQtdeVarPrecContratoComMedidaVariavel($nrseqcontrato, $serv["CDSERVORCA"], $nrorg);
                if ($qtd > 0) {
                    $medidaIsNotNull = true;
                }
                
                $servicosPesquisados[] = $serv["CDSERVORCA"];
            }
            
            $this->contratoFactory->atualizarValorVariacaoPrecoServicoContrato($params, $medidaIsNotNull);
        }
    }
    
    public function getQtdeVarPrecContratoComMedidaVariavel($nrseqcontrato, $cdservorca, $nrorg) {
        $params = array(
            "NRSEQCONTRATO"  => $nrseqcontrato,
            "CDSERVORCA"     => $cdservorca,
            "NRORG"          => $nrorg
        );
        $dataset = $this->contratoFactory->getQtdeVarPrecContratoComMedidaVariavel($params);
        return (int)$dataset[0]["QTD"];
    }
    
    /**
     * Retorna a proposta ligada a um contrato
    **/
    public function getPropostaDoContrato($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        return $this->contratoFactory->getPropostaDoContrato($params);
    }
    /**
     * Atualiza dados da proposta e do contrato em contratos de composição de serviço
    **/
    public function atualizarInformacoesContratoProposta($row, $nrorg, $cdoperador) {
        $this->connection->beginTransaction();
        try {
            $contrato = $row["CONTRATO"];

            $params = array(
                "NRSEQORCAMENTO" => $contrato["NRSEQORCAMENTO"],
                "NRORG"          => $nrorg
            );
            $contratosOcamento = $this->contratoFactory->getContratosRefeOrcaCont($params);
            foreach($contratosOcamento as $contOrca) {
                if($contOrca["NRVERSAOCONTRATO"] == 1) {
                    $nrseqcontrato = $contOrca["NRSEQCONTRATO"];
                    $this->deletarTiposMedidaContrato($nrseqcontrato, $nrorg);
                    $this->excluirElementosContrato($nrseqcontrato, $nrorg);
                    $this->excluirComposicoesContrato($nrseqcontrato, $nrorg);
                    $this->excluirItensContrato($nrseqcontrato, $nrorg);
                    $this->excluirNegociacaoDeValoresContrato($nrseqcontrato, $nrorg);
                }
            }
            
            if($row["TPALTERACAO"] == "TPMEDIDAS") {
                $medidas = $row["MEDIDA"];
                $params  = array(
                    "IDELEMENTORAIZ"     => $medidas["IDELEMENTORAIZ"],
                    "NRSEQORCAMENTO"     => $row["PROPOSTA"]["NRSEQORCAMENTO"],
                    "CDTPMEDIDAVARIAVEL" => $medidas["CDTPMEDIDAVARIAVEL"],
                    "QTMEDIDAVARIAVEL"   => $medidas["QTMEDIDAVARIAVEL"],
                    "CDOPERULTATU"       => $cdoperador,
                    "NRORG"              => $nrorg
                );
                $this->contratoFactory->salvarTipoMedidaProposta($params);
                $this->propostaService->atualizarTipoDeMedidaProposta($row["PROPOSTA"], $nrorg, $cdoperador, $row["TPTRATAMENTO"], true);
            } else {
                $elementos   = $row["ELEMENTOS"];
                $composicoes = $row["COMPOSICOES"];
                $this->propostaService->atualizarItensProposta($row["PROPOSTA"], $elementos, $composicoes, $nrorg, $cdoperador, $row["TPTRATAMENTO"]);
            }
            
            $this->replicarAlteracaoItensPropostaParaContrato($contratosOcamento, $nrorg, $cdoperador);
            $this->connection->commit();
        }  catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
    /**
     * Busca as informações da proposta e atualiza nas tabelas do contrato
    **/
    public function replicarAlteracaoItensPropostaParaContrato($contratosOcamento, $nrorg, $cdoperador) {
        foreach($contratosOcamento as $cont) {
            if($cont["NRVERSAOCONTRATO"] == 1) {
                $nrseqcontrato    = $cont["NRSEQCONTRATO"];
                $nrseqorcamento   = $cont["NRSEQORCAMENTO"];
                $escopos          = $cont["NRTIPOORCAMENTO"];
                $nrmodelocontrato = $cont["NRSEQMODCONTRA"];
                
                $this->atualizarElementosContrato($nrseqcontrato, $nrseqorcamento, $nrorg, $escopos);
                $this->atualizarComposicaoContrato($nrseqcontrato, $nrseqorcamento, $nrorg);
                $this->atualizarItensContratoProposta($nrseqcontrato, $nrseqorcamento, $nrorg, $escopos);
                
                if($cont["IDUTILIZAVARPRECO"] == 'S')
                    $this->atualizarTiposMedidasContrato($nrseqcontrato, $nrseqorcamento, $nrorg, $escopos);
                    
                $this->atualizarMedidasServicos($nrseqcontrato, $nrseqorcamento, $nrorg, $escopos, $cdoperador);
                $this->atualizarNegociacaoDeValores($nrseqcontrato, $nrorg, $escopos, $cdoperador);
            }
        }
    }
    /**
     * Busca a negociação gerada na proposta e atualiza o contrato
    **/
    public function atualizarNegociacaoDeValores($nrseqcontrato, $nrorg, $escopos, $cdoperador) {
        $params = array(
            "NRSEQCONTRATO"   => $nrseqcontrato,
            "NRTIPOORCAMENTO" => $escopos,
            "NRORG"           => $nrorg
        );
        
        $negociacoes = $this->contratoFactory->getNegociacaoProposta($params);
        foreach($negociacoes as $negocicao) {
            $nrnegociacaocontrato = $this->inserirDadosNegociacaoContrato($negocicao, $negocicao["NRPARCFATURA"], $nrorg, $cdoperador, $negocicao["NRNEGOCIACAOPROPOSTA"]);
            
            $params = array(
                "NRNEGOCIACAOPROPOSTA" => $negocicao["NRNEGOCIACAOPROPOSTA"],
                "NRSEQCONTRATO"        => $nrseqcontrato,
                "NRORG"                => $nrorg
            );
            $itens = $this->contratoFactory->getItensNegociacaoProposta($params);
            foreach($itens as $item) 
                $this->inserirItemNegociacaoContrato($item, $nrnegociacaocontrato, $item, $item["NRITNEGOCIACAOPROPOSTA"], $nrorg, $cdoperador);
            
            $params = array(
                "NRNEGOCIACAOPROPOSTA" => $negocicao["NRNEGOCIACAOPROPOSTA"],
                "NRORG"                => $nrorg
            );
            $competencias = $this->propostaService->getCompetenciaNegociacaoProposta($negocicao["NRNEGOCIACAOPROPOSTA"], $nrorg);
            foreach($competencias as $competencia) {
                $this->inserirCompetenciaNegociacaoContrato($competencia, $nrnegociacaocontrato, $nrorg, $cdoperador);
            }
            
            $descontosPorPeriodo = $this->propostaFactory->getDescontosPorPeriodoDaNegociacao($params);
            foreach($descontosPorPeriodo as $descontoPorPeriodo)
                $this->inserirDescontosPorPeriodo($descontoPorPeriodo, $nrnegociacaocontrato, $nrorg, $cdoperador);
            
            $parcelas = $this->propostaFactory->getParcelasNegociacao($params);
            foreach($parcelas as $parcela) {
                $nrparcelanegociacao = $this->newCode->getCodeByTableName("FCT_PARCELANEGOCONT", $nrorg, 1, 10, true);
                $params = array (
                    "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
                    "NRPARCELANEGOCONT"    => $nrparcelanegociacao,
                    "NRPARCELANEGOPROP"    => $parcela["NRPARCELANEGOPROP"],
                    "QTDIASFATURAMENTO"    => $parcela["QTDIASFATURAMENTO"],
                    "NRPARCELA"            => $parcela["NRPARCELA"],
                    "NRDIAVENCIMENTO"      => $parcela["NRDIAVENCIMENTO"],
                    "VRPARCELA"            => $parcela["VRPARCELA"],
                    "IDATIVO"              => "S",
                    "NRORG"                => $nrorg,
                    "NRORGINCLUSAO"        => $nrorg,
                    "CDOPERINCLUSAO"       => $cdoperador
                );
                $this->contratoFactory->inserirParcelaNegociacao($params);
            }
            
            $this->atualizarValoresNegociacaoContrato($nrnegociacaocontrato, $nrorg, $cdoperador);
        }
    }
    
    /**
     * Busca os elementos da proposta ligada ao contrato
     * e os insere na tabela de relacionamento entre contrato e elemento
    **/
    public function atualizarElementosContrato($nrseqcontrato, $nrseqorcamento, $nrorg) {
        $params = array (
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $elementos = $this->contratoFactory->getElementosProposta($params);
        $this->inserirElementosContrato($elementos, $nrseqcontrato);
    }
    /**
     * Busca as composição da proposta ligada ao contrato
     * e os insere na tabela de relacionamento entre contrato e composicao
    **/
    public function atualizarComposicaoContrato($nrseqcontrato, $nrseqorcamento, $nrorg) {
        $composicoes = $this->propostaService->getComposicoesProposta($nrseqorcamento, $nrorg);
        $this->inserirComposicoesContrato($composicoes, $nrseqcontrato);
    }
    /**
     * Busca os tipos de medida da proposta ligada ao contrato
     * e os insere na tabela de relacionamento entre contrato e medida
    **/
    public function atualizarTiposMedidasContrato($nrseqcontrato, $nrseqorcamento, $nrorg, $escopos) {
        $medidas = $this->propostaService->getVariacoesPrecoProposta($nrseqorcamento, $nrorg);
        
        $medidasescopo = array();
        foreach($medidas as $medida) {
            if($medida["NRTIPOORCAMENTO"] == $escopos) 
                array_push($medidasescopo, $medida);
        }
        
        $this->inserirTipoDeMedidaContrato($medidasescopo, $nrseqcontrato, $escopos);
    }
    /**
     * Busca os itens da proposta ligada ao contrato
     * e os insere na tabela de itens
    **/
    public function atualizarItensContratoProposta($nrseqcontrato, $nrseqorcamento, $nrorg, $escopos) {
        $params = array (
            "NRSEQORCAMENTO"  => $nrseqorcamento,
            "NRORG"           => $nrorg,
            "NRTIPOORCAMENTO" => $escopos
        );
        
        $itens    = $this->contratoFactory->getItensProposta($params, "IS NULL");
        $itensPai = $this->inserirItensContrato($itens, $nrseqcontrato, array());
        
        $itens = $this->contratoFactory->getItensProposta($params, "IS NOT NULL");
        $this->inserirItensContrato($itens, $nrseqcontrato, $itensPai);
    }
    /**
     * copia as informações das parcelas do contrato para a proposta
    **/
    public function replicarInformacoesParcelasParaProposta($nrnegociacaoproposta, $row) {
        $nrparcela = $this->newCode->getCodeByTableName("FCT_PARCELANEGOPROP", $row["NRORG"], 1, 10, true);
        $params    = array(
            "NRPARCELANEGOPROP"    => $nrparcela,
            "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
            "QTDIASFATURAMENTO"    => $row["QTDIASFATURAMENTO"],
            "NRPARCELA"            => $row["NRPARCELA"],
            "NRDIAVENCIMENTO"      => $row["NRDIAVENCIMENTO"],
            "VRPARCELA"            => $row["VRPARCELA"],
            "NRORG"                => $row["NRORG"],
            "NRORGINCLUSAO"        => $row["NRORGINCLUSAO"],
            "CDOPERINCLUSAO"       => $row["CDOPERINCLUSAO"],
            "IDATIVO"              => "S"
        );
        $this->propostaFactory->inserirParcelaNegociacao($params);
        return $nrparcela;
    }
    /**
     * valida a quantidade maxima de parcelas numa negociacao de valores
    **/
    public function validarQuantidadeMaxParcelas($nrtipoorcamento, $nrnegociacaocontrato, $cdoperador, $nrorg) {
        $params = array(
            "CDOPERADOR" => $cdoperador,
            "NRORG"      => $nrorg
        );
        
        $dataOperador = $this->contratoFactory->getQuantidadeMaxParcelasOper($params);
        if(count($dataOperador) == 0)
            $dataOperador = $this->contratoFactory->getQuantidadeMaxParcelasPerfil($params);
        
        if(count($dataOperador) > 0 && $dataOperador[0]["QTPARCMAXIMA"]) {
            return $dataOperador[0]["QTPARCMAXIMA"];
        } else {
            $params = array(
                "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
                "NRTIPOORCAMENTO"      => $nrtipoorcamento,
                "NRORG"                => $nrorg
            );
            $dataEscopo = $this->contratoFactory->getQtMaxParcelasItemEscopo($params);
            if(count($dataEscopo) == 0 || !$dataEscopo[0]["QTPARCELASFATU"]) {
                $params = array(
                    "NRTIPOORCAMENTO" => $nrtipoorcamento,
                    "NRORG"           => $nrorg
                );
                $dataEscopo = $this->contratoFactory->getQtMaxParcelasEscopo($params);
            }
            
            return $dataEscopo[0]["QTPARCELASFATU"];
        }
    }
    /**
     * Valida a quantidade de parcelas inseridas atualmente na negociação
    **/
    public function validarQuantidadeParcelasInseridas($nrnegociacaocontrato, $nrmaxparcelas, $nrorg) {
        $params = array(
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "NRORG"                => $nrorg
        );
        $parcelasInseridas = $this->contratoFactory->getParcelasNegociacao($params);
        if(count($parcelasInseridas) >= $nrmaxparcelas)
            return "LIMITE_PARC_INSERIDO" . " " . $nrmaxparcelas;
        else return (string) $nrmaxparcelas;
    }

    public function getEscopoContrato($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        
        $dataset = $this->contratoFactory->getEscopoContrato($params);
        return $dataset[0]["NRTIPOORCAMENTO"];
    }

    /**
     * Valida os elementos do contrato e se necessário desabilita-os no OM
    **/
    public function desabilitarProdutoNoOM($nrseqcontrato, $operador, $nrorgLogado) {
        try {
            $utilizaIntegracao = $this->integracaoOmService->verificarUtilizaIntegracao($nrorgLogado);
            $elementosP        = $this->getInformacoesContrato($nrseqcontrato, $nrorgLogado);
            $dadosRescisao     = $this->getDadosRescisaoContrato($nrseqcontrato, $nrorgLogado);
            
            if($utilizaIntegracao && count($elementosP) > 0) {
                $nrorgCliente = $this->getNrorgParceiroDeNegocio($elementosP[0]["NRPARCNEGOCIO"]);
                if(!$nrorgCliente) {
                    throw new \Exception("Falha ao desabilitar os elementos no OM.<br>Não foi encontrado a organização do parceiro de negócio deste contrato.");
                } else {
                    $produtos = array();
                    foreach($elementosP as $produto) {
                        $elementos  = array();
                        $elementosM = $this->getElementosParaDesabilitar($produto["IDELEMENTO"], $produto["NRPARCNEGOCIO"], $nrseqcontrato, $nrorgLogado);
                        
                        foreach($elementosM as $elemento) {
                            array_push($elementos, substr($elemento["IDELEMENTO"], strlen($produto["IDELEMENTO"]) + 3));
                        }
                        
                        array_push($produtos, array(
                            "NRPRODUTO" => substr($produto["IDELEMENTO"], strlen('P_')),
                            "ELEMENTOS" => $elementos
                        ));
                    }
                }
                
                if(count($produtos) > 0) {
                    $params = array(
                        "NRORG"                   => $nrorgCliente,
                        "PRODUTOS"                => $produtos,
                        "contractCode"            => $nrseqcontrato,
                        "rescissionDate"          => $dadosRescisao["DTRECISAOCONTR"],
                        "rescissionJustification" => $dadosRescisao["DSJUSTIFICAENCERRA"]
                    );
                    // $this->integracaoOmService->desabilitarElementosNoOm($params, $nrorgLogado);
                    return $params ;
                    // $result = $this->integracaoOmService->desabilitarElementosNoOm($params, $nrorgLogado);
                }
            }
            return array();
        } catch (\Exception $e) {
            $errorTrigger = strpos($e->getMessage(), "USR_BLOCK_DELETE_ELEMENTO_ORG");
            if($errorTrigger === false)
                throw $e;
            else 
                throw new \Exception("Operação bloqueda!<br><br>A Exclusão dos elementos por organização não é permitida. Favor entrar em contato com a Teknisa nos seguintes setores:<br><br> - Qualidade<br> - Controles");
        } 
    }
    
    public function reajustarParcelasNegociacao($nrseqcontrato, $nrnegociacaocontrato, $nrorg, $cdoperador) {
        $params = array(
            "NRSEQCONTRATO"        => $nrseqcontrato,
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "NRORG"                => $nrorg
        );
        $dataset = $this->contratoFactory->getValorNegociacaoComSomaParcelas($params);
        
        if (count($dataset) > 0) {
            $valorNegociacao = $dataset[0]["VRTOTITEMCOMDESC"];
            $somaParcelas = $dataset[0]["SOMA_PARCELAS"];
            if (!is_null($somaParcelas) && $valorNegociacao != $somaParcelas) {
                $diferenca = $valorNegociacao - $somaParcelas;
                $percentual = $diferenca / $somaParcelas * 100;

                $params = array(
                    "VRPERCENTUAL"         => $percentual,
                    "NRORGULTATU"          => $nrorg,
                    "CDOPERULTATU"         => $cdoperador,
                    "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
                    "NRORG"                => $nrorg
                );
                $this->contratoFactory->reajustarParcelasNegociacao($params);
            }
        }
    }

    /**
     * Busca os contratos aprovados ligados ao parceiro de negócio 
     * do contrato encerrado e os elementos nele contidos
    **/
    public function getInformacoesContrato($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        return $this->contratoFactory->getInformacoesContrato($params);
    }
    
    /**
     * Retorna o NRORG de um parceiro de negócio
    **/
    public function getNrorgParceiroDeNegocio($nrparcnegocio) {
        $params = array(
            "NRPARCNEGOCIO" => $nrparcnegocio
        );
        $dataset = $this->contratoFactory->getNrorgParceiroDeNegocio($params);
        return count($dataset) > 0 ? $dataset[0]["NRORG"] : null;
    }
    /**
     * Valida os elementos que serão desabilitados no OM
    **/
    public function getElementosParaDesabilitar($elementoP, $nrparcnegocio, $nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "IDELEMENTOPAI" => $elementoP,
            "NRORG"         => $nrorg,
            "NRPARCNEGOCIO" => $nrparcnegocio
        );
        return $this->contratoFactory->getElementosParaDesabilitar($params);
    }

    /**
     * Atualiza o valor de todas as negociaçções de valores da proposta com a soma do itens.
     * 
     * @param integer $nrseqcontrato
     * @param integer $nrorg
     * @param string  $cdoperador
    **/
    public function atualizarValorTodasNegociacoesComSomaDosItens($nrseqcontrato, $nrorg, $cdoperador) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        
        $negociacoes = $this->contratoFactory->getNegociacoesContrato($params);
        foreach ($negociacoes as $nego) {
            $this->atualizarValoresNegociacaoContrato($nego["NRNEGOCIACAOCONTRATO"], $nrorg, $cdoperador);
        }
    }

    public function atualizarValoresNegociacaoAoEditarItemSemComposicao($nritemocontrato, $vrtotitemcont, $localAtendNovo, $localAtendAntigo, $dsLoteFaturaNovo, $dsLoteFaturaAntigo) {
        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        
        $this->connection->beginTransaction();
        try {
            $params = array(
                "NRITEMOCONTRATO" => $nritemocontrato,
                "NRORG"           => $nrorg
            );
            $item = $this->contratoFactory->getDadosItemContratoParaNegociacaoValores($params);
            $item = $item[0];
            
            $dadosContrato = $this->getDadosContrato($item["NRSEQCONTRATO"], $nrorg);
            //$geraParcelasSeparadasPorLocal = $dadosContrato["IDGERARATEIO"];
            $agrupamentoParcelas = $dadosContrato["IDAGRUPPARC"];
            
            if ($agrupamentoParcelas != "1" && (($localAtendAntigo != $localAtendNovo) or ($dsLoteFaturaNovo != $dsLoteFaturaAntigo))) {
                
                if ($localAtendNovo == "") $localAtendNovo = null;

                if (($localAtendNovo != null) && (($agrupamentoParcelas == '4') or ($agrupamentoParcelas == '5'))){

                    $params = array(
                        "NRESTRUTURAM" => $localAtendNovo
                    );

                    $tipoLocalAtend = $this->contratoFactory->getTipoLocalAtend($params);
                }
                else {

                    $tipoLocalAtend = null;

                }
                
                $cdpaisfat = $sgestadofat = $cdmunicipiofat = null;
                $enderecoFaturamento = $this->getEnderecoFaturamento($localAtendNovo, $item["NRPARCFATURA"], $nrorg);
                if (!empty($enderecoFaturamento)) {
                    $cdpaisfat      = $enderecoFaturamento["CDPAIS"];
                    $sgestadofat    = $enderecoFaturamento["SGESTADO"];
                    $cdmunicipiofat = $enderecoFaturamento["CDMUNICIPIO"];
                }
                
                $nrnegociacaocontratoVelho = null;
                $params = array(
                    "NRITEMOCONTRATO" => $nritemocontrato,
                    "NRORG"           => $nrorg
                );
                $dataset = $this->contratoFactory->getCodigoNegociacaoDoItem($params);
                if (count($dataset) > 0) {
                    $nrnegociacaocontratoVelho = $dataset[0]["NRNEGOCIACAOCONTRATO"];
                }

                // Busca se já existe uma negociação inserida no contrato com os mesmos parâmetros de faturamento do item.
                // Se já existe, o item será movido para ela.
                // Se não existe, insere uma nova negociação para depois mover o item.
                $nrnegociacaocontrato = $this->getNegociacaoContratoPorParametrosFaturamento($item["NRSEQCONTRATO"], $nrorg, $item["NRTIPOORCAMENTO"], $item["IDTPFATURA"], $item["CDFILIALFATURA"], $item["NRPARCFATURA"], $item["CDTIPOOPERFATURA"], $item["CDSERIENF"], $item["CDEMPRESA"], $item["CDINSCESTA"], $item["CDINSCMUNI"], $agrupamentoParcelas, $item["IDPREVCOBRFUT"], $localAtendNovo, $item["CDTRIBPRODPADR"], $cdpaisfat, $sgestadofat, $cdmunicipiofat, $item["IDNATUOPER"], $tipoLocalAtend, $dsLoteFaturaNovo);
                
                if (is_null($nrnegociacaocontrato)) {
                    $nrnegociacaocontrato = $this->newCode->getCodeByTableName("FCT_NEGOCIACAOCONTRATO", $nrorg, 1, 10, true);
                    $params = array(
                        "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
                        "NRSEQCONTRATO"        => $item["NRSEQCONTRATO"],
                        "NRTIPOORCAMENTO"      => $item["NRTIPOORCAMENTO"],
                        "IDTPFATURA"           => $item["IDTPFATURA"],
                        "CDFILIALFATURA"       => $item["CDFILIALFATURA"],
                        "NRPARCFATURA"         => $item["NRPARCFATURA"],
                        "CDTIPOOPERFATURA"     => $item["CDTIPOOPERFATURA"],
                        "CDSERIENF"            => $item["CDSERIENF"],
                        "CDEMPRESA"            => $item["CDEMPRESA"],
                        "CDINSCESTA"           => $item["CDINSCESTA"],
                        "CDINSCMUNI"           => $item["CDINSCMUNI"],
                        "VRTOTITEM"            => $item["VRTOTITEMCONT"],
                        "VRPERCDESCITEM"       => null,
                        "VRDESCITEM"           => null,
                        "VRTOTITEMCOMDESC"     => $item["VRTOTITEMCONT"],
                        "IDATIVO"              => "S",
                        "NRORG"                => $nrorg,
                        "NRORGINCLUSAO"        => $nrorg,
                        "CDOPERINCLUSAO"       => $cdoperador,
                        "NRNEGOCIACAOPROPOSTA" => null,
                        "NRESTRUTURAM"         => $localAtendNovo,
                        "IDPREVCOBRFUT"        => $item["IDPREVCOBRFUT"],
                        "CDTRIBPRODPADR"       => $item["CDTRIBPRODPADR"],
                        "CDPAISFAT"            => $cdpaisfat,
                        "SGESTADOFAT"          => $sgestadofat,
                        "CDMUNICIPIOFAT"       => $cdmunicipiofat,
                        "IDNATUOPER"           => $item["IDNATUOPER"],
                        "NRTIPOESTRUTURA"      => $tipoLocalAtend,
                        "DSLOTEFATURAMENTO"    => $dsLoteFaturaNovo
                    );
                    $this->contratoFactory->inserirNegociacaoContrato($params);
                    
                    if ($item["IDTPFATURA"] != "P") {
                        $params = array(
                            "NRTIPOORCAMENTO" => $item["NRTIPOORCAMENTO"],
                            "CDSERVORCA"      => $item["CDSERVORCA"],
                            "NRORG"           => $nrorg
                        );
                        $competencia = $this->propostaFactory->getCompetenciaItemNegociacao($params);
                        
                        foreach ($competencia as $comp) {
                            $this->inserirCompetenciaNegociacaoContrato($comp, $nrnegociacaocontrato, $nrorg, $cdoperador);
                        }
                    }
                }
                
                $params = array(
                    "NRNEGOCIACAOCONTRATO"   => $nrnegociacaocontrato,
                    "NRITNEGOCIACAOCONTRATO" => $item["NRITNEGOCIACAOCONTRATO"],
                    "NRORG"                  => $nrorg
                );
                $this->contratoFactory->atualizarCodNegociacaoDoItemContrato($params);
                
                if ($nrnegociacaocontratoVelho) {
                    $this->atualizarValoresNegociacaoContrato($nrnegociacaocontratoVelho, $nrorg, $cdoperador);
                }
            }
            
            $this->recalcularItemNegociacaoContrato($nritemocontrato, $vrtotitemcont, $cdoperador, $nrorg);
            
            $this->connection->commit();
        }
        catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
    
    public function recalcularItemNegociacaoContrato($nritemocontrato, $vrtotitemcont, $cdoperador, $nrorg) {
        $params = array(
            "NRITEMOCONTRATO" => $nritemocontrato,
            "NRORG"           => $nrorg
        );
        $dataset = $this->contratoFactory->getCodigoNegociacaoDoItem($params);
        if (count($dataset) > 0) {
            $nrnegociacaocontrato = $dataset[0]["NRNEGOCIACAOCONTRATO"];
        
            $params = array(
                "VRTOTITEM"            => $vrtotitemcont,
                "CDOPERULTATU"         => $cdoperador,
                "NRORGULTATU"          => $nrorg,
                "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
                "NRITEMOCONTRATO"      => $nritemocontrato,
                "NRORG"                => $nrorg
            );
            $this->contratoFactory->atualizarValorItemNegociacao($params);

            // Atualiza o valor da negociacao de valores com a soma dos itens
            $this->atualizarValoresNegociacaoContrato($nrnegociacaocontrato, $nrorg, $cdoperador);
        }
    }
    
    public function getValorVariacoesPrecoContrato($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        
        $resultado = $this->contratoFactory->getValorVariacoesPrecoContrato($params);
        return $resultado[0]["QTMEDIDAS"];
    }
    
    /* Valida se foi realizado reajuste dos valores do contrato antes de regerar as parcelas de faturamento e/ou alterar a vig\ência do contrato */
    public function validaReajuste($nrseqcontrato, $dtinicio, $dtfinal, $nrorg) {
       
       /* Trecho comentato pegava o valor do menmônico para definir se deveria ter a trava de reajsute de contrato, o mesmo foi substituido pelo campo na prarametrização sm.
       
       $validaReajuste = $this->validaReajusteFatu;
        
       if ($validaReajuste == true){ */
       
       $params = array(
                "NRORG"  => $nrorg
            );
            
        $validaReajuste = $this->contratoFactory->validaReajusteFatu($params);
        
        if ($validaReajuste[0]['IDBLOQAPURFATSEMREAJ'] == 'S'){
           
            $params = array(
                "NRSEQCONTRATO" => $nrseqcontrato,
                "NRORG"         => $nrorg
            );
            
            $resultado = $this->contratoFactory->getDatasContr($params);
            
            $dtiniciocontrato = $resultado[0]["DTINICIOCONTRATO"];
            $dtfimcontrato = $resultado[0]["DTFIMCONTRATO"];
            $dtinivigencont = $resultado[0]["DTINIVIGENCONT"];
            $dtfinvigencont = $resultado[0]["DTFINVIGENCONT"];
           
           if (($dtinicio != null) && ($dtfinal != null)){
               
                $dtinivigencont = $dtinicio;
                $dtfinvigencont = $dtfinal;
               
           };
           
           
            if (($dtinivigencont == null) && ($dtfinvigencont == null)) {
                
               $retorno = array();  
            } 
            else {
              
                if (($dtinivigencont == $dtiniciocontrato) && ($dtfinvigencont == $dtfimcontrato)) {
                
                    $retorno = array();
                }
                else {
                 
                    $params = array(
                        "NRSEQCONTRATO" => $nrseqcontrato,
                        "DTINICIO"      => $dtinivigencont,
                        "DTFINAL"       => $dtfinvigencont,
                        "NRORG"         => $nrorg
                    );
                    
                    $retorno = $this->contratoFactory->validaReajuste($params); 
                }
            }
        }
        else{
           
           $retorno = array(); 
        }
        
        return $retorno;
    }
    
    public function excluirParcelasNegociacao($nrnegociacaocontrato, $nrorg) {
        $params = array(
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "NRORG"                => $nrorg
        );
        
        $this->contratoFactory->excluirParcelasNegociacao($params);
    }
    
    public function validarParametrosFaturamentoCont($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        
        $negociacoes = $this->contratoFactory->getParametrosFaturaNegociacoesContrato($params);
        foreach($negociacoes as $negociacao) {
            if ($negociacao["CDFILIALFATURA"] == null)
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Unidade para Faturamento" não foi encontrado para este contrato. Favor conferir a parametrização de faturamento do Escopo.');
            
            if ($negociacao["CDTIPOOPERFATURA"] == null)
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Tipo de Operação da Nota Fiscal" não foi encontrado para este contrato. Favor conferir a parametrização de faturamento do Escopo.');
            
            if ($negociacao["CDSERIENF"] == null)
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Série da Nota Fiscal" não foi encontrado para este contrato. Favor conferir a parametrização de faturamento do Escopo.');
            
            /*if ($negociacao["QTPRODFATURA"] > 0)
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Produto para Faturamento" não foi encontrado para este contrato. Favor conferir a parametrização de faturamento do Escopo ou do Serviço.');
            */
            
            if(in_array($negociacao["IDTPFATURA"], array("A", "X"))) {
                $params = array(
                    "NRNEGOCIACAOCONTRATO" => $negociacao["NRNEGOCIACAOCONTRATO"],
                    "NRORG"                => $nrorg
                );
                $competencia = $this->contratoFactory->getCompetenciaNegociacaoContrato($params);
                if(count($competencia) == 0)
                    throw new \Exception('Operação bloqueada. <br/><br/>O período de competência não foi encontrado para este contrato. Favor conferir a parametrização de faturamento do Escopo ou do Serviço.');
            }
        }
    }
    
    /**
     * valida se existe descontos e acrescimos no contrato
    **/
    public function getDescontosContrato($nrseqcontrato, $nrorg) {
        $descontoNegociacao = array();
        $descontoPorPeriodo = array();
        
        $params = array(
            "NRSEQCONTRATO"  => $nrseqcontrato,
            "NRORG"          => $nrorg
        );
        
        $negociacoes = $this->contratoFactory->getNegociacoesContrato($params);
        foreach($negociacoes as $negociacao) {
            $params = array(
                "NRNEGOCIACAOCONTRATO" => $negociacao["NRNEGOCIACAOCONTRATO"],
                "NRORG"                => $nrorg
            );
            
            $descPorperiodo = $this->contratoFactory->getDescontosPorPeriodoDaNegociacao($params);
            $descNegociacao = $this->contratoFactory->getDescontosNegociacaoValores($params);
            
            if(count($descPorperiodo) > 0) $descontoPorPeriodo = array_merge($descontoPorPeriodo, $descPorperiodo);
            if(count($descNegociacao) > 0) $descontoNegociacao = array_merge($descontoNegociacao, $descNegociacao);
        }
        
        $descontos = array(
            "PORPERIODO" => $descontoPorPeriodo,
            "NEGOCIACAO" => $descontoNegociacao
        );
        
        return (count($descontoPorPeriodo) > 0 || count($descontoNegociacao) > 0) ? $descontos : array();
    }
    
    /**
     * Insere descontos por perído para um contrato
    **/
    public function inserirDescontosPorPeriodo($descontos, $nrnegociacaocontrato, $nrorg, $cdoperador) {
        $nrdescontoporperiodo = $this->newCode->getCodeByTableName("FCT_DESCPERIODONEGOCONT", $nrorg, 1, 10, true);
        $params = array(
            "NRDESCPERIODONEGOCONT" => $nrdescontoporperiodo,
            "NRNEGOCIACAOCONTRATO"  => $nrnegociacaocontrato,
            "IDATIVO"               => 'S',
            "NRORG"                 => $nrorg,
            "VRPERCDESCITEM"        => $descontos["VRPERCDESCITEM"],
            "VRDESCITEM"            => $descontos["VRDESCITEM"],
            "VRTOTITEMCOMDESC"      => $descontos["VRTOTITEMCOMDESC"],
            "QTMESESDESC"           => $descontos["QTMESESDESC"],
            "DTFINALVALIDADEDESC"   => $descontos["DTFINALVALIDADEDESC"],
            "DTINCLUSAO"            => $descontos["DTINCLUSAO"],
            "NRORGINCLUSAO"         => $descontos["NRORGINCLUSAO"],
            "CDOPERINCLUSAO"        => $descontos["CDOPERINCLUSAO"],
            "DTULTATU"              => $descontos["DTULTATU"],
            "NRORGULTATU"           => $descontos["NRORGULTATU"],
            "CDOPERULTATU"          => $descontos["CDOPERULTATU"],
            "NRORDEMAPLICADESC"     => $descontos["NRORDEMAPLICADESC"]
        );
        $this->contratoFactory->inserirDescontoPorPeriodo($params);
    }
    
    /**
     * Atualiza os acrescimos e descontos dados no contrato
     * antes das atualizações dos itens e medidas
    **/
    public function atualizarDescontosAcrescimosContrato($itensContrato, $descontosContrato, $nrseqcontrato, $nrorg, $negociacoes, $alteraMedida, $idSituacao, $parcelas) {
        foreach($itensContrato as $item) {
            $novoItem             = $this->getNovoItemCorrespondente($item["IDELEMENTO"], $item["CDSERVORCA"], $item["CDTPMEDIDAVARIAVEL"], $nrseqcontrato, $nrorg);
            $nrnewitemcontrato    = $novoItem["NRITEMOCONTRATO"];
            $nrnewitemcontratopai = $novoItem["NRITEMCONTRATOPAI"];
            
            if($item["IDELEMENTO"]) {
                if(!empty($novoItem)) {
                    $qtmedidacont   = (!$alteraMedida) ?  $item["QTMEDIDACONTR"] : $novoItem["QTMEDIDACALCULADA"];
                    $dadosTblPreco  = $this->getIdMultiplicavariacaoItem($item["CDSERVORCA"], $item["CDTPMEDIDASERV"], $item["CDTPMEDIDAVARIAVEL"], $qtmedidacont, $nrorg);
                    
                    $vrtblpreco = $dadosTblPreco["VRPRECOVARIACAO"];
                    if($dadosTblPreco["IDMULTIPVARIACAO"] == "S") $vrtblpreco *= $this->getSomatorioMedidaServico($item["CDSERVORCA"], $item["IDELEMENTO"], $nrseqcontrato, $nrorg); 
                    
                    $vrunititem = $item["VRUNITITEMCONT"];
                    $vrtotalitemcont = ($dadosTblPreco == 'N') ? $vrunititem : $vrunititem * $qtmedidacont;
                    $params = array(
                        "NRORG"                  => $nrorg,
                        "NRITEMOCONTRATO"        => $nrnewitemcontrato,
                        "QTMEDIDACONTR"          => $qtmedidacont,
                        "VRUNITITEMCONTTBLPRECO" => $vrtblpreco,
                        "VRUNITITEMCONT"         => $vrunititem,
                        "VRTOTITEMCONT"          => $vrtotalitemcont
                    );
                    
                    $this->contratoFactory->atualizarValorItensOrcamento($params);
                    
                    $params = array (
                        "NRSEQCONTRATO"  => $nrseqcontrato,
                        "CDSERVORCA"     => $item["CDSERVORCA"],
                        "NRORG"          => $nrorg
                    );
                    $this->contratoFactory->atualizarValorItemPai($params);
                    $this->atualizarValorItensNegociacaoValores($nrseqcontrato, $nrnewitemcontrato, $vrtotalitemcont, $nrnewitemcontratopai, $nrorg, $item["CDOPERINCLUSAO"]);
                }    
            }

            if(count($descontosContrato) > 0) {
                foreach($descontosContrato["NEGOCIACAO"] as &$desconto) {
                    if($desconto["TIPODESCONTO"] == "ITENS" && $desconto["NRITEMOCONTRATO"] == $item["NRITEMOCONTRATO"]) {
                        if($nrnewitemcontrato) $desconto["NRITEMOCONTRATO"] = $nrnewitemcontrato; 
                        else unset($desconto);
                    }
                }
            }
        }

        if(count($descontosContrato) > 0) {
            foreach($negociacoes as $negociacao) {
                $params = array(
                    "NRSEQCONTRATO"    => $nrseqcontrato,
                    "IDTPFATURA"       => $negociacao["IDTPFATURA"],
                    "CDSERIENF"        => $negociacao["CDSERIENF"],
                    "CDTIPOOPERFATURA" => $negociacao["CDTIPOOPERFATURA"],
                    "CDFILIALFATURA"   => $negociacao["CDFILIALFATURA"],
                    "NRORG"            => $nrorg
                );
                
                $newnegociacao = $this->contratoFactory->getNovaNegociacaoCorrespondente($params);
                foreach($descontosContrato as $key=>$descontos) {
                    foreach($descontos as $row) {
                        if($row["NRNEGOCIACAOCONTRATO"] == $negociacao["NRNEGOCIACAOCONTRATO"]) {
                            if(count($newnegociacao) < 1) {
                                unset($row);
                            } else { 
                                if($key != "PORPERIODO") {
                                    $vrpercdesc = $row["VRPERCDESCITEM"];
                                    $vrdesconto = $row["VRDESCITEM"];
                                
                                    $sqlAux = "VRPERCDESCITEM   = $vrpercdesc,
                                               VRDESCITEM       = VRTOTITEM * $vrpercdesc / 100,
                                               IDTPDESCONTO     = '" . $row['IDTPDESCONTO'] . "',
                                               VRTOTITEMCOMDESC = VRTOTITEM - (VRTOTITEM * $vrpercdesc / 100)";
                                    
                                    if($row["TIPODESCONTO"] == "ITENS") {
                                        $params = array(
                                            "NRNEGOCIACAOCONTRATO" => $newnegociacao[0]["NRNEGOCIACAOCONTRATO"],
                                            "NRITEMOCONTRATO"      => $row["NRITEMOCONTRATO"],
                                            "NRORG"                => $nrorg
                                        );
                                        $this->contratoFactory->atualizarItensNegociaco($params, $sqlAux);
                                    } else {
                                        $params = array(
                                            "NRNEGOCIACAOCONTRATO" => $newnegociacao[0]["NRNEGOCIACAOCONTRATO"],
                                            "NRORG"                => $nrorg
                                        );
                                        $this->contratoFactory->atualizarNegociaco($params, $sqlAux);
                                    }
                                } else {
                                    $nrdescontoporperiodo = $this->newCode->getCodeByTableName("FCT_DESCPERIODONEGOCONT", $nrorg, 1, 10, true);
                                    $vrdescitem = $newnegociacao[0]["VRTOTITEMCOMDESC"] * $row["VRPERCDESCITEM"] / 100;
                                    $vrpercdesc = $row["VRPERCDESCITEM"];
                                    $params = array(
                                        "NRDESCPERIODONEGOCONT" => $nrdescontoporperiodo,
                                        "IDATIVO"               => 'S',
                                        "NRORG"                 => $nrorg,
                                        "VRPERCDESCITEM"        => $vrpercdesc,
                                        "VRDESCITEM"            => $vrdescitem,
                                        "VRTOTITEMCOMDESC"      => $newnegociacao[0]["VRTOTITEMCOMDESC"] - $vrdescitem,
                                        "NRNEGOCIACAOCONTRATO"  => $newnegociacao[0]["NRNEGOCIACAOCONTRATO"],
                                        "QTMESESDESC"           => $row["QTMESESDESC"],
                                        "DTFINALVALIDADEDESC"   => $row["DTFINALVALIDADEDESC"],
                                        "DTINCLUSAO"            => $row["DTINCLUSAO"],
                                        "NRORGINCLUSAO"         => $row["NRORGINCLUSAO"],
                                        "CDOPERINCLUSAO"        => $row["CDOPERINCLUSAO"],
                                        "DTULTATU"              => $row["DTULTATU"],
                                        "NRORGULTATU"           => $row["NRORGULTATU"],
                                        "CDOPERULTATU"          => $row["CDOPERULTATU"],
                                        "NRORDEMAPLICADESC"     => $row["NRORDEMAPLICADESC"],
                                        "IDTPDESCONTO"          => $row["IDTPDESCONTO"]
                                    );
                                    $this->contratoFactory->inserirDescontoPorPeriodo($params);
                                }
                            }
                        }
                    }
                }
            }
        }
    }
    
    /**
     * Retorna o nritemocontrato de um item segundo as informações do elemento, serviço e medida
    **/
    public function getNovoItemCorrespondente($idelemento, $cdservorca, $cdtpmedida, $nrseqcontrato, $nrorg){
        $params = array(
            "IDELEMENTO"         => $idelemento, 
            "CDSERVORCA"         => $cdservorca, 
            "CDTPMEDIDAVARIAVEL" => $cdtpmedida,
            "NRSEQCONTRATO"      => $nrseqcontrato, 
            "NRORG"              => $nrorg
        );
        
        $item = $this->contratoFactory->getNovoItemCorrespondente($params);
        return count($item) > 0 ? $item[0] : null;
    }
    
    /**
     * Retorna os dados da tabela de preço ligados a medida de um serviço 
    **/
    public function getIdMultiplicavariacaoItem($cdservorca, $cdtpmedidaserv, $cdtpmedidavariavel, $qtmedidacont, $nrorg) {
        $params = array(
            "CDTPMEDIDASERV"     => $cdtpmedidaserv,
            "CDTPMEDIDAVARIAVEL" => $cdtpmedidavariavel,
            "QTMEDIDACONTR"      => $qtmedidacont,
            "CDSERVORCA"         => $cdservorca, 
            "NRORG"              => $nrorg
        );
        $dadosTblPreco = $this->contratoFactory->getIdMultiplicavariacaoItem($params);
        return count($dadosTblPreco) > 0 ? $dadosTblPreco[0] : null; 
    }
    
    /**
     * Retorna o somatório da quantidade de medida do serviço de um elemento do contrato
    **/
    public function getSomatorioMedidaServico($cdservorca, $idelemento, $nrseqcontrato, $nrorg) {
        $params = array(
            /*"IDELEMENTO"         => $idelemento, 
            "CDSERVORCA"         => $cdservorca, 
            "NRSEQCONTRATO"      => $nrseqcontrato, 
            "NRORG"              => $nrorg*/
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg,
            "IDELEMENTO"    => $idelemento,
            "CDSERVORCA"    => $cdservorca
        );
        
        $medidaservico = $this->contratoFactory->getSomatorioMedidaServico($params);
        return count($medidaservico) > 0 ? $medidaservico[0]["QTMEDIDASERV"] : null;
    }
    
    /**
     * Atualiza o valor dos itens da negociacao
    **/
    public function atualizarValorItensNegociacaoValores($nrseqcontrato, $nritemcontrato, $vrtotalitemcont, $nritemcontratopai, $nrorg, $cdoperador) {
        $params = array(
            "NRITEMOCONTRATO" => $nritemcontrato,
            "NRORG"           => $nrorg
        );
        $dataset = $this->contratoFactory->getCodigoNegociacaoDoItem($params);
        $nrnegociacaocontrato = $dataset[0]["NRNEGOCIACAOCONTRATO"];
        $params = array(
            "VRTOTITEM"            => $vrtotalitemcont,
            "CDOPERULTATU"         => $cdoperador,
            "NRORGULTATU"          => $nrorg,
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "NRITEMOCONTRATO"      => $nritemcontrato,
            "NRORG"                => $nrorg
        );
        $this->contratoFactory->atualizarValorItemNegociacao($params);

        //1- retorna a soma do valor dos elementos filhos do item
        $params = array(
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "NRITEMOCONTRATO"      => $nritemcontratopai,
            "NRORG"                => $nrorg
        );
        $dataset = $this->contratoFactory->getSomaValorElementosItemNegociacao($params);
        $somaValoresItem = (float)$dataset[0]["VRTOTAL"];

        //2- atualiza o item pai com a soma dos filhos
        $params = array(
            "VRTOTITEM"            => $somaValoresItem,
            "CDOPERULTATU"         => $cdoperador,
            "NRORGULTATU"          => $nrorg,
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "NRITEMOCONTRATO"      => $nritemcontratopai,
            "NRORG"                => $nrorg
        );
        $this->contratoFactory->atualizarValorItemNegociacao($params);
        
        //3- atualiza o valor das negociacoes com a soma dos itens pai
        $this->atualizarValorTodasNegociacoesComSomaDosItens($nrseqcontrato, $nrorg, $cdoperador);
    }
    
    /**
     * Verifica se não houve alteração no valor das parcelas
    **/
    public function atualizarParcelasContrato($negociacoes, $nrseqcontrato, $parcelas, $nrorg) {

        foreach($negociacoes as $negociacao) {

            $params = array(
                "NRSEQCONTRATO"    => $nrseqcontrato,
                "IDTPFATURA"       => $negociacao["IDTPFATURA"],
                "CDSERIENF"        => $negociacao["CDSERIENF"],
                "CDTIPOOPERFATURA" => $negociacao["CDTIPOOPERFATURA"],
                "CDFILIALFATURA"   => $negociacao["CDFILIALFATURA"],
                "NRORG"            => $nrorg
            );
            
            $newnegociacao = $this->contratoFactory->getNovaNegociacaoCorrespondente($params);

            if (count($newnegociacao) > 0) {
                if($negociacao["SOMA_PARCELAS"] == $newnegociacao[0]["VRTOTITEMCOMDESC"]) {
                    foreach($parcelas as $parcela) {
                        if($parcela["NRNEGOCIACAOCONTRATO"] == $negociacao["NRNEGOCIACAOCONTRATO"]) {
                            $nrparcelanegocont = $this->newCode->getCodeByTableName("FCT_PARCELANEGOCONT", $nrorg, 1, 10, true);
                            $params = array(
                                "NRPARCELANEGOCONT"    => $nrparcelanegocont,
                                "IDATIVO"              => "S",
                                "NRNEGOCIACAOCONTRATO" => $newnegociacao[0]["NRNEGOCIACAOCONTRATO"],
                                "QTDIASFATURAMENTO"    => $parcela["QTDIASFATURAMENTO"],
                                "NRPARCELA"            => $parcela["NRPARCELA"],
                                "NRDIAVENCIMENTO"      => $parcela["NRDIAVENCIMENTO"],
                                "VRPARCELA"            => $parcela["VRPARCELA"],
                                "NRORG"                => $parcela["NRORG"],
                                "NRORGINCLUSAO"        => $parcela["NRORGINCLUSAO"],
                                "CDOPERINCLUSAO"       => $parcela["CDOPERINCLUSAO"],
                                "NRPARCELANEGOPROP"    => null 
                            );
                            
                            $this->contratoFactory->inserirParcelaNegociacao($params);
                        }
                    }
                }
            }
        }
    }
    
     /**
     * A função "completaPercentual" verifica qual o percentual faltante para inserção na página "índices Financeiros Padrões"
     */
    
    public function completaPercentual($nrseqcontrato, $nrorg){
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg,
            "CDINDICE"      => null
        );
        
        $valida = $this->contratoFactory->validaPercentual($params);
        if (!empty($valida[0])){
           $result = 100 - $valida[0]["TOTPERCENT"];
        } else {
           $result =  100; 
        }
        
        return $result;
    }
    
    
     /**
     * A função "validaPercentual" valida o percentual para inserção na página "índices Financeiros Padrões"
     */
    
    public function validaPercentual($nrpercentindice, $nrseqcontrato, $nrorg, $cdindice = null){
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg,
            "CDINDICE"      => $cdindice
        );
        
        $valida = $this->contratoFactory->validaPercentual($params);
        if (!empty($valida[0])){
           $result = $valida[0]["TOTPERCENT"] + $nrpercentindice;
        } else {
           $result =  $nrpercentindice; 
        }
        
        return $result;
    }
    
    
     /**
     * A função "insereIndicesPadroes" insere os indices padrões que já estiverem preenchidos para o Parceiro de negócio ou para o escopo de faturamento, com prioridade para o parceiro de negócio.
     */
    public function insereIndicesPadroes($nrtipoorcamento, $nrparcnegocio, $nrseqcontrato, $nrorg, $operador){
        
        $params = array(
            "NRPARCNEGOCIO" => $nrparcnegocio,
            "NRORG" => $nrorg
        );
        
        $indicesParcNegocio = $this->contratoFactory->indicesParcNegocio($params);
        
        if (!empty($indicesParcNegocio)){
            
            foreach($indicesParcNegocio as $indice){
                
                $novoCodigo = $this->newCode->getCodeByTableName("FCT_INDICESPADRCONTR", $nrorg, 1, 10, true);
                $params = array(
                    "NRINDICESPADRCONTR" => $novoCodigo,
                    "NRSEQCONTRATO"      => $nrseqcontrato,
                    "CDTPINDICE"         => $indice["CDTPINDICE"],
                    "IDPERVALOR"         => $indice["IDPERVALOR"],
                    "CDINDICE"           => $indice["CDINDICE"],
                    "NRPERCENTINDICE"    => $indice["NRPERCENTINDICE"],
                    "NRORG"              => $nrorg,
                    "OPERADOR"           => $operador
                );
                
                $this->contratoFactory->insereIndicesPadroes($params);
                
            }   
            
        }
        else{
           
            $params = array(
                "NRTIPOORCAMENTO" => $nrtipoorcamento,
                "NRORG" => $nrorg
            );
            
            $indicesEscopo = $this->contratoFactory->indicesEscopo($params);
            
            if (!empty($indicesEscopo)){
            
                $novoCodigo = $this->newCode->getCodeByTableName("FCT_INDICESPADRCONTR", $nrorg, 1, 10, true);
            
                foreach($indicesEscopo as $indice){
                    
                    $params = array(
                        "NRINDICESPADRCONTR" => $novoCodigo,
                        "NRSEQCONTRATO"      => $nrseqcontrato,
                        "CDTPINDICE"         => $indice["CDTPINDICE"],
                        "IDPERVALOR"         => $indice["IDPERVALOR"],
                        "CDINDICE"           => $indice["CDINDICE"],
                        "NRPERCENTINDICE"    => $indice["NRPERCENTINDICE"],
                        "NRORG"              => $nrorg,
                        "OPERADOR"           => $operador
                    );
                    
                    $this->contratoFactory->insereIndicesPadroes($params);
            
                }
            }
        }
    }
    
    /**
     * Valida se há contratos reajustados automaticamente ou contratos vencidos para uma 
     * determinada data
     */
    public function validarExistenciaRenovacaoAutomatica($dataReferencia, $nrorg) {
        $params = array(
            "DTREFERENCIA" => $dataReferencia,
            "NRORG"        => $nrorg
        );
        
        $contratosvencidos = $this->contratoFactory->validarExistenciaRenovacaoAutomatica($params);
        return (count($contratosvencidos) > 0);
    }
    
    public function atualizarMedidasServicos($nrseqcontrato, $nrseqorcamento, $nrorg, $escopos, $cdoperador) {
        $params = array(
            "NRSEQORCAMENTO"  => $nrseqorcamento,
            "NRTIPOORCAMENTO" => $escopos,
            "NRORG"           => $nrorg
        );
        
        $medidas = $this->contratoFactory->getMedidasVariaveisDosServicosProposta($params);
        foreach($medidas as $medida) {
            $medida["NRSEQCONTRATO"]   = $nrseqcontrato; 
            $medida["NRTIPOORCAMENTO"] = $escopos; 
            $this->inserirOuAtualizarMedidaVariavelServico($medida, $nrorg, $cdoperador);
        }
    }
    
    public function inserirOuAtualizarMedidaVariavelServico($row, $nrorg, $cdoperador, $somenteAtualizar = false) {
        $nrestruturam = isset($row["NRESTRUTURAM"]) ? $row["NRESTRUTURAM"] : null;
        $item = isset($row["NRITEMOCONTRATO"]) ? $row["NRITEMOCONTRATO"] : null;
        $params = array (
            "NRSEQCONTRATO"      => $row["NRSEQCONTRATO"],
            "CDTPMEDIDAVARIAVEL" => $row["CDTPMEDIDAVARIAVEL"],
            "CDSERVORCA"         => $row["CDSERVORCA"],
            "NRORG"              => $nrorg,
            "NRESTRUTURAM"       => $nrestruturam,
            "NRITEMOCONTRATO"    => $item
        );
        
        $dataset = $this->contratoFactory->getMedidaVariavelServicoContrato($params);
        if (count($dataset) > 0) {
            $nrmedidacontrato = $dataset[0]["NRMEDIDACONTRATO"];
            $qtmedidavariavel = $row["QTMEDIDACONTR"];
            
            $this->atualizarMedidaVariavelServico($nrmedidacontrato, $qtmedidavariavel, $cdoperador, $nrorg, $nrestruturam, $item);
        }
        else if ($somenteAtualizar == false) {
            $this->inserirMedidaVariavelServico($row, $nrorg, $cdoperador, $nrestruturam, $item);
        }
    }
    
    private function atualizarMedidaVariavelServico($nrmedidacontrato, $qtmedidavariavel, $cdoperador, $nrorg, $nrestruturam = null, $item = null) {
        $params = array(
            "QTMEDIDAVARIAVEL" => $qtmedidavariavel,
            "NRORGULTATU"      => $nrorg,
            "CDOPERULTATU"     => $cdoperador,
            "NRMEDIDACONTRATO" => $nrmedidacontrato,
            "NRORG"            => $nrorg,
            "NRESTRUTURAM"     => $nrestruturam,
            "NRITEMOCONTRATO"   => $item
        );
        
        $this->contratoFactory->atualizarMedidaVariavelServico($params);
    }

    private function inserirMedidaVariavelServico($row, $nrorg, $cdoperador, $nrestruturam = null, $item = null) {
        $nrmedidacontrato = $this->newCode->getCodeByTableName("FCT_RELACMEDIDACONTRATO", $nrorg, 1, 10, true);
        $params = array(
            "NRMEDIDACONTRATO"   => $nrmedidacontrato,
            "NRSEQCONTRATO"      => $row["NRSEQCONTRATO"],
            "CDTPMEDIDAVARIAVEL" => $row["CDTPMEDIDAVARIAVEL"],
            "QTMEDIDAVARIAVEL"   => $row["QTMEDIDACONTR"],
            "NRORG"              => $nrorg,
            "NRORGINCLUSAO"      => $nrorg,
            "CDOPERINCLUSAO"     => $cdoperador,
            "IDATIVO"            => "S",
            "IDELEMENTORAIZ"     => null,
            "QTFRANQUIA"         => null,
            "CDSERVORCA"         => $row["CDSERVORCA"],
            "NRTIPOORCAMENTO"    => $row["NRTIPOORCAMENTO"],
            "NRESTRUTURAM"       => $nrestruturam,
            "NRITEMOCONTRATO"    => $item
        );

        $this->contratoFactory->inserirMedidaVariavelServico($params);
    }
    
    public function getSomaQuantidadeMedidaServicoContrato($nrseqcontrato, $cdservorca, $nrorg, $nrestruturam = null) {
        $params = array(
            "NRSEQCONTRATO"  => $nrseqcontrato,
            "CDSERVORCA"     => $cdservorca,
            "NRORG"          => $nrorg,
            "NRESTRUTURAM"   => $nrestruturam
        );
        
        $dataset = $this->contratoFactory->getSomaQuantidadeMedidaServicoContrato($params);
        return (count($dataset) > 0) ? $dataset[0]["QTMEDIDACONTR"] : null;
    }
    
    /**
     * realiza o update da proposta para incluir / alterar o campo "DSALTERACONTRATUAIS"
    **/
    public function updateDsAlteracoesContr($nrseqcontrato, $dsalteracontratuais, $nrorg, $cdoperador) {
        
        $params = array(
            "DSALTERACONTRATUAIS" => $dsalteracontratuais,
            "OPERADOR"            => $cdoperador,
            "NRORG"               => $nrorg,
            "NRSEQCONTRATO"       => $nrseqcontrato
        );

        $this->contratoFactory->updateDsAlteracoesContr($params);
    }
    
    /**
     * Valida se o operador tem acesso à página "Alterações Contratuais"
    **/
    public function validaAlteracoesContratuais($nrorg) {
        
        $params = array(
            "NRORG" => $nrorg
        );

        $operadores = $this->contratoFactory->validaAlteracoesContratuais($params);
        
        if (!empty($operadores)){
            
            $cdoperador = $this->environment->getCdOperador();
            $count = 0;
            
            foreach ($operadores as $operador){
                if ($operador["CDOPERADOR"] == $cdoperador){
                    $count = $count + 1;
                }    
            }
            
            if ($count == 0){
                $retorno = "DESABILITADO";  
            }
            else{
                $retorno = "HABILITADO"; 
            }
        }
        else{
            $retorno = "DESABILITADO";    
        }
        
        return $retorno;
    }
    
    /**
     *recebe os dados de "Alterações Contratuais"
    **/
    public function getAlteracaoContratual($nrseqcontrato, $nrorg) {
        
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"          => $nrorg
        );

        $dsalteracontratuais = $this->contratoFactory->getAlteracaoContratual($params);
        $dsalteracontratuais = $dsalteracontratuais[0]["DSALTERACONTRATUAIS"];
        
        return $dsalteracontratuais;
    }
    
    public function inserirAssinaturasContr($nrmodelocontrato, $nrseqcontrato, $nrorg, $cdoperador){
        
        try {
            
            $params = array(
                "NRORG" => $nrorg
            );
            
            $certsign = $this->contratoFactory->validaTokenCertsign($params);
            
            if(!empty($certsign)) {
                
                $params = array(
                    "NRSEQMODCONTRA" => $nrmodelocontrato,
                    "NRORG" => $nrorg
                );
                
                $signatarios = $this->contratoFactory->buscaSignatariosPadroes($params);
                
                if(count($signatarios) > 0) {
                
                  foreach($signatarios as $signatario){
                      
                      $params = array(
                         "NRSEQCONTRATO"     => $nrseqcontrato,
                         "NRPARCNEGOCIO"     => $signatario["NRPARCNEGOCIO"],
                         "NRSEQINTERLOCUTOR" => null,
                         "NRORG"             => $nrorg,
                         "NRASSDIGITALCONTR" => null
                      );
                      
                      $valida = $this->contratoFactory->validaSignatCadastrados($params);
                       
                      if ($valida == 0){
                          
                          $nrassdigitalcontr = $this->newCode->getCodeByTableName("FCT_ASSINATDIGITALCONTR", $nrorg, 1, 10, true);
                          
                          $params = array(
                              "NRASSDIGITALCONTR" => $nrassdigitalcontr,
                              "NRSEQCONTRATO"     => $nrseqcontrato,
                              "NRPARCNEGOCIO"     => $signatario["NRPARCNEGOCIO"],
                              "NRSEQINTERLOCUTOR" => null,
                              "NRCPFSIGNATARIO"   => $signatario["NRINSCRICAOPARC"],
                              "IDTIPOASSINATURA"  => $signatario["IDTIPOASSINATURA"], 
                              "IDTESTEMUNHA"      => $signatario["IDTESTEMUNHA"], 
                              "NRORDENACAO"       => $signatario["NRORDENACAO"], 
                              "NRORG"             => $nrorg,  
                              "OPERADOR"          => $cdoperador
                          );
                          
                          $signatarios = $this->contratoFactory->insereAssinatura($params);
                      }
                  }  
                }
            }
            
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
     /**
     * A função "validaAssinaturaCont" realiza a validação dos signatários padrões para evitar a inclusão repetida de um parceiro.
     */
    public function validaAssinaturaCont($row){
        try {
            
           $nrorg = $this->environment->getNrOrg();
           $nrparcnegocio     = $row["NRPARCNEGOCIO"];
           $nrseqcontrato     = $row["NRSEQCONTRATO"];
           $interlocutor      = $row["NRSEQINTERLOCUTOR"];
           $nrassdigitalcontr = $row["NRASSDIGITALCONTR"];
           
           $params = array(
              "NRSEQCONTRATO"     => $nrseqcontrato,
              "NRPARCNEGOCIO"     => $nrparcnegocio,
              "NRSEQINTERLOCUTOR" => $interlocutor,
              "NRORG"             => $nrorg,
              "NRASSDIGITALCONTR" => $nrassdigitalcontr
           );
          
           $valida = $this->contratoFactory->validaSignatCadastrados($params);
           
           //if ($valida == 0){
                
                /* Chamada da API do Certsign para adicionar o signatário ao documento.
                   a ideia é retornar nessa função "-1" caso dê problemas na adição do signatário no Certsign
                   e "0" para sucesso. Esse retorno deve ser retornado para a variável $valida.
                */
           //}
           
           return $valida;    
        
        } catch(\Exception $e) {
            throw $e;
        }   
    }
    
    /**
     * Valida se o token da certsign está preenchido
     */
    public function validaIdCertsign($nrseqcontrato, $nrorg){
        try {
            
           /* Recebe Token Certsign */  
           $params = array(
                "NRORG" => $nrorg
           );
            
           $certsign = $this->contratoFactory->validaTokenCertsign($params);
        
           $certsign = $certsign[0]["DSTOKENCERTSIGN"];   
           if (empty($certsign) || empty($nrseqcontrato)) {
                $retorno = array(
                    "DSTOKENCERTSIGN"   => $certsign,
                    "IDASSELETRDIGITAL" => "N"
                );
            }
            else{
               /* Recebe identificador de utilização de assinatura eletrônica ou digital*/
               $params = array(
                    "NRSEQCONTRATO" => $nrseqcontrato,
                    "NRORG" => $nrorg
               );
               
               $idAssEletrDigital = $this->contratoFactory->recebeIdAssEletrDigital($params);
            
               $idAssEletrDigital = $idAssEletrDigital[0]["IDASSELETRDIGITAL"];  
               
               $retorno = array(
                   "DSTOKENCERTSIGN"   => $certsign,
                   "IDASSELETRDIGITAL" => $idAssEletrDigital
               );
           }       
           return $retorno;    
        
        } catch(\Exception $e) {
            throw $e;
        }   
    }
    
    /**
     * Envia novamente o e-mail de assinatura para os signatários que ainda não realziaram a assinatura
     */
    public function solicitarAssinatura($nrseqcontrato, $nrorg, $operador){
        try {
           
           /* Recebe Token Certsign */    
           $params = array(
                "NRORG" => $nrorg
           );
            
           $certsign = $this->contratoFactory->validaTokenCertsign($params);
        
           $certsign = $certsign[0]["DSTOKENCERTSIGN"];  
           
           if(!empty($certsign)) {
                    
                $params = array(
                    "NRSEQCONTRATO" => $nrseqcontrato,
                    "NRORG"         => $nrorg
                ); 
               
                $documentsId = $this->contratoFactory->getIdDocumentoCertsign($params);
                
                $documentIdAux = 0;
            
                foreach($documentsId as $docId) {
                    
                    $documentId = $docId["IDDOCUMCERTSIGN"];
                    
                    if (($documentId != null) && ($documentId != $documentIdAux)) {
                        
                        // Chamada da API do Certsign
                        $this->assinaturaDigital->reenviarSolicitacao($documentId);
                    }
                    
                    $documentIdAux = $documentId;
                };
           };
           
           $retorno = 'OK';  
        
        } catch(\Exception $e) {
            $retorno = $e->getMessage();
            //throw $e;
        }   
           
        return $retorno;    
    }
    
    /**
     * Exclui o signatário do Certsign e altera a situação para 'Assinado Manualmente'.
     */
    public function assinadoManualmente($signatarios, $checked, $nrorg, $operador){
        try {
           
           if ($checked == true){
                $assinaturas = $signatarios;  
           }   
           else{
                $assinaturas = array(
                    "0" => $signatarios
                );
           }
            
           /* Recebe Token Certsign */    
           $params = array(
                "NRORG" => $nrorg
           );
            
           $certsign = $this->contratoFactory->validaTokenCertsign($params);
           $certsign = $certsign[0]["DSTOKENCERTSIGN"];
           
           if(!empty($certsign)) {
               
               foreach ($assinaturas as $assinatura){
                   
                   $situacao = $assinatura["IDSITUACAO"];
                   
                   if ($situacao == 'P') { 
                            
                        $params = array(
                            "NRASSDIGITALCONTR" => $assinatura["NRASSDIGITALCONTR"],
                            "NRSEQCONTRATO"     => $assinatura["NRSEQCONTRATO"],
                            "NRORG"             => $nrorg
                        ); 
                       
                        $assDocumento = $this->contratoFactory->recebeSeqDocumento($params);
                            
                        foreach ($assDocumento as $assDoc) {
                            
                            $params = array(
                                "NRSEQCONTRATO"  => $assinatura["NRSEQCONTRATO"],
                                "NRSEQCONTDOC"  => $assDoc["NRSEQCONTDOC"],
                                "NRORG"          => $nrorg
                            ); 
                           
                            $documentsId = $this->contratoFactory->getIdDocumentoCertsignDoc($params);
                            
                            $documentIdAux = 0;
                    
                            foreach($documentsId as $docId) {
                            
                                $documentId = $docId["IDDOCUMCERTSIGN"];
                                     
                                if (($documentId != null) && ($documentId != $documentIdAux)) {
     
                                    $idsignatcertsign = $assinatura["IDSIGNATCERTSIGN"];
                                    $nrcpfsignatario  = $assinatura["NRCPFSIGNATARIO"];
                                    $situacao = $assinatura["IDSITUACAO"];
                                        
                                    // Chamada da API do Certsign
                                    $delSignatCertsign = $this->assinaturaDigital->excluirSignatario($documentId, $idsignatcertsign, $nrcpfsignatario);
                                    
                                    /* -- Limpa o ID dos signatários da proposta antiga -- */
                                    $params = array(
                                        "OPERADOR"          => $operador,
                                        "NRORG"             => $nrorg,
                                        "NRASSDIGITALCONTR" => $assinatura["NRASSDIGITALCONTR"],
                                        "NRSEQCONTRATO"     => $assinatura["NRSEQCONTRATO"],
                                        "NRSEQCONTDOC"     => $assDoc["NRSEQCONTDOC"]
                                    ); 
                                   
                                    $this->contratoFactory->updateSituacaoAssManualDoc($params);
                                    
                                }
                        
                                $documentIdAux = $documentId;
                            }
                        };
                            
                        $this->verificaSituacaoSignatarios($assinatura["NRSEQCONTRATO"], $assinatura["NRASSDIGITALCONTR"], $nrorg, $operador);
                   }
               }
           };
        
           $retorno = 'OK';   
        
        } catch(\Exception $e) {
            
            $retorno = $e->getMessage();
            //throw $e;
        }   
        
        return $retorno;    
    }
    
    
    /**
     * Exclui o signatário do Certsign e altera a situação para 'Assinado Manualmente'.
     */
    public function assinadoManualmenteDoc($signatarios, $checked, $nrorg, $operador){
        try {
           
           if ($checked == true){
                $assinaturas = $signatarios;  
           }   
           else{
                $assinaturas = array(
                    "0" => $signatarios
                );
           }
            
           /* Recebe Token Certsign */    
           $params = array(
                "NRORG" => $nrorg
           );
            
           $certsign = $this->contratoFactory->validaTokenCertsign($params);
           $certsign = $certsign[0]["DSTOKENCERTSIGN"];
           
           if(!empty($certsign)) {
               
               foreach ($assinaturas as $assinatura){
                   
                   $situacao = $assinatura["IDSITUACAO"];
                   
                   if ($situacao == 'P') { 
                        
                        $params = array(
                            "NRSEQCONTRATO" => $assinatura["NRSEQCONTRATO"],
                            "NRSEQCONTDOC" => $assinatura["NRSEQCONTDOC"],
                            "NRORG"         => $nrorg
                        ); 
                       
                        $documentsId = $this->contratoFactory->getIdDocumentoCertsignDoc($params);
                        
                        $documentIdAux = 0;
                
                        foreach($documentsId as $docId) {
                        
                            $documentId = $docId["IDDOCUMCERTSIGN"];
                        
                            if (($documentId != null) && ($documentId != $documentIdAux)) {
 
                                $params = array(
                                    "NRASSDIGITALCONTR" => $assinatura["NRASSDIGITALCONTR"],
                                    "NRSEQCONTRATO"     => $assinatura["NRSEQCONTRATO"],
                                    "NRORG"             => $nrorg
                                ); 
                               
                                $nrcpfsignatario = $this->contratoFactory->getCpfSignatAssDoc($params);
                                
                                if(!empty($nrcpfsignatario))
                                $nrCPF = $nrcpfsignatario[0]["NRCPFSIGNATARIO"];
                                
                                $idsignatcertsign = $assinatura["IDSIGNATCERTSIGN"];
                                $situacao = $assinatura["IDSITUACAO"];
                                    
                                // Chamada da API do Certsign
                                $delSignatCertsign = $this->assinaturaDigital->excluirSignatario($documentId, $idsignatcertsign, $nrCPF);
                                
                                /* -- Limpa o ID dos signatários da proposta antiga -- */
                                $params = array(
                                    "OPERADOR"          => $operador,
                                    "NRORG"             => $nrorg,
                                    "NRASSDIGITALCONTR" => $assinatura["NRASSDIGITALCONTR"],
                                    "NRSEQCONTRATO"     => $assinatura["NRSEQCONTRATO"],
                                    "NRSEQCONTDOC"     => $assinatura["NRSEQCONTDOC"]
                                ); 
                               
                                $this->contratoFactory->updateSituacaoAssManualDoc($params);
                                
                            }
                    
                            $documentIdAux = $documentId;
                        }
                            
                        $this->verificaSituacaoSignatarios($assinatura["NRSEQCONTRATO"], $assinatura["NRASSDIGITALCONTR"], $nrorg, $operador);
                   }
               };
           };
        
           $retorno = 'OK';   
        
        } catch(\Exception $e) {
            
            $retorno = $e->getMessage();
            //throw $e;
        }   
        
        return $retorno;    
    }
    
    
    /* Verifica se todos os as situações dos documentos de assinatura para atuzalizar os registros dos signatários. Sendo:
       - Se alguns dos documentos estiver recusado,  o signatário fica como recusado.
       - Fora o caso acima, caso ainda tenha algum documento pendente, o signatário permanece pendente.
       - Caso não haja nenhum pendente e nenhum recusado e algum registro aprovado, o signatário fica aprovado.
       - Caso não haja nenhum pendente e nenhum recusado e nenhum aprovado, o signatário fica manual.
    */
    public function verificaSituacaoSignatarios($seqProposta, $signatario, $nrorg, $operador) {
        try {
            
            $countAprovado  = 0;
            $countRecusado = 0;
            $countPendente  = 0;
            $justificaRecusa = null;
            
            $params = array(
                "NRASSDIGITALCONTR" => $signatario,
                "NRSEQCONTRATO"     => $seqProposta,
                "NRORG"             => $nrorg
            );
            
            $dadosProposta = $this->contratoFactory->recebeDadosAssDocContr($params);  
            
            foreach ($dadosProposta as $dados){
                
                if ($dados["IDSITUACAO"] == 'A'){
                    
                    $countAprovado = $countAprovado+1;
                } 
                else if ($dados["IDSITUACAO"] == 'R'){ 
                    
                    $countRecusado = $countRecusado+1;
                    
                    if ($justificaRecusa == null) {
                        
                        $justificaRecusa = $dados["DSJUSTIFICARECUSA"];
                    } 
                    else {
                        
                        $justificaRecusa = $justificaRecusa.' /// '.$dados["DSJUSTIFICARECUSA"];
                    }
                } 
                else if ($dados["IDSITUACAO"] == 'P'){
                    
                    $countPendente = $countPendente+1;
                } 
            } 

            if ($countRecusado > 0) {
                
                $params = array(
                    "IDSITUACAO"        => 'R',
                    "DSJUSTIFICARECUSA" => $justificaRecusa,
                    "NRORG"             => $nrorg, 
                    "OPERADOR"          => $operador,
                    "NRASSDIGITALCONTR" => $signatario,
                    "NRSEQCONTRATO"     => $seqProposta
                );
                
                $this->contratoFactory->updateAssinaContrato($params);
            }
            else if ($countPendente > 0) {
                
                /* O registro permanece pendente */
            }
            else if ($countAprovado > 0) {
                
                 $params = array(
                    "IDSITUACAO"        => 'A',
                    "DSJUSTIFICARECUSA" => $justificaRecusa,
                    "NRORG"             => $nrorg, 
                    "OPERADOR"          => $operador,
                    "NRASSDIGITALCONTR" => $signatario,
                    "NRSEQCONTRATO"     => $seqProposta
                );
                
                $this->contratoFactory->updateAssinaContrato($params);
            }
            else{
              
              $params = array(
                    "IDSITUACAO"        => 'M',
                    "DSJUSTIFICARECUSA" => $justificaRecusa,
                    "NRORG"             => $nrorg, 
                    "OPERADOR"          => $operador,
                    "NRASSDIGITALCONTR" => $signatario,
                    "NRSEQCONTRATO"     => $seqProposta
                );
                
                $this->contratoFactory->updateAssinaContrato($params);  
            }

            
        } catch(\Exception $e){
            throw $e;
        }
    }
    
    
    /**
     * Valida se as assinaturas da certsign estão aprovadas para aprovar o contrato.
     */
    public function validaAprovacaoCertsign($nrseqcontrato, $nrorg){
        try {
            
           /* Recebe Token Certsign */    
           $params = array(
                "NRORG" => $nrorg
           );
            
           $certsign = $this->contratoFactory->validaTokenCertsign($params);
        
           if(!empty($certsign)) {
           
               /* Recebe identificador de utilização de assinatura eletrônica ou digital*/
               $params = array(
                    "NRSEQCONTRATO" => $nrseqcontrato,
                    "NRORG" => $nrorg
               );
               
               $idAssEletrDigital = $this->contratoFactory->recebeIdAssEletrDigital($params);
            
               $idAssEletrDigital = $idAssEletrDigital[0]["IDASSELETRDIGITAL"];
               
               if ($idAssEletrDigital == 'S'){
                  
                   /* Recebe as assinaturas e verifica se todas estão aprovadas*/
                   $params = array(
                       "NRSEQCONTRATO" => $nrseqcontrato,
                       "NRORG" => $nrorg
                   );
                   
                   $assinaturas = $this->contratoFactory->recebeassinaturas($params); 
                   
                   $countPendCanc = 0;
                   foreach ($assinaturas as $assinatura){
                       
                       if ($assinatura["IDSITUACAO"] == 'P'|| $assinatura["IDSITUACAO"] == 'R'){
                         
                         $countPendCanc = $countPendCanc + 1; 
                       }
                   }
                   
                   if ($countPendCanc == 0){
                       $retorno = 'OK';
                   }
                   else{
                       $retorno = 'PENDENCIA';
                   }
                   
               }
               else{
                  $retorno = 'OK';     
               }    
           }
           else{
             
              $retorno = 'OK';  
           }

           return $retorno;    
           
        } catch(\Exception $e) {
            throw $e;
        }   
    }
    
     /**
     * A função "gerarDocumentoCertsign" realiza o upload e cria o documento no ambiente certsign
     */
    public function gerarDocumentoCertsign($nrseqcontrato, $nmDocumento, $documento, $nrorg, $operador){
        $this->connection->beginTransaction();
        try {
            /* 1 - Realiza o Upload e recebe a string de upload para criação do documento no Certsign */
            $upload = $this->assinaturaDigital->uploadtoCertsing($nmDocumento, $documento);
          
            $uploadId = $upload;
            
            /* -- Arrumando a String para criação do documento -- */
            $uploadId = str_replace(array('{"uploadId":"', '"}'), '', $uploadId);
            $uploadId = str_replace('\/', '/', $uploadId);
    
            /* 2 - Cria o documento no Certsign */
            
            /* -- Recebe dados do Sender -- */
            $params= array(
                "NRORG"            => $nrorg
            );        
            
            $responsavel = $this->contratoFactory->getDadosSender($params);
    
            $sender = array();
    
            foreach ($responsavel as $resp){
                $sender['NOME']  = $resp['NMSENDERCERTSIGN'];
                $sender['EMAIL'] = $resp['DSEMAILSENDERCERTSIGN'];
                $sender['CPF']   = $resp['NRCPFSENDERCERTSIGN'];
            }
            
            /* -- Recebe os Signatários Digitais -- */
            
            $params= array(
                "NRSEQCONTRATO"   => $nrseqcontrato,
                "IDTIPOASSINATURA" => 'D',
                "NRORG"            => $nrorg
            );        
            
            $signatarios = $this->contratoFactory->getSignatarios($params);
    
            $signers = array();
    
            foreach ($signatarios as $ind => $sign){
                
                if ($sign['IDTESTEMUNHA'] == 'N'){
                    $testemunha = 'Signer';  
                }
                else{
                    $testemunha = 'Witness';   
                }
                
                $signers[$ind] = array(
                    'POSICAO' => $sign['NRORDENACAO'],
                    'TIPO'    => $testemunha,
                    'NOME'    => $sign['NOME'],
                    'EMAIL'   => $sign['EMAIL'],
                    'CPF'     => $sign['NRCPFSIGNATARIO']
                );
            }
            
            /*  -- Recebe os Signatários Eletrônicos -- */
            
            $params= array(
                "NRSEQCONTRATO"   => $nrseqcontrato,
                "IDTIPOASSINATURA" => 'E',
                "NRORG"            => $nrorg
            );        
            
            $signatarios = $this->contratoFactory->getSignatarios($params);
    
            $eletrSigners = array();
    
            foreach ($signatarios as $ind => $sign){
                
                if ($sign['IDTESTEMUNHA'] == 'N'){
                    $testemunha = 'Signer';  
                }
                else{
                    $testemunha = 'Witness';   
                }
                
                $eletrSigners[$ind] = array(
                    'POSICAO' => $sign['NRORDENACAO'],
                    'TIPO'    => $testemunha,
                    'NOME'    => $sign['NOME'],
                    'EMAIL'   => $sign['EMAIL'],
                    'CPF'     => $sign['NRCPFSIGNATARIO']
                );
            }
            
            /* -- Recebe o Tipo de Documento e email do operador responsável -- */
            
            $params= array(
                "NRSEQCONTRATO"   => $nrseqcontrato
            );    
            
            $tipoDocParamSm = (int)$responsavel[0]['NRTIPODOCCERTSIGN'];
            $padraoAssinatura = (int)$responsavel[0]['IDPADRAOASSINACERTSIGN'];
            
            $dados = $this->contratoFactory->getTipoDocumento($params);
            $tipoDoc = (int)$dados[0]['NRTIPODOCCERTSIGN'];
            if(empty($tipoDoc)){
                $tipoDoc = $tipoDocParamSm;
            }
            
            $dados = $this->contratoFactory->getEnviarDocAss($params);
            $emailOperResp = null;
            if(count($dados)>0){
                $emailOperResp = $dados[0]['DSEMAILOPER'];
            }
            
            /* -- Chama a API para criar o Documento no Certsign -- */
            $docCertsign = $this->assinaturaDigital->createSignatureCertsing($uploadId, $nmDocumento, $sender, $signers, $eletrSigners, $padraoAssinatura, $tipoDoc, $emailOperResp);
            
            /* -- Atualiza o registro dos documentos do contrato para incluir o ID e a Chave do Certisign -- */
            
            $id    = $docCertsign['response']['id'];
            $chave = $docCertsign['response']['chave'];
            
            $params = array(
                "IDDOCUMCERTSIGN"    => $id,
                "CHAVEDOCUMCERTSIGN" => $chave,
                "OPERADOR"           => $operador,
                "NRORG"              => $nrorg,
                "NRSEQCONTRATO"      => $nrseqcontrato
            );        
            
            $this->contratoFactory->updateDocumentoIdCertsign($params);
             
            /* -- Atualiza o registro dos signatários do contrato para incluir o ID do Certisign -- */
            $attendees = $docCertsign['response']['attendees'];
            
            foreach ($attendees as $signatario){
                
                /* recebe o sequencial do signatário */
                $params = array(
                    "NRSEQCONTRATO"   => $nrseqcontrato,
                    "NRCPFSIGNATARIO" => $signatario['individualIdentificationCode'],
                    "NRORG"           => $nrorg
                );  
                
                $seqSignatario = $this->contratoFactory->recebeSeqSignatario($params);
                
                if (!empty($seqSignatario))
                    $seqSignat = $seqSignatario[0]["NRASSDIGITALCONTR"];
                
                /* recebe o sequencual do documento */
                $params = array(
                    "NRSEQCONTRATO"   => $nrseqcontrato,
                    "NRORG"           => $nrorg
                );  
                
                $seqDocumento = $this->contratoFactory->recebeSeqDocContr($params);
                
                foreach ($seqDocumento as $documento){
                
                    /*Atualiza o documento do signatário*/
                    if (!empty($seqSignat)) {
                    
                        $nrDocAssinatContr = $this->newCode->getCodeByTableName("FCT_DOCASSINATCONTR", $nrorg, 1, 10, true);
                      
                        $params = array(
                            "NRDOCASSINATCONTR" => $nrDocAssinatContr,
                            "NRASSDIGITALCONTR" => $seqSignat,
                            "NRSEQCONTDOC"      => $documento["NRSEQCONTDOC"],
                            "IDSIGNATCERTSIGN"  => $signatario['signerId'],
                            "NRSEQCONTRATO"     => $nrseqcontrato,
                            "NRORG"             => $nrorg,
                            "OPERADOR"          => $operador
                        );
                        
                        $this->contratoFactory->insereDocAssinatura($params);
                    }
                }
            }
            
            /* -- Altera a situação do contrato para "Documento Enviado" -- */
            $params= array(
                "OPERADOR"      => $operador,
                "NRORG"         => $nrorg,
                "NRSEQCONTRATO" => $nrseqcontrato
            );        
            
            $this->contratoFactory->updateSitContrDocEnv($params);
            $this->connection->commit();
            return "OK";
        }
        catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
    
    /**
     * A função "excluirDocumentoCertsign" realiza a exclusão do documento no Certsign.
     */
    public function excluirDocumentoCertsign($nrseqcontrato, $nrorg, $operador){
        
        try {
            
            $params = array(
                "NRORG" => $nrorg
            );
            
            $certsign = $this->contratoFactory->validaTokenCertsign($params);
            
            if(!empty($certsign)) {
                
                /* Recebe identificador de utilização de assinatura eletrônica ou digital*/
               $params = array(
                    "NRSEQCONTRATO" => $nrseqcontrato,
                    "NRORG"         => $nrorg
               );
               
               $idAssEletrDigital = $this->contratoFactory->recebeIdAssEletrDigital($params);
            
               $idAssEletrDigital = $idAssEletrDigital[0]["IDASSELETRDIGITAL"];
               
               if ($idAssEletrDigital == 'S'){
                   
                   $params = array(
                        "NRSEQCONTRATO" => $nrseqcontrato,
                        "NRORG"         => $nrorg
                    ); 
                   
                    $documentsId = $this->contratoFactory->getIdDocumentoCertsign($params);
                    
                    $documentIdAux = 0;
                    
                    foreach($documentsId as $docId) {
                        
                        $documentId = $docId["IDDOCUMCERTSIGN"];
                        
                        if (($documentId != null) && ($documentId != $documentIdAux)) {
                            
                            /* -- Chama a API para excluir o documento no Certsign -- */
                            $delDocCertsign = $this->assinaturaDigital->excluirdocumento($documentId);
                            
                            /* -- Limpa o ID e a Chave dos documentos da proposta antiga -- */
                            $params = array(
                                "OPERADOR"       => $operador,
                                "NRORG"          => $nrorg,
                                "NRSEQCONTRATO"  => $nrseqcontrato
                            ); 
                            
                            $this->contratoFactory->clearDocumentoIdCertsign($params);
                            
                            /* -- Limpa o ID dos signatários da proposta antiga -- */
                            $params = array(
                                "OPERADOR"        => $operador,
                                "NRORG"           => $nrorg,
                                "NRSEQCONTRATO"   => $nrseqcontrato,
                                "NRCPFSIGNATARIO" => 'T'
                            ); 
                           
                            $this->contratoFactory->clearSignatarioIdCertsign($params);
                            
                            $documentIdAux = $documentId;
                        }
                    }
                }
            }
            
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    /**
     * A função "inserirSignatario" realiza a inclusão de um novo signatário.
     */
    public function inserirSignatario($row){
        try {
            
            $nrorg              = $this->environment->getNrOrg();
            $operador           = $this->environment->getCdOperador();
            $nrassdigitalcontr  = $row["NRASSDIGITALCONTR"];
            $nrseqcontrato      = $row["NRSEQCONTRATO"];
            $nrparcnegocio      = $row["NRPARCNEGOCIO"];
            $interlocutor       = $row["NRSEQINTERLOCUTOR"];
            $nome               = $row["NMPRINCIPALPARC"];
            $email              = $row["EMAIL"];
            $cpf                = $row["NRCPFSIGNATARIO"];
            $tipo               = $row["IDTIPOASSINATURA"];
            $testemunhaId       = $row["IDTESTEMUNHA"];
            $ordenacao          = $row["NRORDENACAO"];
            $dsemailnotsignenv  = $row["DSEMAILNOTSIGNENV"];
            $dsemailnotifoutros = $row["DSEMAILNOTIFOUTROS"];
           
            $params = array(
                "NRSEQCONTRATO"  => $nrseqcontrato,
                "NRORG"           => $nrorg
            ); 
           
            $documentsId = $this->contratoFactory->getIdDocumentoCertsign($params);
            
            $documentIdAux = 0;
            foreach($documentsId as $docId) {
                
                $documentId = $docId["IDDOCUMCERTSIGN"];
                
                if (($documentId != null) && ($documentId != $documentIdAux)) {
                    /* -- Recebe os Signatários -- */
                
                    if ($tipo == 'D'){
                        $signers      = array();
                        $eletrSigners = array();
                        
                        if ($testemunhaId == 'N'){
                            $testemunha = 'Signer';  
                        }
                        else{
                            $testemunha = 'Witness';   
                        }
                        
                        $signers[0] = array(
                            'POSICAO' => $ordenacao,
                            'TIPO'    => $testemunha,
                            'NOME'    => $nome,
                            'EMAIL'   => $email,
                            'CPF'     => $cpf
                        );
                    }   
                    else{
                        $signers      = array();
                        $eletrSigners = array();
                            
                        if ($testemunhaId == 'N'){
                            $testemunha = 'Signer';  
                        }
                        else{
                            $testemunha = 'Witness';   
                        }
                        
                        $eletrSigners[0] = array(
                            'POSICAO' => $ordenacao,
                            'TIPO'    => $testemunha,
                            'NOME'    => $nome,
                            'EMAIL'   => $email,
                            'CPF'     => $cpf
                        );
                    }
                    
                    /* -- Chama a API para inserir o signatario no Certsign -- */
                    $incSignatCertsign = $this->assinaturaDigital->incluirSignatario($documentId, $signers, $eletrSigners);
                    
                    /* -- Atualiza o registro dos signatários da proposta para incluir o ID do Certsing -- */
                    $signatarios = $incSignatCertsign['response'];
                    
                    foreach ($signatarios as $signatario){
                        foreach ($signatario as $signer){
                
                            $params = array(
                                "IDSIGNATCERTSIGN" => $signer['id'],
                                "OPERADOR"         => $operador,
                                "NRORG"            => $nrorg,
                                "NRCPFSIGNATARIO"  => $signer['individualIdentificationCode']
                            );
                    
                            $this->contratoFactory->updateSignatarioIdCertsign($params);
                        }
                    }
                    
                    $documentIdAux = $documentId;
                }
            }
        } catch(\Exception $e) {
            throw $e;
        }   
    }
    
    /**
     * A função "excluirSignatariosCertsign" realiza a exclusão de um signatário no Certsign.
     */
    public function excluirSignatariosCertsign($nrseqcontrato, $nrassdigitalcontr, $idsignatcertsign, $nrcpfsignatario, $nrorg, $operador){
        
        try {
            
            $params = array(
                "NRORG" => $nrorg
            );
            
            $certsign = $this->contratoFactory->validaTokenCertsign($params);
            
            if(!empty($certsign)) {
                
                /* Recebe identificador de utilização de assinatura eletrônica ou digital*/
               $params = array(
                    "NRSEQCONTRATO" => $nrseqcontrato,
                    "NRORG"         => $nrorg
               );
               
               $idAssEletrDigital = $this->contratoFactory->recebeIdAssEletrDigital($params);
            
               $idAssEletrDigital = $idAssEletrDigital[0]["IDASSELETRDIGITAL"];
               
               if ($idAssEletrDigital == 'S'){
                   
                   $idAceitaExclusao  = 'N';
                    
                    $params = array(
                        "NRASSDIGITALCONTR" => $nrassdigitalcontr,
                        "NRSEQCONTRATO"     => $nrseqcontrato,
                        "NRORG"             => $nrorg
                    );
                    
                    $dadosProposta = $this->contratoFactory->recebeDadosAssDocContr($params);  
                    
                    foreach ($dadosProposta as $dados){
                        
                        if (($dados["IDSITUACAO"] != 'P') && ($dados["IDSITUACAO"] != 'M')) {
                            
                             $idAceitaExclusao = 'S'; 
                        }
                    }
                   
                    if ($idAceitaExclusao != 'S'){
                   
                       $params = array(
                            "NRSEQCONTRATO" => $nrseqcontrato,
                            "NRORG"         => $nrorg
                        ); 
                       
                        $documentsId = $this->contratoFactory->getIdDocumentoCertsign($params);
                        
                        $documentIdAux = 0;
                        
                        foreach($documentsId as $docId) {
                            
                            $documentId = $docId["IDDOCUMCERTSIGN"];
                            
                            if (($documentId != null) && ($documentId != $documentIdAux)) {
                                
                                /* -- Chama a API para excluir um signatário no Certsign -- */
                                $delSignatCertsign = $this->assinaturaDigital->excluirSignatario($documentId, $idsignatcertsign, $nrcpfsignatario);
                                
                                $documentIdAux = $documentId;
                            }
                        }
                    }
                    else {
                        throw new \Exception("Operação bloqueada!<br/><br/>Existem documentos já assinados ou recusados.");
                    }
                }
            }
            
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    /**
     * realiza o download do documento do ambiente Certsign 
    **/
    public function downloadDocEletrDigital($nrseqcontrato, $nrorg){
        
        try {
            
            $params = array(
                "NRORG" => $nrorg
            );
            
            $certsign = $this->contratoFactory->validaTokenCertsign($params);
            
            if(!empty($certsign)) {
                
                /* Recebe identificador de utilização de assinatura eletrônica ou digital*/
               $params = array(
                    "NRSEQCONTRATO" => $nrseqcontrato,
                    "NRORG"         => $nrorg
               );
               
               $idAssEletrDigital = $this->contratoFactory->recebeIdAssEletrDigital($params);
            
               $idAssEletrDigital = $idAssEletrDigital[0]["IDASSELETRDIGITAL"];
               
               if ($idAssEletrDigital == 'S'){
                   
                   $params = array(
                        "NRSEQCONTRATO"  => $nrseqcontrato,
                        "NRORG"          => $nrorg
                    ); 
                   
                    $documentsId = $this->contratoFactory->getIdDocumentoCertsign($params);
                    
                    $documentIdAux = 0;
                    
                    foreach($documentsId as $docId) {
                        
                        $documentId = $docId["IDDOCUMCERTSIGN"];
                        $chave      = $docId["CHAVEDOCUMCERTSIGN"];
                        
                        if (($documentId != null) && ($documentId != $documentIdAux)) {
                            
                            $ds = DIRECTORY_SEPARATOR;
                            
                            /* -- Chama a API para Download do documento no Certsign -- */
                            $downDocCertsign = $this->assinaturaDigital->dowloadDocumento($chave);
                            
                            $docs = $downDocCertsign['response'];
                            $conteudo = base64_decode($docs['bytes']);

                            $file = $this->tempDir.$ds.$docs['name'];
                            
                            file_put_contents($file, $conteudo);

                            if (file_exists($file)) {
                                set_time_limit(0);
                                
                                header('Content-Description: File Transfer');
                                header('Content-Transfer-Encoding: binary');
                                header('Content-Type: '. $docs['mimeType']);
                                header('Content-Disposition: attachment; filename="'.basename($file).'"');
                                header('Expires: 0');
                                header('Cache-Control: must-revalidate');
                                header("Pragma: no-cache");
                                header('Content-Length: ' . filesize($file));
                                ob_clean();
                                flush();
                                
                                readfile($file);   
                                exit;
                            }
                        }
                        
                        $documentIdAux = $documentId;
                    }
                }
            }
            
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function validarEscopoExclusaoOM($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        
        $valida = $this->contratoFactory->validarEscopoExclusaoOM($params);
        return (int)$valida[0]["VALIDA"];
    }
    
    public function encerraContrato($nrseqcontrato, $idsituacaocontrato, $dtrecisao, $idtpexclusaoparcela, $nrorg, $cdoperador, $nrtiporescisao, $idDocX, $dtpedrescisaocontr, $nrmotivorescisao, $dsjustificaencerra, $vrpendenciafin) {
        $dadosDaRescisao = array();

        if ($idsituacaocontrato == "A") {
            
            /*$validaEscopoExcOm - Parâmetro para validar se o escopo pode desabilitar os produtos / elementos no OM. 
            A função faz um count na tabela de parametrização, portanto, se ">0" é por que o escopo está inserido na tabela.*/
            
            $validaEscopoExcOm = $this->validarEscopoExclusaoOM($nrseqcontrato, $nrorg);
            
            if ($validaEscopoExcOm > 0) {
                $dadosDaRescisao = $this->desabilitarProdutoNoOM($nrseqcontrato, $cdoperador, $nrorg);
            }
        }
        
        if(count($dadosDaRescisao) > 0) {
            $this->atualizarRescisao($dadosDaRescisao, $nrorg, false);
        }
        
        $this->connection->beginTransaction();
        try {
            $params = array(
                "NRSEQCONTRATO" => $nrseqcontrato,
                "NRORG"         => $nrorg
            );
            
            $parcNegocio = $this->contratoFactory->getParcNegocioContrato($params);
            
            $this->executarProcedureFctEncerraContrato($nrseqcontrato, $cdoperador, $nrorg, $dtrecisao, $idtpexclusaoparcela);
            
            $params = $this->gerarParametrosAtualizacaoRescisao($dtpedrescisaocontr, $dtrecisao, $nrmotivorescisao, $nrtiporescisao, $vrpendenciafin, $dsjustificaencerra, $nrorg, $cdoperador, $nrseqcontrato, 'C', false, null);
            $this->contratoFactory->atualizarDadosRescisaoContrato($params);
            
            /* Anexar nos anexos do contrato */
            $this->anexarDocumentoRescindidoContrato($nrseqcontrato, $parcNegocio, $nrtiporescisao, $nrorg, $cdoperador, null);
            
            $this->DeletaAgendPendenteContratoEncerrado($nrseqcontrato, $nrorg);
            $this->inativaParcNegocio($parcNegocio, $nrorg, $cdoperador);
            
            if ($idsituacaocontrato == "A" && count($dadosDaRescisao) > 0) {
                $this->integracaoOmService->desabilitarElementosNoOm($dadosDaRescisao, $nrorg);
                //$dadosDaRescisao = $this->desabilitarProdutoNoOM($nrseqcontrato, $cdoperador, $nrorg);
            }
            
            $this->excluirDocumentoCertsign($nrseqcontrato, $nrorg, $cdoperador);
            $this->connection->commit();
        }
        catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
    
    /**
     * realiza a atualização do Nr. de Parcelas da negociação
     **/
    public function atualizarNrParcelas($nrnegociacaocontrato, $nrorg){
        
        $params = array(
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "NRORG"                => $nrorg
        );
        
        $parcelas = $this->contratoFactory->getParcelasOrderQtDiasFatu($params);
        
        $cont = 0;
        foreach($parcelas as $parcela){
            
            $cont = $cont+1;
            
            $params = array(
                "NRPARCELA"         => $cont,
                "NRPARCELANEGOCONT" => $parcela['NRPARCELANEGOCONT'],
                "NRORG"             => $nrorg
            );
            
            $this->contratoFactory->atualizarNrParcelas($params);
        }
    }
    
    /**
     * Suspende o contrato para pausar o faturamento e as alterações no contrato.
    **/
    public function suspenderContrato($nrseqcontrato, $idParcelasAnt, $nrorg, $operador, $dsjustifcasuspensao, $cdopersolsuspensao) {
        $this->connection->beginTransaction();
        try {
            $dataAtual = date_create();
            $dataAtual = $dataAtual->format("d/m/Y");
            
            $nrseqorcamento = null;
            $idUtilizaComp  = null;
            
            
            /* Altera a situação do contrato para suspenso e grava a data de suspensão
               Obs: Normalmente seria feito por ultimo na rotina, mas preciso da data de suspensão para 
                    atualizar a data de validade na integração com o OM */
            $params = array(
                'IDSITUACAO'    => 'S',
                'DTSUSPENSAO'   => $dataAtual, 
                "OPERADOR"      => $operador,
                "NRORG"         => $nrorg,
                "NRSEQCONTRATO" => $nrseqcontrato,
                "DSJUSTIFCASUSPENSAO" => $dsjustifcasuspensao,
                "CDOPERSOLSUSPENSAO" => $cdopersolsuspensao
            );
            
            $this->contratoFactory->atualizaSituacaoSuspenso($params);
            
            /* -- Insere o log de Suspensão  -- */
            $nrDadosSuspContr = $this->newCode->getCodeByTableName("FCT_DADOSSUSPCONTR", $nrorg, 1, 10, true);
            
            $params = array(
                'NRDADOSSUSPCONTR'    => $nrDadosSuspContr,
                "NRSEQCONTRATO"       => $nrseqcontrato,
                'DTSUSPENSAO'         => $dataAtual, 
                "CDOPERSOLSUSPENSAO"  => $cdopersolsuspensao,
                "DSJUSTIFCASUSPENSAO" => $dsjustifcasuspensao,
                "NRORG"               => $nrorg,
                "OPERADOR"            => $operador
            );
            
            $this->contratoFactory->insereLogDadosSuspensao($params);
            
            
            /* Deleta as parcelas e medições de faturamento pendentes da suspensão 
                 - Se IdParcelasAnt = MANTER: Mantém as parcelas de faturamento e as medições anteriores à suspensão.
                 - Se IdParcelasAnt = EXCLUIR: exclui as parcelas de faturamento e as medições anteriores à suspensão.
             */
            
            if ($idParcelasAnt == 'MANTER') {
                
                $this->executarProcedureFctSuspenderParcelasFatura($nrseqcontrato, $nrorg, $dataAtual);
    
            }
            else /*EXCLUIR*/ {
                
                $this->executarProcedureFctSuspenderParcelasFatura($nrseqcontrato, $nrorg, null);
                
            }
            
            /* Altera data de validade OM*/
            
            $params = array(
                "NRSEQCONTRATO" => $nrseqcontrato,
                "NRORG"         => $nrorg
            );
                
            $recebeIdUtilizaComp = $this->contratoFactory->recebeIdUtilizaComp($params);
            $utilizaComp = $recebeIdUtilizaComp[0]['UTILIZACOMP'];
            
            if ($utilizaComp > 0) {
                
                $idUtilizaComp = 'S';
            } 
            
            $this->IntegracaoOM($nrseqcontrato, null, $idUtilizaComp, $nrorg, true, true);
                
            
            $this->connection->commit();
        }
        catch (\Exception $e) {
            $this->connection->rollBack();
            throw $e;
        }
    }
    
    /**
     * Cancela a suspensão do contrato
    **/
    public function cancelarSuspensaoContrato($nrseqcontrato, $nrorg, $operador) {
        $this->connection->beginTransaction();
        try {
            
            $nrseqorcamento = null;
            $idUtilizaComp  = null;
            
            /* Altera a situação do contrato para suspenso e grava a data de suspensão
               Obs: Normalmente seria feito por ultimo na rotina, mas preciso da data de suspensão para 
                    atualizar a data de validade na integração com o OM */
            $params = array(
                "IDSITUACAO"          => 'A',
                "DTSUSPENSAO"         => null, 
                "OPERADOR"            => $operador,
                "NRORG"               => $nrorg,
                "NRSEQCONTRATO"       => $nrseqcontrato,
                "CDOPERSOLSUSPENSAO"  => null, 
                "DSJUSTIFCASUSPENSAO" => null
            );
            
            $this->contratoFactory->atualizaSituacaoSuspenso($params);
            
            /* -- Insere o log de Suspensão  -- */
            $nrDadosSuspContr = $this->newCode->getCodeByTableName("FCT_DADOSSUSPCONTR", $nrorg, 1, 10, true);
            
            $params = array(
                'NRDADOSSUSPCONTR'    => $nrDadosSuspContr,
                "NRSEQCONTRATO"       => $nrseqcontrato,
                'DTSUSPENSAO'         => null, 
                "CDOPERSOLSUSPENSAO"  => null,
                "DSJUSTIFCASUSPENSAO" => null,
                "NRORG"               => $nrorg,
                "OPERADOR"            => $operador
            );
            
            $this->contratoFactory->insereLogDadosSuspensao($params);
            
            /* Regera as parcelas de faturamento do contrato */
            $this->executarProcedureFctGerarParcelasFatura($nrseqcontrato, $nrorg, $operador);
            
            /* Altera data de validade OM*/
            
            $params = array(
                "NRSEQCONTRATO" => $nrseqcontrato,
                "NRORG"         => $nrorg
            );
                
            $recebeIdUtilizaComp = $this->contratoFactory->recebeIdUtilizaComp($params);
            
            $utilizaComp  = $recebeIdUtilizaComp[0]['UTILIZACOMP'];
            
            if ($utilizaComp > 0){
                
                $idUtilizaComp = 'S';
            } 
                
            $this->IntegracaoOM($nrseqcontrato, $nrseqorcamento, $idUtilizaComp, $nrorg, false, true);
                
            
            $this->connection->commit();
        }
        catch (\Exception $e) {
            $this->connection->rollBack();
            throw $e;
        }
    }
    
    /**
     * A função "executarProcedureFctSuspenderParcelasFatura" executa a procedure
     * "FCT_SUSPENDER_PARCELAS_FATURA".
     */
     
    public function executarProcedureFctSuspenderParcelasFatura($nrseqcontrato, $nrorg, $dtrecisao) {
        $procedure = new FctSuspenderParcelasFatura($this->connection);
        $procedure->executar($nrseqcontrato, $nrorg, $dtrecisao);
    }
    
    /**
     * Verifica se um contrato possui alguma negociação feita para um de seus itens ou elementos.
     */
     
    public function verificarSeContratoPossuiNegociacao($nrseqcontrato, $nrseqcontratopai, $nrorg) {
        $params = array(
            "NRSEQCONTRATO"    => $nrseqcontratopai,
            "NEWNRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"            => $nrorg
        );
        
        $dataset = $this->contratoFactory->verificarSeContratoPossuiNegociacao($params);
        return $dataset[0]["QTD"] > 0;
    }
     
    /* Retorna o parametro validação para a geração de 
     * documentos de encerramento em Docx ou PDF
    **/
    
    public function getParametroExtensaoDocEncerra($nrtiporescisao, $nrorg){
        $params = array(
            "NRTIPORESCISAO" => $nrtiporescisao,
            "NRORG"         => $nrorg
        );

        $result = $this->contratoFactory->getParametroExtensaoDocEncerra($params);
        
        return isset($result) ? $result : null;
    }
 
    
    public function anexarDocumentoRescindidoContrato($nrseqcontrato, $parcnegocio, $nrtiporescisao, $nrorg, $cdoperador, $arrayContr) {
        if ($arrayContr == null) {
        
            $contratos = array();
            $contratos[$parcnegocio][] = $nrseqcontrato;
        }
        else{
            $contratos = $arrayContr;
        }
        
        $caminhoArquivos = $this->docContratoService->gerarDocumentoContratoRescisao($contratos, $nrtiporescisao, $nrorg, 'E', 'P');
        
        foreach ($caminhoArquivos as $caminho) {
            foreach ($caminho as $chave => $arq) {
                if($arq["DADOSDOCUMENTO"]){
                
                    $arquivo = $arq["DADOSDOCUMENTO"]["DSCAMINHOARQ"];  
                    $nome = $arq["DADOSDOCUMENTO"]["NMARQUIVO"];
                    $tipo = $arq["DADOSDOCUMENTO"]["TYPE"];
                    
                    $tamanho = filesize($arq["DADOSDOCUMENTO"]["DSCAMINHOARQ"]);
                    
                    $conteudo = @file_get_contents($arquivo);
                    
                    $file = Utilities::uploadArquivoFileServer($this->zhFileUploader, "anexo_contrato", $arquivo);

                    $caminhoNovo = $file["path"];
                    
                    foreach ($contratos as $indice => $contrato) {
                
                        foreach($contrato as $cont){
                        
                            $nranexocontrato = $this->newCode->getCodeByTableName("FCT_ANEXOCONTRATO", $nrorg, 1, 10, true);
                            
                            $params = array(
                                "NRANEXOCONTRATO" => $nranexocontrato, 
                                "NRSEQCONTRATO"   => $cont, 
                                "NMARQUIVO"       => $nome, 
                                "DSCAMINHO"       => $caminhoNovo, 
                                "DSTIPO"          => $tipo, 
                                "VRTAMANHO"       => $tamanho, 
                                "NRORG"           => $nrorg,
                                "OPERADOR"        => $cdoperador,
                                "NRTIPOANEXO"     => null
                            );
                            
                            $this->contratoFactory->SaveAnexoDocContratoRescindido($params);
                        }
                    }
                }
            }
        }
            
    }
    
    /* Encerrar o contrato em massa */
    public function encerrarContratoEmMassa($dadosrescisao, $contratos, $idDocX, $nrorg, $operador){
        $arrDosContratosRescindidos = array();
        $dadosRetornados = array();
        
        foreach ($contratos as $contrato) {
            
            /*$validaEscopoExcOm - Parâmetro para validar se o escopo pode desabilitat os produtos / elementos no OM. 
            A função faz um count na tabela de parametrização, portanto, se ">0" é por que o escopo está inserido na tabela.*/
            
            $validaEscopoExcOm = $this->validarEscopoExclusaoOM($contrato["NRSEQCONTRATO"], $nrorg);
            
            if ($validaEscopoExcOm > 0) {
                $dadosRetornados = $this->desabilitarProdutoNoOM($contrato["NRSEQCONTRATO"], $operador, $nrorg);
            }
            
            if (count($dadosRetornados) > 0) {
                $arrDosContratosRescindidos[$contrato["NRSEQCONTRATO"]] = $dadosRetornados;
            }
        }  
        
        if(count($arrDosContratosRescindidos) > 0)
            $this->atualizarRescisao($arrDosContratosRescindidos, $nrorg, true);
        
        $this->connection->beginTransaction();
        try {
            $dtpedrescisaocontr  = $dadosrescisao["DTPEDRESCISAOCONTR"];
            $dtrecisaocontr      = $dadosrescisao["DTRECISAOCONTR"];
            $idtpexclusaoparcela = $dadosrescisao["IDTPEXCLUSAOPARCELA"];
            $nrmotivorescisao    = $dadosrescisao["NRMOTIVORESCISAO"];
            $nrtiporescisao      = $dadosrescisao["NRTIPORESCISAO"];
            $vrpendenciafin      = $dadosrescisao["VRPENDENCIAFIN"];
            $dsjustificaencerra  = $dadosrescisao["DSJUSTIFICAENCERRA"];
            
            $parcArray = array();
            
            foreach($contratos as $contrato){
                
                $this->executarProcedureFctEncerraContrato($contrato["NRSEQCONTRATO"], $operador, $nrorg, $dtrecisaocontr, $idtpexclusaoparcela);
                
                if ($contrato["IDSITUACAOCONTRATO"] == "A") {
                    $this->atualizaDocumentoSituacao($contrato["NRSEQCONTRATO"], $nrorg, 'E');
                    
                    $params = array(
                        "DTPEDRESCISAOCONTR" => $dtpedrescisaocontr, 
                        "DTRECISAOCONTR"     => $dtrecisaocontr,
                        "NRMOTIVORESCISAO"   => $nrmotivorescisao,
                        "NRTIPORESCISAO"     => $nrtiporescisao,
                        "VRPENDENCIAFIN"     => $vrpendenciafin,
                        "DSJUSTIFICAENCERRA" => $dsjustificaencerra,
                        "NRORG"              => $nrorg,
                        "OPERADOR"           => $operador,
                        "IDSITUACAORESCISAO" => 'C',
                        "IDTPEXCLUSAOPARCELA"=> $contrato["IDTPEXCLUSAOPARCELA"],
                        "NRSEQCONTRATO"      => $contrato["NRSEQCONTRATO"]
                    );
                    
                    $this->contratoFactory->atualizarDadosRescisaoContrato($params);
                    
                    $this->DeletaAgendPendenteContratoEncerrado($contrato["NRSEQCONTRATO"], $nrorg);
                    
                    $this->inativaParcNegocio($contrato["NRPARCNEGOCIO"], $nrorg, $operador);
                    
                    if (isset($arrDosContratosRescindidos[$contrato["NRSEQCONTRATO"]]) && count($arrDosContratosRescindidos[$contrato["NRSEQCONTRATO"]]) > 0) {
                        $this->integracaoOmService->desabilitarElementosNoOm($arrDosContratosRescindidos[$contrato["NRSEQCONTRATO"]], $nrorg);
                    }
                    
                    $this->excluirDocumentoCertsign($contrato["NRSEQCONTRATO"], $nrorg, $operador);
                }
                
                $parcArray[$contrato["NRPARCNEGOCIO"]][] = $contrato["NRSEQCONTRATO"];
                
            }
            
            /* Anexar nos anexos do contrato */
            $this->anexarDocumentoRescindidoContrato(null, null, $nrtiporescisao, $nrorg, $operador, $parcArray);
            
            $this->connection->commit();
            return $parcArray;
        }
        catch (\Exception $e) {
            $this->connection->rollBack();
            throw $e;
        }
    }
    
    
    /* Inativar o parceiro de negócio caso não hajam mais contratos ativos. */
    public function inativaParcNegocio($parcNegocio, $nrorg, $operador){
        try {
            $params = array(
                "NRPARCNEGOCIO" => $parcNegocio, 
                "NRORG"         => $nrorg
            );
            
            $valida = $this->contratoFactory->validaContratosAtivos($params);
            
            if ($valida == 0){
               
                /* --- Inativa Parceiro de Negócio  --- */
                $params = array(
                    "NRORG"         => $nrorg,
                    "OPERADOR"      => $operador,
                    "NRPARCNEGOCIO" => $parcNegocio
                ); 
                
                $this->contratoFactory->updateInativaParcnegocio($params);
                
                /* --- Inativa a Parceria de Cliente  --- */
                $params = array(
                    "NRORG"         => $nrorg,
                    "OPERADOR"      => $operador,
                    "NRPARCNEGOCIO" => $parcNegocio
                ); 
                
                $this->contratoFactory->updateInativaParceriaCliente($params);
                
                /* --- Inativa Cliente  --- */
                $params = array(
                    "NRORG"         => $nrorg,
                    "OPERADOR"      => $operador,
                    "NRPARCNEGOCIO" => $parcNegocio
                ); 
                
                $this->contratoFactory->updateInativaCliente($params);
                
            }
            
        }
        catch (\Exception $e) {
            throw $e;
        }
    }
    
    
    /**
     * Valida se é necessário filtrar os serviços na inserção de contratos manuais
    **/
    public function validaFiltroServico($tipoorcamento, $nrorg){
            
        $params = array(
            "NRTIPOORCAMENTO" => $tipoorcamento,
            "NRORG"           => $nrorg
        );
        
        $count = $this->contratoFactory->countServicos($params);
            
        if ($count > 0) {
            
            $filtrar = $this->contratoFactory->validaFiltroServico($params);
        }
        else {
           $filtrar = 'N'; 
        }
        
        return $filtrar;
    }
    
    /**
     * A função "aprovarContrMassa" realiza a aprovação de diversos contratos
     */
    public function aprovarContrMassa($contratos, $nrorg, $operador) {
        $arrayErros = array();
        $qtErros = 0;
        
        $result = array(); // array dos itens que foram inseridos na rotina de geração de contrato automático de serviço

        foreach ($contratos as $contrato) {
            
            $params = array(
                "NRPARCNEGOCIO" => $contrato["NRPARCNEGOCIO"],
                "NRORG"          => $nrorg
            );

            $tipoParc = $this->contratoFactory->getTipoParceiro($params);
            
            if ($tipoParc =='FORNECEDOR') {
                $this->salvarAprovacao($contrato["NRSEQCONTRATO"], $nrorg, $operador);   
            }
            else {
                $erroRotina = null;
                
                $nrseqcontrato      = $contrato["NRSEQCONTRATO"];
                $nrContratoFct      = $contrato["NRCONTRATOFCT"];
                $nrParcNegocio      = $contrato["NRPARCNEGOCIO"];
                $nrSeqOrcamento     = $contrato["NRSEQORCAMENTO"];
                $idSituacaoContrato = $contrato["IDSITUACAOCONTRATO"];
                
                if (($idSituacaoContrato == 'P') || ($idSituacaoContrato == 'D')) {
                    
                    $negValores = $this->validarNegociacaoValores($nrseqcontrato);
                    
                    if ($negValores == true){
                        
                        $aprovCertisign = $this->validaAprovacaoCertsign($nrseqcontrato, $nrorg);
                        
                        if ($aprovCertisign == 'OK'){

                            if ($nrSeqOrcamento != null) {
                                $params = array(
                                    "NRSEQORCAMENTO" => $nrSeqOrcamento,
                                    "NRORG"          => $nrorg
                                );
                                
                                $idPropAlimenticia = $this->contratoFactory->verificaPropostaAlimenticia($params);
                            }
                            else {
                                $idPropAlimenticia = 'N';
                            }
                            
                            if ($idPropAlimenticia == 'S') {
                                $this->salvarAprovacao($nrseqcontrato, $nrorg, $operador);   
                                $retornoContrAuto = $this->gerarContratoParaFaturamentoDeServicos($nrParcNegocio, $nrseqcontrato);
                                if ($retornoContrAuto)
                                    $result[] = $retornoContrAuto;
                            }
                            else {
                                $integracaoFM =  $this->integracaoFmService->integraLocalAtend($nrseqcontrato, $nrorg, $operador);
                                if ($integracaoFM == 'OK'){

                                    $integracaoTecfood =  $this->integracaoTecfoodService->integraServicosTecfood($nrseqcontrato, $nrorg, $operador);
                                    if ($integracaoTecfood == 'OK'){
                                        
                                        $this->salvarDadosMedidaContrato($nrseqcontrato, $nrorg, $operador);
                                        $integracao = $this->IntegracaoOMeGeraParcela($nrseqcontrato, $nrSeqOrcamento, $nrorg);
                                        
                                        if ($integracao == 'OK') {
                                            $this->salvarAprovacao($nrseqcontrato, $nrorg, $operador);
                                            //contrato gerado automaticamente para serviços e faturamento
                                            $retornoContrAuto = $this->gerarContratoParaFaturamentoDeServicos($nrParcNegocio, $nrseqcontrato);
                                            if ($retornoContrAuto)
                                                $result[] = $retornoContrAuto;
                                        }
                                        else {
                                            $erroRotina = $integracao;
                                        }
                                    }
                                    else {
                                        $erroRotina ="Operação bloqueada! " . $integracaoTecfood;
                                    }
                                }
                                else {
                                    $erroRotina = "Ocorreu uma falha na integração dos locais de atendimento do módulo 'SM' para o módulo 'FM'. Motivo: " . $integracaoFM;
                                }
                            }
                        }
                        else {
                            $erroRotina = 'Existem assinaturas eletrônicas ou digitais pendentes ou rejeitadas.';
                        }
                    }
                    else {
                        $erroRotina = 'Os itens da aba "Negociação de Valores" que são de parcelamento não estão com as parcelas criadas corretamente: o valor total da soma das parcelas deve ser igual ao valor do item.';
                    }
                }
                else {
                    $erroRotina = 'Só é permitido aprovar contratos que estejam com a situação "Pendente" ou "Documento Enviado"';
                }
                
                if ($erroRotina != null) {
                    $qtErros = $qtErros+1;
                    
                    $params = array(
                        "NRPARCNEGOCIO" => $nrParcNegocio,
                        "NRORG"         => $nrorg
                    );
                                    
                    $nmParceiro = $this->contratoFactory->recebeNomeParceiro($params);
                    
                    $arrayErros[] = array(
                        "NRCONTRATOFCT" => $nrContratoFct,
                        "NMPARCNEGOCIO" => $nmParceiro,
                        "ERRO" => $erroRotina
                    );
                }

                $a = 0;
                if ($a == 0) {
                    $paramsAux = array (
                        "NRSEQCONTRATO" => $contrato["NRSEQCONTRATO"]
                    );
                    $dataset = $this->contratoFactory->getQuantidadeItensMoedaDiferenteContrato($paramsAux);
                    if ($dataset[0]["QTD"] > 0) {
                        $params = array(
                            "NRPARCNEGOCIO" => $nrParcNegocio,
                            "NRORG"         => $nrorg
                        );
                                        
                        $nmParceiro = $this->contratoFactory->recebeNomeParceiro($params);
                        
                        $arrayErros[] = array(
                            "NRCONTRATOFCT" => $nrContratoFct,
                            "NMPARCNEGOCIO" => $nmParceiro,
                            "ERRO" => "Os itens dos contratos selecionados foram inseridos com uma moeda diferente da moeda atual do contrato. Favor atualizar o valor dos itens.",
                        ); 

                        $qtErros = $qtErros+1;
                    }
                }
            }
        }
        
        $retorno = array(
            "QTERROS" => $qtErros,
            "ERROS" => $arrayErros,
            "ITENS" => $result
        );
        
        return $retorno;
    }
    
    
    public function IntegracaoOMeGeraParcela($nrseqcontrato, $nrSeqOrcamento, $nrorg) {
        try{
            $operador = $this->environment->getCdOperador();
            $idUtilizaComp = null;
            
            $params = array(
                "NRSEQCONTRATO" => $nrseqcontrato,
                "NRORG"         => $nrorg
            );
                
            $recebeIdUtilizaComp = $this->contratoFactory->recebeIdUtilizaComp($params);
            $utilizaComp = $recebeIdUtilizaComp[0]['UTILIZACOMP'];
            
            if ($utilizaComp > 0) {
                
                $idUtilizaComp = 'S';
                //Envia os Elementos para o OM
                $this->integracaoOmService->integracaoOM($nrSeqOrcamento, $nrorg, $idUtilizaComp, false, $nrseqcontrato, false); 
            }
            
            $this->executarProcedureFctGerarParcelasFatura($nrseqcontrato, $nrorg, $operador);
                        
            return "OK";
        }
        catch(\Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function salvarAprovacao($nrseqcontrato, $nrorg, $operador) {
        $novoCodigo = $this->newCode->getCodeByTableName("FCT_APROVACONTRATO", $nrorg, 1, 10, true);
        
        $params = array(
            "NRSEQAPROVCONT" => $novoCodigo,
            "NRSEQCONTRATO"  => $nrseqcontrato,
            "NRORG"          => $nrorg,
            "OPERADOR"       => $operador
        );
        
        $this->contratoFactory->insereAprovacaoContrato($params);
        
        $params = array(
            "NRORG"         => $nrorg,
            "OPERADOR"      => $operador,
            "NRSEQCONTRATO" => $nrseqcontrato
        );
        
        $this->contratoFactory->atualizaContratoAprovacao($params);
    }
    
    /**
     * A função "regerarFaturaMassa" regera o faturamento de diversos contratos
     */
    public function regerarFaturaMassa($contratos, $nrorg, $operador) {
        $arrayErros = array();
        $qtErros = 0;
        
        foreach ($contratos as $contrato) {
            
            $erroRotina = null;
            
            $nrseqcontrato      = $contrato["NRSEQCONTRATO"];
            $nrContratoFct      = $contrato["NRCONTRATOFCT"];
            $nrParcNegocio      = $contrato["NRPARCNEGOCIO"];
            $idSituacaoContrato = $contrato["IDSITUACAOCONTRATO"];
            
            if ($idSituacaoContrato == "A") {
                try {
                    $this->executarProcedureFctGerarParcelasFatura($nrseqcontrato, $nrorg, $operador);
                }
                catch (\Exception $e) {
                    $erroRotina = $e->getMessage();
                }
            }
            else {
                $erroRotina = 'Só é permitido regerar faturamento de contratos que estejam com a situação "Aprovado"';
            }
            
            if ($erroRotina != null){
                
                $qtErros = $qtErros+1;
                
                $params = array(
                    "NRPARCNEGOCIO" => $nrParcNegocio,
                    "NRORG"         => $nrorg
                );
                                
                $nmParceiro = $this->contratoFactory->recebeNomeParceiro($params);
                
                $arrayErros[] = array(
                    "NRCONTRATOFCT" => $nrContratoFct,
                    "NMPARCNEGOCIO" => $nmParceiro,
                    "ERRO" => $erroRotina
                );
            }
        }
        
        $retorno = array(
            "QTERROS" => $qtErros,
            "ERROS" => $arrayErros
        );

        return $retorno;
    }
        
     /* verifica se um contrato tem parcelas já faturadas. 
     * Caso positivo, exclui as parcelas e retorna a mensagem falando quaanto ja foi faturado
     */
    public function verificarParcelasContReneg($nrseqcontrato, $nrorg) {
       
        
        /* Recebe dados do contrato versionado */
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        
        $contratoVers = $this->contratoFactory->recebeDadosContratoVersionado($params);
        
        $nrseqcontratoVers = $contratoVers[0]["NRSEQCONTRATO"];
        $dsObsContrVers = $contratoVers[0]["NRSEQCONTRATO"];
        
       
       /* Recebe dados das negociaçoes de contrato do tipo Parcelamento */
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        
        $dadosNegociacao = $this->contratoFactory->recebeDadosNegociacao($params);
        
        $retorno = 'OK';
        $msgObservacao = null;
        
        foreach($dadosNegociacao as $negociacao){
            
            $vrfaturado = 0;
            
            /* Verifica se ja foram apuradas parcelas */
            $params = array(
                "NRSEQCONTRATO"    => $nrseqcontrato,
                "CDTIPOOPERFATURA" => $negociacao['CDTIPOOPERFATURA'],
                "CDSERIENF"        => $negociacao['CDSERIENF'],
                "CDEMPRESA"        => $negociacao['CDEMPRESA'],
                "CDINSCESTA"       => $negociacao['CDINSCESTA'],
                "CDINSCMUNI"       => $negociacao['CDINSCMUNI'],
                "NRORG"            => $nrorg
            );
            
            $vrfaturado = $this->contratoFactory->recebeValorFaturado($params);
            
            if ($vrfaturado > 0){
                
                /* Deleta a configuração de parcelas referente à negociação */
                
                $params = array(
                    "NRSEQCONTRATO"    => $nrseqcontratoVers,
                    "CDTIPOOPERFATURA" => $negociacao['CDTIPOOPERFATURA'],
                    "CDSERIENF"        => $negociacao['CDSERIENF'],
                    "CDEMPRESA"        => $negociacao['CDEMPRESA'],
                    "CDINSCESTA"       => $negociacao['CDINSCESTA'],
                    "CDINSCMUNI"       => $negociacao['CDINSCMUNI'],
                    "NRORG"            => $nrorg
                );
                
                $nrNegociacao = $this->contratoFactory->recebeNegociacaoParcelas($params);
                
                $params = array(
                    "NRNEGOCIACAOCONTRATO" => $nrNegociacao,
                    "NRORG"                => $nrorg
                );
                
                $this->contratoFactory->deleteParcelasParamNegociacao($params);
                
                
                /* Recebe mensagem de  retorno e de Observação */
                
                $vrfaturadoFormat =  Utilities::formatarNumero($vrfaturado);
                
                if ($retorno == 'OK') { 
                    
                    
                    $retorno = 'A renegociação do contrato foi realizada. <br><br> Obs: O contrato de origem possuia negociações com parcelas já apuradas.  Favor recriar a parametrização das parcelas considerando o valor já apurado. <br><br>'.$negociacao['DESCRICAO'].' - '.$vrfaturadoFormat;
                } 
                else {
                    
                    $retorno = $retorno.'<br>  '.$negociacao['DESCRICAO'].' - '.$vrfaturadoFormat;
                }
                
                
                if ($msgObservacao = null) { 
                    
                    
                    $msgObservacao = $negociacao['DESCRICAO'].' - '.$vrfaturadoFormat;
                } 
                else {
                    
                    
                    $msgObservacao = $msgObservacao."\n".$negociacao['DESCRICAO'].' - '.$vrfaturadoFormat;
                }
            }
            
            
  
        }
        
        /* Atualiza Observação do contrato */
        if ($msgObservacao != null) { 
        
            $msgObservacao = 'A renegociação do contrato foi realizada. Porém, o contrato de origem possuia negociações com parcelas já apuradas.  Favor recriar a parametrização das parcelas considerando o valor já apurado: '.$msgObservacao;
        
            if ($dsObsContrVers == null) {
                
                $observacao = $msgObservacao;
            }
            else {
               
                $observacao = $dsObsContrVers."\n".'/ ---------------------------- /'."\n"."\n".$msgObservacao;
            }
            
            $params = array(
                "DSOBSERVACAOCONT" => $observacao,
                "NRSEQCONTRATO" => $nrseqcontratoVers,
                "NRORG"         => $nrorg
            );
            
            $this->contratoFactory->atualizaObsContratoVers($params);
            
        }
        
        return $retorno;
    }
    
    public function getUtilizaComposicaoServico($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
            
        $recebeIdUtilizaComp = $this->contratoFactory->recebeIdUtilizaComp($params);
        $utilizaComp = (int)$recebeIdUtilizaComp[0]['UTILIZACOMP'];
        return $utilizaComp > 0;
    }
    
    /**
     * A função "insereOperadoresNotifica" realiza a inserção dos operadores do sistema que devem ser notificados.
     */
    public function insereOperadoresNotifica($nrassdigitalcontr, $operadores) {
        $nrorg = $this->environment->getNrOrg();
        $operador = $this->environment->getCdOperador();
       
        /* -- Deleta os registros antigos -- */
        $params = array(
            "NRASSDIGITALCONTR" => $nrassdigitalcontr,
            "NRORG"             => $nrorg
        );
      
        $this->contratoFactory->deletaOperadoresNotifica($params);
        
        foreach ($operadores as $cdoperdor) {
            $nrrelopernotifassele = $this->newCode->getCodeByTableName("FCT_RELACOPERNOTIFASSELE", $nrorg, 1, 10, true);
            $params = array(
                "NRRELOPERNOTIFASSELE" => $nrrelopernotifassele,
                "NRASSDIGITALCONTR"    => $nrassdigitalcontr,
                "CDOPERADOR"           => $cdoperdor,
                "NRORG"                => $nrorg,
                "OPERADOR"             => $operador
            );
          
            $this->contratoFactory->insereOperadoresNotifica($params);
        }
    }
    
    public function recebeOrdenacaoENotificacoes($nrseqmodcontra, $idtpsignatario, $nrorg){
        $retorno = array();
       
        $params = array(
            "NRSEQMODCONTRA" => $nrseqmodcontra, 
            "IDTPSIGNATARIO" => $idtpsignatario,
            "NRORG"          => $nrorg
        );
      
        $dados = $this->contratoFactory->recebeOrdenacaoENotificacoes($params);
        if (count($dados) != 0) {
            $retorno['DADOS'] = 'OK';
            $retorno['NRORDENACAO']        = $dados[0]['NRORDENACAO'];
            $retorno['DSEMAILNOTSIGNENV']  = $dados[0]['DSEMAILNOTSIGNENV'];
            $retorno['DSEMAILNOTIFOUTROS'] = $dados[0]['DSEMAILNOTIFOUTROS'];
           
            $nrsignatpadrcont = $dados[0]['NRSIGNATPADRCONT'];
           
            $params = array(
                "NRSIGNATPADRCONT" => $nrsignatpadrcont, 
                "NRORG"            => $nrorg
            );
           
            $operadores = $this->contratoFactory->recebeOperdoresNotificacoes($params);
           
            foreach ($operadores as $operador) {
                $retorno['OPERADORES'][] = $operador["CDOPERADOR"];
            }
        }
        else {
            $retorno['DADOS'] = 'VAZIO';
        }
       
        return $retorno;
    }
    
    public function replicarNegociacaoContrato($nrseqcontrato, $nrseqcontratopai, $nrorg, $operador) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontratopai,
            "NRORG"         => $nrorg
        );
        $itensContrato = $this->contratoFactory->getItensContratos($params);
        
        foreach ($itensContrato as $item) {
            if (!empty($item["NRITEMCONTRATOPAI"]) && !empty($item["IDELEMENTO"])) {
                
                $params["NRITEMOCONTRATO"] = $item["NRITEMCONTRATOPAI"];
                $params["NRITEMELEMENTO"] = $item["NRITEMOCONTRATO"];
                $dataset = $this->negociacaoContratoFactory->getNegociacaoContratoAprovadoFiltrandoItem($params);
                if (count($dataset) > 0) {
                    $negociacao = $dataset[0];
                    
                    $itemEquivalente = $this->getItemContratoElementoEquivalente($nrseqcontrato, $nrorg, $item["CDSERVORCA"], $item["IDELEMENTO"], $item["CDTPMEDIDASERV"]);
                    if (!is_null($itemEquivalente)) {
                        $this->insereNegociacaoComParcelas($nrseqcontrato, $negociacao, $itemEquivalente, $nrorg, $operador);
                    }
                }
            }
            else {
                $params["NRITEMOCONTRATO"] = $item["NRITEMOCONTRATO"];
                $params["NRITEMELEMENTO"] = null;
                $dataset = $this->negociacaoContratoFactory->getNegociacaoContratoAprovadoFiltrandoItem($params);
                
                if (count($dataset) > 0) {
                    $negociacao = $dataset[0];
                    
                    $itemEquivalente = $this->getItemContratoElementoEquivalente($nrseqcontrato, $nrorg, $item["CDSERVORCA"], $item["IDELEMENTO"], $item["CDTPMEDIDASERV"]);
                    if (!is_null($itemEquivalente)) {
                        $this->insereNegociacaoComParcelas($nrseqcontrato, $negociacao, $itemEquivalente, $nrorg, $operador);
                    }
                }
            }
        }
    }
    
    public function getItemContratoElementoEquivalente($nrseqcontrato, $nrorg, $cdservorca, $idelemento, $cdtpmedidaserv) {
        $params = array(
            "NRSEQCONTRATO"   => $nrseqcontrato,
            "NRORG"           => $nrorg,
            "CDSERVORCA"      => $cdservorca,
            "CDTPMEDIDASERV"  => $cdtpmedidaserv
        );
        
        if (!empty($idelemento)) {
            $params["IDELEMENTO"] = $idelemento;
            $dataset = $this->contratoFactory->getItemContratoElemento($params);
        }
        else {
            $dataset = $this->contratoFactory->getItemContratoServico($params);
        }
        
        return (count($dataset) > 0) ? $dataset[0] : null;
    }
    
    public function insereNegociacaoComParcelas($nrseqcontrato, $negociacao, $item, $nrorg, $operador) {
        $nrnegcontrato = $this->newCode->getCodeByTableName("FCT_NEGCONTRATO", $nrorg, 1, 10, true);
        $params = array(
            "NRNEGCONTRATO"       => $nrnegcontrato,
            "NRPARCNEGOCIO"       => $negociacao["NRPARCNEGOCIO"],
            "NRAGRUPAMENTO"       => $negociacao["NRAGRUPAMENTO"],
            "IDTPFATURA"          => $negociacao["IDTPFATURA"],
            "CDFILIAL"            => $negociacao["CDFILIAL"],
            "NRPARCFATURA"        => $negociacao["NRPARCFATURA"],
            "CDTIPOOPERFATURA"    => $negociacao["CDTIPOOPERFATURA"],
            "CDSERIENF"           => $negociacao["CDSERIENF"],
            "CDEMPRESA"           => $negociacao["CDEMPRESA"],
            "CDINSCESTA"          => $negociacao["CDINSCESTA"],
            "CDINSCMUNI"          => $negociacao["CDINSCMUNI"],
            "NRSEQCONTRATO"       => $nrseqcontrato,
            "NRITEMOCONTRATO"     => !empty($item["NRITEMCONTRATOPAI"]) ? $item["NRITEMCONTRATOPAI"] : $item["NRITEMOCONTRATO"],
            "NRITEMELEMENTO"      => !empty($item["NRITEMCONTRATOPAI"]) ? $item["NRITEMOCONTRATO"] : null,
            "DSVARIAVELNEGOCIA"   => $negociacao["DSVARIAVELNEGOCIA"],
            "IDTIPONEGOCIA"       => $negociacao["IDTIPONEGOCIA"],
            "DSOBSNEGOCIA"        => $negociacao["DSOBSNEGOCIA"],
            "IDATIVO"             => $negociacao["IDATIVO"],
            "NRORG"               => $nrorg,
            "OPERADOR"            => $operador,
            "NRORG"               => $nrorg,
            "CDOPERSOLICINEGOCIA" => $negociacao["CDOPERSOLICINEGOCIA"],
            "NRMOTIVOPARALISACAO" => $negociacao["NRMOTIVOPARALISACAO"]
        );
        $this->negociacaoContratoFactory->saveDadosNegContrato($params);
        
        
        $params = array(
            "NRNEGCONTRATO" => $negociacao["NRNEGCONTRATO"],
            "NRORG"         => $nrorg
        );
        $parcelasNegociacao = $this->negociacaoContratoFactory->getParcelasNegociacaoContratoAprovado($params);
        foreach ($parcelasNegociacao as $parcela) {
            $nrparcelasnegcontr = $this->newCode->getCodeByTableName("FCT_PARCELASNEGCONTR", $nrorg, 1, 10, true);
            $params = array(
                "NRPARCELASNEGCONTR" => $nrparcelasnegcontr,
                "NRNEGCONTRATO"      => $nrnegcontrato,
                "DTINIPARCNEGOCIA"   => $parcela["DTINIPARCNEGOCIA"],
                "DTFIMPARCNEGOCIA"   => $parcela["DTFIMPARCNEGOCIA"],
                "IDMULTIPLICAQTMED"  => $parcela["IDMULTIPLICAQTMED"],
                "VRPARCELANEGOCIA"   => $parcela["VRPARCELANEGOCIA"],
                "IDATIVO"            => $parcela["IDATIVO"],
                "NRORG"              => $nrorg,
                "OPERADOR"           => $operador,
                "NRORG"              => $nrorg
            );
            $this->negociacaoContratoFactory->saveParcelasNegContrato($params);
        }
    }
    
    public function getDadosRescisaoContrato($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG" => $nrorg
        );
        
        $dataset = $this->contratoFactory->getDadosRescisaoContrato($params);
        return $dataset[0];
    }
    
    /**
     * Este procedimento é responsável por efetuar um SELECT pedindo a quantidade de itens de negociação sem produto para faturamento preenchido.
     * Retorna true quando existem ou false quando não existem.
     * @return {bool | boolean}
    */
    public function validarProdutoFaturamento($nrseqcontrato) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
        );
        
        $quantidadeNulos = $this->contratoFactory->validarProdutoFaturamento($params);
        return ($quantidadeNulos[0]["QTD"] > 0) ? true : false;
    }
    
    public function validaBloqueiaDataInicialContReneg($nrseqmodcontra, $nrorg) {
        $params = array(
            "NRSEQMODCONTRA" => $nrseqmodcontra,
            "NRORG" => $nrorg
        );
        
        $result = $this->contratoFactory->validaBloqueiaDataInicialContReneg($params);
        return $result[0];
    }
    
    public function desfazerRenovacaoDoContratoProcessoCompleto($nrseqcontrato, $nrseqprorrcont, $reajusteJunto, $nrorg, $cdoperador) {
        $this->connection->beginTransaction();
        try {
            $this->desfazerRenovacaoDoContrato($nrorg, $nrseqcontrato, $nrseqprorrcont, $reajusteJunto);
            $this->executarProcedureFctGerarParcelasFatura($nrseqcontrato, $nrorg, $cdoperador);
            $this->refazerIntegracaoOMPeriodoExtendido($nrseqcontrato, $nrorg);
            
            $this->connection->commit();
        }
        catch (\Exception $e) {
            $this->connection->rollBack();
            throw $e;
        }
    }
    
    public function desfazerReajusteDoContratoProcessoCompleto($nrseqcontrato, $nrseqprorrcont, $renovacaoJunto, $nrorg, $cdoperador) {
        $this->connection->beginTransaction();
        try {
            $this->desfazerReajusteDoContrato($nrorg, $nrseqcontrato, $nrseqprorrcont, $renovacaoJunto);
            $this->executarProcedureFctGerarParcelasFatura($nrseqcontrato, $nrorg, $cdoperador);
            
            if ($renovacaoJunto)
                $this->refazerIntegracaoOMPeriodoExtendido($nrseqcontrato, $nrorg);
            else
                $this->atualizarValorLinhaProduto($nrseqcontrato, $cdoperador, $nrorg);
            
            $this->connection->commit();
        }
        catch (\Exception $e) {
            $this->connection->rollBack();
            throw $e;
        }
    }
    
    public function desfazerRenovacaoDoContrato($nrorg, $nrseqContrato, $renovacao, $deveReajustar = true, $houveReajuste = null){
        try {
            //Busca o registro de VALORLINP do prazo que será desfeito. Se houver registro, ele deve ser excluído.
            $this->desfazerValorlinpContrato($nrseqContrato, $nrorg);
            
            //atualizo os valores do contrato baseado na renovacao
            $this->AtualizarRenovacaoContrato($nrseqContrato, $renovacao, $nrorg);

            //excluir a prorrog
            $params = array(
                "NRSEQPRORRCONT" => $renovacao,
                "NRORG" => $nrorg
            );
            $this->contratoFactory->excluirProrrog($params);
            
            //ver se tem reajuste
            if ($houveReajuste == null)
                $houveReajuste = $this->possuiDadosDeReajuste($nrorg,$nrseqContrato);
            
            //tendo reajuste desfaz 
            if ($deveReajustar && $houveReajuste != null)
                $this->desfazerReajusteDoContrato($nrorg,$nrseqContrato, $renovacao, false);
        }
        catch(\Exception $e){
            throw $e;
        }
    }
    
    public function refazerIntegracaoOMPeriodoExtendido($nrseqcontrato, $nrorg) {
        $utilizaComposicao = $this->getUtilizaComposicaoServico($nrseqcontrato, $nrorg);
        if ($utilizaComposicao) {
            $this->integracaoOmService->integracaoOM(null, $nrorg, 'S', true, $nrseqcontrato, false); 
        }
    }
    
    public function AtualizarRenovacaoContrato($nrseqcontrato, $nrseqprorr,$nrorg){
        try{
            //pegar a data
            $params = array(
                "NRSEQPRORRCONT" => $nrseqprorr,
                "NRORG" => $nrorg
            );
            $datas = $this->contratoFactory->getDatasProrrogContrato($params);
            if(!empty($datas[0]["DTANTDTFINAL"])){
                //mandar a data
                $params = array(
                    "NRSEQCONTRATO" => $nrseqcontrato,
                    "NRORG" => $nrorg,
                    "DTFIM" => $datas[0]["DTANTDTFINAL"],
                    "DTINICIO" => $datas[0]["DTANTDTINICIAL"]
                );
                $this->contratoFactory->atualizarRenovacaoContrato($params); 
            } 
        } catch(\Exception $e){
            throw $e;
        }
    }
    
    /**
    * Função auxiliar que serve para determianr se um reajuste existe em uma renovação.
    * @params $nrorg o número da organização atual 
    * @params $nrSeqContrato o número do contrato em questão
    * @return {bool} Essa renovação possui dados de reajuste? true se tiver, false se não tiver
    */
    public function possuiDadosDeRenovacao($nrorg, $nrseqContrato){
        try{
            $params = array(
                "NRORG" => $nrorg,
                "NRSEQCONTRATO" => $nrseqContrato
            );
            $houveReajuste = $this->contratoFactory->getDadosRenovacaoContrato($params);
            return  (count($houveReajuste) > 0) ? $houveReajuste[0] : null;
        } catch(\Exception $e){
            throw $e;
        }
    }
    
    
    /**
    * Função que determina se existe algum contrato de reajuste abserado no contrato em questão
    * @params $nrorg o número da organização atual 
    * @params $nrSeqContrato o número do contrato em questão
    * @return {bool} Esse contrato possui dados de reajuste? true se tiver, false se não tiver
    */
    public function possuiReajusteJunto($nrorg, $nrSeqContrato){
        try{
            $params = array(
                "NRSEQCONTRATO" => $nrSeqContrato,
                "NRORG" => $nrorg 
            );
            $reajuste = $this->contratoFactory->getDadosReajusteContrato($params); 
            return (!empty($reajuste) ? true : false);
        } catch(\Exception $e){
            throw $e;
        }
    }
    
    
    /**
    * Função que determina se existe algum contrato de reajuste abserado no contrato em questão
    * @params $nrorg o número da organização atual 
    * @params $nrSeqContrato o número do contrato em questão
    * @return {bool} Esse contrato possui dados de reajuste? true se tiver, false se não tiver
    */
    public function possuiDadosDeReajuste($nrorg, $nrSeqContrato){
        try{
            $params = array(
                "NRSEQCONTRATO" => $nrSeqContrato,
                "NRORG" => $nrorg 
            );
            $reajuste = $this->contratoFactory->getDadosReajusteContrato($params); 
            return ((count($reajuste) > 0)  ? $reajuste[0] : false);
        } catch(\Exception $e){
            throw $e;
        }
    }
    
    /**
    * Essa função é chamada ao desfazer o reajuste de um contrato. 
    * Essa função só pode ser chamada no momento que possui um contrato já reajustado.
    */
    public function desfazerReajusteDoContrato($nrorg, $nrSeqContrato, $nrseqprorr = null, $deveRenovar = true){
        try{
            $cdoperador = $this->environment->getCdOperador();
            
            $elementosDoContrato = array();
            $params = array(
                "NRORG" => $nrorg,
                "NRSEQCONTRATO" => $nrSeqContrato
            );
            $contratosDeReajustes = $this->contratoFactory->getDadosReajusteContrato($params); 
            foreach($contratosDeReajustes as $contrato){
                $nrorga = $contrato["NRORG"];
                $nrultimoReajuste = $contrato["NRULTIMOREAJUSTE"];
                $params = $this->gerarParamsDesfazerReajuste($nrorga, $nrultimoReajuste);
                // pegar ITEMCONTRATO_HR
                $itemContrato = $this->contratoFactory->getItemContratoHistorico($params);
                // pegar ITNEGCIACAO_HR
                $itensNegociacao = $this->contratoFactory->getItensNegociacaoHistorico($params);
                // pegar NEOGICACAOCONTRATO_HR
                $negociacaoContrato = $this->contratoFactory->getNegociacaoContrato($params);
                // pegar PARCELANEGOCONT_HR
                $parcelaNegoCont = $this->contratoFactory->getParcelasNegociacoHistorico($params);
               // Objeto responsavel por conter dado de todos os historicos relacionados com esse contrato 
                $elementoDoContrato = array(
                    "CONTRATO"             => $contrato,
                    "ITEMCONTRATO"         => $itemContrato,
                    "ITNEGOCIACAOCONTRATO" => $itensNegociacao,
                    "NEGOCIACAOCONTRATO"   => $negociacaoContrato,
                    "PARCELANEGOCONT"      => $parcelaNegoCont
                );
                $this->AtualizarContrato($elementoDoContrato);
                $this->LimpezaHistoricoContrato($elementoDoContrato,$params, $nrSeqContrato);
                $params = array(
                    "NRSEQCONTRATO" => $nrSeqContrato,
                    "NRORG" => $nrorg
                );
                $negociacoesContrato = $this->contratoFactory->getNegociacoesContrato($params);
                foreach ($negociacoesContrato as $negoCont) {
                    $nrnegociacaocontrato = $negoCont["NRNEGOCIACAOCONTRATO"];
                    $valorNegociacao = $negoCont["VRTOTITEMCOMDESC"];
                    // Atualiza os registros da aba de Desconto por Periodo com o valor novo
                    $this->atualizarValoresDescontoPorPeriodoDaNegociacao($valorNegociacao, $nrnegociacaocontrato, $nrorg, $cdoperador);
                }
                
                if ($deveRenovar && $nrseqprorr != null) {
                    $this->desfazerRenovacaoDoContrato($nrorg, $nrSeqContrato, $nrseqprorr, false, $nrultimoReajuste );
                }
            }
        } catch(\Exception $e){
            throw $e;
        }
        
    }
    
    /**
     * Limpar as tabelas de históricos relacionadas a um histórico
     * Cada elemento do contrato precisa de ser removido desse array para efetuar a limpeza
    */
    private function LimpezaHistoricoContrato($elemento, $params, $nrseqcontrato = null){
       try{
            foreach($elemento["ITEMCONTRATO"] as $item){
                $this->contratoFactory->excluiItemContratoHistorico($params);
            }
            foreach($elemento["ITNEGOCIACAOCONTRATO"] as $itNego){
                $this->contratoFactory->excluiItensNegociacoHistorico($params);
            }
            foreach($elemento["NEGOCIACAOCONTRATO"] as $negociacao){
                $this->contratoFactory->excluiNegociacaoContrato($params);
            }
            foreach($elemento["PARCELANEGOCONT"] as $parcela){
                $this->contratoFactory->excluiParcelasNegociacoHistorico($params);
            }
            foreach($elemento["CONTRATO"] as $contrato){
                $parms = array(
                    "NRULTIMOREAJUSTE"  => $params["NRULTIMOREAJUSTE"],
                    "NRORG"             => $params["NRORG"],
                    "NRSEQCONTRATO"     => $nrseqcontrato
                );
                $this->contratoFactory->atualizaUltimoReajusteContrato($parms);
                $this->contratoFactory->excluiUltimoReajusteContratoReajuste($params);
            }
        } catch(\Exception $e){
            throw $e;
        }
    }
    
    private function AtualizarContrato($elemento){
       try{
            $nrorg = $elemento["CONTRATO"]["NRORG"];
            foreach($elemento["ITEMCONTRATO"] as $item){
                $params = array(
                    "NRORG"=>$nrorg,
                    "NRITEMOCONTRATO" => $item["NRITEMOCONTRATO"],
                    "IDATIVO"=>$item["IDATIVO"],
                    "IDMULTMEDVRTOT"=>$item["IDMULTMEDVRTOT"],
                    "QTITEMCONTRATO"=>$item["QTITEMCONTRATO"],
                    "QTMEDIDACALCULADA"=>$item["QTMEDIDACALCULADA"],
                    "QTMEDIDACONTR"=>$item["QTMEDIDACONTR"],
                    "VRTOTITEMCONT"=>$item["VRTOTITEMCONT"],
                    "VRUNITITEMCONT"=>$item["VRUNITITEMCONT"],
                    "VRUNITITEMCONTTBLPRECO"=>$item["VRUNITITEMCONTTBLPRECO"]
                );
                $this->contratoFactory->atualizarItemContratoHistorico($params);
            }
            foreach($elemento["ITNEGOCIACAOCONTRATO"] as $itNego){
                $params = array(
                    "NRORG"=>$nrorg,
                    "NRITNEGOCIACAOCONTRATO" => $itNego["NRITNEGOCIACAOCONTRATO"],
                    "IDATIVO"=>$itNego["IDATIVO"],
                    "IDTPDESCONTO"=>$itNego["IDTPDESCONTO"],
                    "VRDESCITEM"=>$itNego["VRDESCITEM"],
                    "VRPERCDESCITEM"=>$itNego["VRPERCDESCITEM"],
                    "VRTOTITEM"=>$itNego["VRTOTITEM"],
                    "VRTOTITEMCOMDESC"=>$itNego["VRTOTITEMCOMDESC"]
                );
                $this->contratoFactory->atualizarItensNegociacaoContratoHistorico($params);
            }
            foreach($elemento["NEGOCIACAOCONTRATO"] as $negociacao){
                $params = array(
                    "NRORG"=>$nrorg,
                    "NRNEGOCIACAOCONTRATO"=>$negociacao["NRNEGOCIACAOCONTRATO"],
                    "IDATIVO"=>$negociacao["IDATIVO"],
                    "IDTPDESCONTO"=>$negociacao["IDTPDESCONTO"],
                    "VRDESCITEM"=>$negociacao["VRDESCITEM"],
                    "VRPERCDESCITEM"=>$negociacao["VRPERCDESCITEM"],
                    "VRTOTITEM"=>$negociacao["VRTOTITEM"],
                    "VRTOTITEMCOMDESC"=>$negociacao["VRTOTITEMCOMDESC"]
                );
                
                $this->contratoFactory->atualizarNegociacaoContratoHistorico($params);
            }
            foreach($elemento["PARCELANEGOCONT"] as $parcela){
                $params = array(
                    "NRORG"=>$nrorg,
                    "NRPARCELANEGOCONT"=>$parcela["NRPARCELANEGOCONT"],
                    "IDATIVO"=>$parcela["IDATIVO"],
                    "NRPARCELA"=>$parcela["NRPARCELA"],
                    "VRPARCELA"=>$parcela["VRPARCELA"]
                ); 
                $this->contratoFactory->atualizarParcelaNegociacaoContratoHistorico($params);
            }
           
        } catch(\Exception $e){
            throw $e;
        }
        
    }
     
    /**
    *   Função responsável por gerar um objeto de parametro que auxilia na rotina de DESFAZER REAJUSTE 
    *   Usada ao pegar dados da tabela ITNEGOCIACAOCONTRATO & ITEMCONTRATO
    *   @params $nrorg número da organização que fez o request
    *   @params $nrultimoReajuste número do pacote dos itens relacionados a este reajuste 
    *   @return array() array associativo contendo os parametros do select
    */
    public function gerarParamsDesfazerReajuste($nrorg, $nrultimoReajuste){
        try{
            $params = array(
                "NRULTIMOREAJUSTE" => $nrultimoReajuste,
                "NRORG" => $nrorg
            );
           return $params ;  
        } catch(\Exception $e){
            throw $e;
            return null;
        }
    }
    
    public function atualizarValorLinhaProduto($nrseqcontrato, $cdoperador, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato
        );
        $itens = $this->contratoFactory->getValoresManutencaoLicencaUsoContratoLinhaProduto($params);
        
        foreach ($itens as $item) {
            $params = array(
                "VRLICENCUSOLINP" => $item["VRLICENCAUSO"],
                "VRMENSALIDALINP" => $item["VRMANUTENCAO"],
                "NRORG"           => $nrorg,
                "CDOPERADOR"      => $cdoperador,
                "CDCLIENTE"       => $item["CDCLIENTE"],
                "CDLINPCLIE"      => $item["CDLINPCLIE"],
                "DTIVIGVRLINP"    => $item["DTINIVIGENCONT"]
            );
            
            $this->contratoFactory->updateValorLinhaProduto($params);
        }
    }
    
    public function desfazerValorlinpContrato($nrseqcontrato, $nrorg) {
        //Busca a data inicial de vigência do contrato
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        $periodoContrato = $this->contratoFactory->getPeriodoContrato($params);
        $dtinivigencont = $periodoContrato[0]["DTINIVIGENCONT"];
        
        //Busca o registro de VALORLINP do prazo que será desfeito. Se houver registro, ele deve ser excluído.
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "DTIVIGVRLINP"  => $dtinivigencont
        );
        $dataset = $this->contratoFactory->getValorlinpContratoPorData($params);
        if (count($dataset) > 0) {
            $valorlinp = $dataset[0];
            $params = array(
                "CDCLIENTE"    => $valorlinp["CDCLIENTE"],
                "CDLINPCLIE"   => $valorlinp["CDLINPCLIE"],
                "DTIVIGVRLINP" => $dtinivigencont
            );
            $this->contratoFactory->excluirValorlinp($params);
        }
    }
    
    public function getDadosContrato($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        
        $dataset = $this->contratoFactory->getDadosContrato($params);
        return $dataset[0];
    }

    public function getNegociacaoContratoPorParametrosFaturamento($nrseqcontrato, $nrorg, $nrtipoorcamento, $idtpfatura, $cdfilialfatura, $nrparcfatura, $cdtipooperfatura, $cdserienf, $cdempresa, $cdinscesta, $cdinscmuni, $agrupamentoParcelas, $idprevcobrfut, $nrestruturam, $cdtribprodpadr, $cdpaisfat, $sgestadofat, $cdmunicipiofat, $idnatuoper, $nrTipoEstrutura, $dsLoteFaturaNovo) {
        $params = array(
            "NRSEQCONTRATO"      => $nrseqcontrato,
            "NRORG"              => $nrorg,
            "NRTIPOORCAMENTO"    => $nrtipoorcamento,
            "IDTPFATURA"         => $idtpfatura,
            "CDFILIALFATURA"     => $cdfilialfatura,
            "NRPARCFATURA"       => $nrparcfatura,
            "CDTIPOOPERFATURA"   => $cdtipooperfatura,
            "CDSERIENF"          => $cdserienf,
            "CDEMPRESA"          => $cdempresa,
            "CDINSCESTA"         => $cdinscesta,
            "CDINSCMUNI"         => $cdinscmuni,
            "IDPREVCOBRFUT"      => $idprevcobrfut,
            "CDTRIBPRODPADR"     => $cdtribprodpadr,
            "IDAGRUPPARC"        => $agrupamentoParcelas,
            "NRESTRUTURAM"       => $nrestruturam,
            "CDPAISFAT"          => $cdpaisfat,
            "SGESTADOFAT"        => $sgestadofat,
            "CDMUNICIPIOFAT"     => $cdmunicipiofat,
            "IDNATUOPER"         => $idnatuoper,
            "NRTIPOESTRUTURA"    => $nrTipoEstrutura,
            "DSLOTEFATURAMENTO"  => $dsLoteFaturaNovo
        );
        
        $dataset = $this->contratoFactory->getNegociacaoContratoPorParametrosFaturamento($params);
        return (count($dataset) > 0) ? $dataset[0]["NRNEGOCIACAOCONTRATO"] : null;
    }
    
    public function getDadosNegociacaoValoresContrato($nrnegociacaocontrato, $nrorg) {
        $params = array(
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "NRORG"                => $nrorg
        );
        
        $dataset = $this->contratoFactory->getDadosNegociacaoValoresContrato($params);
        return $dataset[0];
    }
    
    public function salvarCentroDeCusto($tipo, $cdCentCust, $nrSeqContrato, $nrCompServico, $idElemento){
        try{
            if($tipo == "C"){
                $params = array(
                   "CDCENTCUST"     => $cdCentCust,
                   "NRSEQCONTRATO"  => $nrSeqContrato,
                   "NRCOMPSERVICO"  => $nrCompServico
                );
                $this->contratoFactory->atualizarCentroDeCustoComposicao($params);
            } else{
                $params = array(
                   "CDCENTCUST"     => $cdCentCust,
                   "NRSEQCONTRATO"  => $nrSeqContrato,
                   "IDELEMENTO"     => $idElemento
                );
                $this->contratoFactory->atualizarCentroDeCustoElemento($params);
            }
            return true;
        } catch(\Exception $e){
            throw $e;
        }
        
    }
    
    public function atualizarRescisao(array $params, $nrorg, $massa = false) {
        if ($massa && count($params) > 0) {
            foreach ($params as $p) {
                $this->integracaoOmService->salvarRescisaoContratoIntegracaoOM($p, $p["contractCode"], $nrorg, true);
            }            
        }
        else {
            $this->integracaoOmService->salvarRescisaoContratoIntegracaoOM($params, $params["contractCode"], $nrorg, true);
        }
    }
    
    public function getEnderecoFaturamento($nrestruturam, $nrparcnegocio, $nrorg) {
        $params = array(
            "NRESTRUTURAM" => $nrestruturam,
            "NRORG"        => $nrorg
        );
        $dataset = $this->parceiroNegocioFactory->getEnderecoPrincipalLocalAtendimento($params);
        
        if (count($dataset) > 0) {
            return $dataset[0];
        }
        else {
            $params = array(
                "NRPARCNEGOCIO" => $nrparcnegocio,
                "NRORG"         => $nrorg
            );
            $dataset = $this->parceiroNegocioFactory->getEnderecoPrincipalParceiro($params);
            return (count($dataset) > 0) ? $dataset[0] : null;
        }
    }
    
    /**
     * Função responsável por gerar contratos automaticamente para faturamento de serviços
     * Esta rotina é chamada tanto pela aprovação em massa como pela aprovação única
     * @params {nrParcNegocio} - O parceiro de Negócio do Contrato
     * @params {nrSeqContratoAp} - O Contrato que acabou sendo aprovado 
     * @returns {array ou null} - Retornara um array() quando todo o processo for concluído contendo os itens inseridos para que posteriormente seja terminado o processo, e nulo quando algum erro ocorrer.
    */
    public function gerarContratoParaFaturamentoDeServicos($nrParcNegocio, $nrSeqContratoAp) {
        if (!empty($nrParcNegocio) && $this->validarGeracaoContratoFaturamentoDeServicos($nrParcNegocio, $nrSeqContratoAp))
            return $this->gerarContratoFaturamentoServicos($nrParcNegocio);
        else
            return null;
    }
    
    /**
     * Função responsável por validar se esse contrato que acaba de ser aprovado deve ter um contrato de serviço gerado automaticamente para o parceiro de negócio.
     * Só será gerado caso o parceiro de negócio não tenha esse contrato sendo gerado. 
     * @params {nrParcNegocio} - O parceiro de Negócio do Contrato
     * @returns {boolean} - resultado da validação
    */
    public function validarGeracaoContratoFaturamentoDeServicos($nrParcNegocio, $nrseqcontrato) {
        $params = array(
            "NRPARCNEGOCIO" => $nrParcNegocio,
            "NRSEQCONTRATO" => $nrseqcontrato
        );
        //chamar uma query para pegar a quantidade de contratos deste parceiro de negocio
        $result = $this->contratoFactory->pegarvalidarGeracaoContratoFaturamentoDeServicos($params);
        return (int)$result[0]["QTD"] == 0;
    }
    
    /**
     * Função responsável por efetivamente gerar o contrato e salvar no banco.
     * Gera o contrato com os parametros definidos.
     * Gera tambem os itens seguindo o que foi parametrizado no escopo.
     * Gera a Negociação de Valores para o contrato.
     * @params {nrParcNegocio} - O parceiro de Negócio do Contrato
     * @params {nrSeqContratoAp} - O Contrato que acabou sendo aprovado 
     * @returns {array()} - Todos os que acabou de ser inserido
    */
    private function gerarContratoFaturamentoServicos($nrParcNegocio, $nrorg = null, $cdoperador = null) {
        if (!empty($this->codigoModeloContratoFaturamentoContratoGerado) && !empty($this->codigoEscopoFaturamentoContratoGerado)) {
            $this->connection->beginTransaction();
            try {
                $modeloDeContrato = $this->contratoFactory->pegarDadosModelo(array("NRSEQMODCONTRA" => $this->codigoModeloContratoFaturamentoContratoGerado));
                $escopoDoContrato = $this->contratoFactory->pegarDadosEscopo(array("NRTIPOORCAMENTO" => $this->codigoEscopoFaturamentoContratoGerado));
                $itensASeremRetornados = null;
                if (count($modeloDeContrato) > 0 && count($escopoDoContrato) > 0) {
                    $modeloDeContrato = $modeloDeContrato[0];
                    $escopoDoContrato = $escopoDoContrato[0];
                    $params = array(
                        "NRTIPOORCAMENTO" => $this->codigoEscopoFaturamentoContratoGerado
                    );
                    $itens = $this->contratoFactory->pegarItemContratosGeradoFaturamentoServicos($params);
                    if (count($itens) > 0) {
                        //INSERÇÂO DO CONTRATO AUTOMÁTICO
                        if(empty($cdoperador)) $cdoperador = $this->environment->getCdOperador();
                        if(empty($nrorg)) $nrorg = $this->environment->getNrOrg();
                        
                        $nrSeqContrato = $this->newCode->getCodeByTableName("FCT_CONTRATO", $nrorg, 1, 10, true);
                        $params = array(
                            "NRSEQCONTRATO"             => $nrSeqContrato,
                            "NRPARCNEGOCIO"             => $nrParcNegocio,
                            "DSREFERENCIACONT"          => $modeloDeContrato["NMMODCONTRATO"],
                            "NRDIASVIGCONT"             => $modeloDeContrato["NRDIASVIGCONT"],
                            "NRTIPOORCAMENTO"           => $this->codigoEscopoFaturamentoContratoGerado,
                            "CDOPERRESPONSAVEL"         => $cdoperador,
                            "IDSITUACAOCONTRATO"        => "A",
                            "IDCONTSERVGERADOAUTO"      => "S",
                            "NRSEQMODCONTRA"            => $this->codigoModeloContratoFaturamentoContratoGerado,
                            "IDASSELETRDIGITAL"         => $modeloDeContrato["IDASSELETRDIGITAL"],
                            "IDENVIADOCOPERRESPCONCASS" => $modeloDeContrato["IDENVIADOCOPERRESPCONCASS"],
                            "CDFILIALORCA"              => $escopoDoContrato["CDFILIALFATURA"],
                            "NRVERSAOCONTRATO"          => 1
                        );
                        $this->contratoFactory->inserirContratosGeradoFaturamentoServicos($params);
                        $this->executarProcedureCriaMnemonico($nrSeqContrato, $nrorg);
                        
                        //INSERÇÂO DOS ITENS PRESENTES NO ESCOPO
                        foreach ($itens as $it) {
                            $tipoMedida = $it["CDTPMEDIDAVARIAVEL"];
                            $usaMedida = "N";
                            $vrunitario = $it["VRPRECO"];
                            $qtdItem = 1;
                            $qtdMedida = null;
                            $vrtotal = $vrunitario * $qtdItem;
                            if (!empty($tipoMedida)) {
                                $usaMedida = "S";
                                $qtdMedida = 0;
                                $vrtotal *= $qtdMedida;
                            }
                            $itemContratoNR = $this->newCode->getCodeByTableName("FCT_ITEMCONTRATO", $nrorg, 1, 10, true);
                            $params = array(
                                "NRITEMOCONTRATO"    => $itemContratoNR,
                                "NRSEQCONTRATO"      => $nrSeqContrato,
                                "NMTIPOORCAMENTO"    => $it["NMTIPOORCAMENTO"],
                                "QTITEMCONTRATO"     => $qtdItem,
                                "VRUNITITEMCONT"     => $vrunitario,
                                "VRTOTITEMCONT"      => $vrtotal,
                                "NRORG"              => $nrorg,
                                "CDOPERADOR"         => $cdoperador,
                                "CDSERVORCA"         => $it["CDSERVORCA"],
                                "CDTPMEDIDASERV"     => $tipoMedida,
                                "CDTPMEDIDAVARIAVEL" => $tipoMedida,
                                "QTMEDIDACONTR"      => $qtdMedida,
                                "IDMULTMEDVRTOT"     => $usaMedida
                            );
                            $this->contratoFactory->inserirItemContratosGeradoFaturamentoServicos($params);
                            $params["NRTIPOORCAMENTO"] = $this->codigoEscopoFaturamentoContratoGerado;
                            $this->inserirOuAtualizarMedidaVariavelServico($params, $nrorg, $cdoperador);
                            $itemInserido = $this->contratoFactory->pegarItemInserido(array("NRITEMOCONTRATO" => $itemContratoNR));
                            $itensASeremRetornados[] = $itemInserido;
                        }//fim do foreach
                        
                        $this->salvarDadosMedidaContrato($nrSeqContrato, $nrorg, $cdoperador);
                        $this->connection->commit();
                        return $itensASeremRetornados;
                    }
                    else {
                        throw new \Exception("Falha ao gerar o contrato automático:<br> Não foi encontrado nenhum item dentro do Escopo de Faturamento parametrizado.");
                    }
                }
                else {
                    throw new \Exception("Falha ao gerar o contrato automático:<br> Não foi encontrado um Modelo de Contrato ou Escopo de Faturamento com o código parametrizado.");
                }
            }
            catch(\Exception $e) {
                $this->connection->rollback();
                throw $e;
            }
        }
    }
    
    public function gerarParcelasContratoNovoFat($nrseqcontrato, $idUtilizaComp, $nrorg, $operador, $nrParc, $idReplicarNegociacao, $idAprovacao,  $row) {

        if ($idAprovacao == "S") {

            $periodoExtendido = false;
        }
        else {
            $periodoExtendido = true;
        }

        $this->IntegracaoOM($nrseqcontrato, null, $idUtilizaComp, $nrorg, false, $periodoExtendido);

        $this->connection->beginTransaction();
        try {
            $result = null;
            if (!empty($nrParc))
                $result = $this->gerarContratoParaFaturamentoDeServicos($nrParc, $nrseqcontrato);
            
            if ($idReplicarNegociacao == "S" && isset($row["NRSEQCONTRATOPAI"])) {
                $nrseqcontratopai = $row["NRSEQCONTRATOPAI"];
                $this->replicarNegociacaoContrato($nrseqcontrato, $nrseqcontratopai, $nrorg, $operador);
            }
            $this->executarProcedureFctGerarParcelasFatura($nrseqcontrato, $nrorg, $operador);
            $this->connection->commit();
            return $result;
        }
        catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
    
    public function gerarContratosServicosAutomatico($callback){
        try {
            $clientes = $this->pegaClientesQueNaoPossuemContratosAutomaticaDeServicos();
            $this->chamarGeracaoDeContratoParaTodosOsClientesQueNaoPossuemContratoAutomatico($clientes, $callback);
        }
        catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function pegaClientesQueNaoPossuemContratosAutomaticaDeServicos(){
        try{
           return $this->contratoFactory->pegaClientesQueNaoPossuemContratosAutomaticaDeServicos(array("NRORG" => 20));
        }catch(\Exception $e){
            throw $e;
        }
    }
    
    public function chamarGeracaoDeContratoParaTodosOsClientesQueNaoPossuemContratoAutomatico($clientes, $callback) {
        foreach ($clientes as $c) {
            try {
                $nrorg = 20;
                $cdoperador = "000000000997";
                $callback($this->gerarContratoFaturamentoServicos($c["NRPARCNEGOCIO"], $nrorg, $cdoperador));
                
                if (!empty($this->codigoModeloContratoFaturamentoContratoGerado) && !empty($this->codigoEscopoFaturamentoContratoGerado)) {
                    echo "Contrato para o parceiro '" . $c["NRPARCNEGOCIO"] . " - " . $c["NMSECUNDARIPARC"] . "' foi gerado com sucesso.\n";
                }
            }
            catch(\Exception $e) {
                // echo "Contrato para o parceiro '" . $c["NRPARCNEGOCIO"] . " - " . $c["NMSECUNDARIPARC"] . "' foi gerado com sucesso. \n";
                echo "Erro ao gerar o contrato para o parceiro '" . $c["NRPARCNEGOCIO"] . " - " . $c["NMSECUNDARIPARC"] . "'.\n Erro:".$e->getMessage(). "\n";
            }
        }
    }
    
    public function salvarAnexoRenegociacaoContrato($nrseqcontrato, $nrorg, $operador,$nrseqcontratogerado ){
        try {
            $this->connection->beginTransaction();
            $params = array(
                "NRSEQCONTRATO" => $nrseqcontrato,
                "NRORG" => $nrorg
            );
            $dataset = $this->contratoFactory->pegarAnexoRenegociacaoContrato($params);
            foreach ($dataset as $row) {
                $nomeArquivo   = $row["NMARQUIVO"];
                $tipo          = $row["DSTIPO"];
                $tamanhoBytes  = $row["VRTAMANHO"] * 1024;
                $urlFileServer = $row["DSCAMINHO"];
                $nrtipoanexo   = $row["NRTIPOANEXO"];
                
                if (!empty($urlFileServer)) {
                    //$conteudo = @file_get_contents($this->fileServerBaseUrl . $urlFileServer);
                    $conteudo = $this->smDocumentosService->getDocumentoFileServer($this->fileServerBaseUrl . $urlFileServer, $nrorg);
                    if ($conteudo !== false) {
                        $file = Utilities::uploadFileServer($this->zhFileUploader, "anexo_contrato", $nomeArquivo, $conteudo, $tamanhoBytes, $tipo);
                        $caminhoNovo = $file["path"];
                        $nrAnexoContrato = $this->newCode->getCodeByTableName("FCT_ANEXOCONTRATO", $nrorg, 1, 10, true);
                        $params = array(
                            "NRANEXOCONTRATO"=> $nrAnexoContrato,
                            "NRSEQCONTRATO"  => $nrseqcontratogerado,
                            "NMARQUIVO"      => $nomeArquivo,
                            "DSCAMINHO"      => $caminhoNovo,
                            "DSTIPO"         => $tipo,
                            "VRTAMANHO"      => $tamanhoBytes / 1024,
                            "NRORG"          => $nrorg,
                            "OPERADOR"       => $operador,
                            "NRTIPOANEXO"    => $nrtipoanexo
                        );
                        $this->contratoFactory->SaveAnexoDocContratoRescindido($params);
                    }
                }
            }
            $this->connection->commit();
            return true;
        } catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
    
    public function inserirSeguroContrato($nrapolice, $dsmodalidade, $dtiniseguro, $dtfinseguro, $vrtaxaseguro, $vrapolice,$nrparccorretora, $nrparcseguradora, $nrorg, $operador, $idvigente, $nrseqcontrato, $dtinclusao) {
        try {
            $this->connection->beginTransaction();
            $nrSeguro = $this->newCode->getCodeByTableName("FCT_SEGUROCONTRATO", $nrorg, 1, 10, true);
            $params = array(
                "NRSEGUROCONTRATO"      =>$nrSeguro,
                "NRAPOLICE"             =>$nrapolice,
                "DSMODALIDADE"          =>$dsmodalidade,
                "DTINISEGURO"           =>$dtiniseguro,
                "DTFINSEGURO"           =>$dtfinseguro,
                "VRTAXASEGURO"          =>$vrtaxaseguro,
                "VRAPOLICE"             =>$vrapolice,
                "NRPARCCORRETORA"       =>$nrparccorretora,
                "NRPARCSEGURADORA"      =>$nrparcseguradora,
                "NRSEQCONTRATO"         =>$nrseqcontrato,
                "NRORG"                 =>$nrorg,
                "DTINCLUSAO"            =>$dtinclusao,
                "OPERADOR"              =>$operador,
                "IDVIGENTE"             =>$idvigente
            );
            $this->contratoFactory->inserirSeguroContrato($params);
            $this->connection->commit();
            return true;
        } catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }    
    }
    
    /**
     * Função responsável por efetuar a consulta ao banco de dados para remover uma rescisão do contrato.
     * @params operador - Operador responsável pela remoção da rescisão
     * @params nrorg - Número da organização que a remoção está ocorrendo.
     * @params nrseqcontrato - Contrato que a operação está ocorrendo
    */
    public function removerRescisaoContrato($operador, $nrorg, $nrseqcontrato) {
        try{
            $this->connection->beginTransaction();
            $params = $this->gerarParametrosAtualizacaoRescisao(null,null,null,null,null,null,$nrorg, $operador, $nrseqcontrato, null, false, null); 
            $dataset = $this->contratoFactory->atualizarDadosRescisaoContrato($params);
            $this->connection->commit();
            return "Rescisão removida com sucesso.";
        }catch(\Exception $e){
            $this->connection->rollBack();
            throw $e; 
        }
    }
    
    /**
     * Função responsável por efetuar a consulta ao banco de dados para remover diversas rescisões de contratos.
     * @params operador - Operador responsável pela remoção da rescisão
     * @params nrorg - Número da organização que a remoção está ocorrendo.
     * @params contratos - Todos os contratos que devem ser operados. 
    */
    public function removerRescisaoContratoMultiplos($operador, $nrorg, $contratos) {
        try{
            $this->connection->beginTransaction();
            $params = $this->gerarParametrosAtualizacaoRescisao(null,null,null,null,null,null,$nrorg, $operador,null, null, true, null); 
            $dataset = $this->contratoFactory->atualizarDadosRescisaoContratoMultiplos($params,$contratos);
            $this->connection->commit();
            return "Rescisão removida com sucesso.";
        }catch(\Exception $e){
            $this->connection->rollBack();
            throw $e; 
        }
    }
    
   public function solicitarRescisaoContrato($dtpedrescisaocontr, $dtrecisao, $nrmotivorescisao, $nrtiporescisao, $vrpendenciafin, $dsjustificaencerra, $nrorg, $cdoperador, $nrseqcontrato, $idtpexclusaoparcela) {
        try{
            $this->connection->beginTransaction();
            $params = $this->gerarParametrosAtualizacaoRescisao($dtpedrescisaocontr, $dtrecisao, $nrmotivorescisao, $nrtiporescisao, $vrpendenciafin, $dsjustificaencerra, $nrorg, $cdoperador, $nrseqcontrato, 'S',false,  $idtpexclusaoparcela); 
            $dataset = $this->contratoFactory->atualizarDadosRescisaoContrato($params);
            $this->connection->commit();
            return "Solicitação realizada com sucesso.";
        }catch(\Exception $e){
            $this->connection->rollBack();
            throw $e; 
        }
   }
   
   public function solicitarRescisaoContratoMultiplos($dtpedrescisaocontr, $dtrecisao, $nrmotivorescisao, $nrtiporescisao, $vrpendenciafin, $dsjustificaencerra, $nrorg, $cdoperador, $contratos, $idtpexclusaoparcela) {
        try{
            $this->connection->beginTransaction();
            $params = $this->gerarParametrosAtualizacaoRescisao($dtpedrescisaocontr, $dtrecisao, $nrmotivorescisao, $nrtiporescisao, $vrpendenciafin, $dsjustificaencerra, $nrorg, $cdoperador, null,'S', true, $idtpexclusaoparcela); 
            $dataset = $this->contratoFactory->atualizarDadosRescisaoContratoMultiplos($params, $contratos);
            $this->connection->commit();
            return "Solicitação realizada com sucesso.";
        }catch(\Exception $e){
            $this->connection->rollBack();
            throw $e; 
        }
   }
    
    public function gerarParametrosAtualizacaoRescisao($dtpedrescisaocontr, $dtrecisao, $nrmotivorescisao, $nrtiporescisao, $vrpendenciafin, $dsjustificaencerra, $nrorg, $cdoperador, $nrseqcontrato, $idsituacaorescisao = 'S', $multiplos = false, $idtpexclusaoparcela = null){
        if(!$multiplos)
            return  array(
                "DTPEDRESCISAOCONTR" => $dtpedrescisaocontr,
                "DTRECISAOCONTR"     => $dtrecisao,
                "NRMOTIVORESCISAO"   => $nrmotivorescisao,
                "NRTIPORESCISAO"     => $nrtiporescisao,
                "VRPENDENCIAFIN"     => $vrpendenciafin,
                "DSJUSTIFICAENCERRA" => $dsjustificaencerra,
                "NRORG"              => $nrorg,
                "OPERADOR"           => $cdoperador,
                "IDSITUACAORESCISAO" => $idsituacaorescisao,
                "IDTPEXCLUSAOPARCELA"=> $idtpexclusaoparcela,
                "NRSEQCONTRATO"      => $nrseqcontrato
            );
        else
            return  array(
                "DTPEDRESCISAOCONTR" => $dtpedrescisaocontr,
                "DTRECISAOCONTR"     => $dtrecisao,
                "NRMOTIVORESCISAO"   => $nrmotivorescisao,
                "NRTIPORESCISAO"     => $nrtiporescisao,
                "VRPENDENCIAFIN"     => $vrpendenciafin,
                "DSJUSTIFICAENCERRA" => $dsjustificaencerra,
                "NRORG"              => $nrorg,
                "OPERADOR"           => $cdoperador,
                "IDSITUACAORESCISAO" => $idsituacaorescisao,
                "IDTPEXCLUSAOPARCELA"=> $idtpexclusaoparcela
            );
    }
    
    public function salvarHistoricoSeguro($nrorg, $operador, $nrsegurocontrato){
        try{
            $this->connection->beginTransaction();
            $params = array(
                "CDOPERADOR"        => $operador,
                "NRORG"             => $nrorg,
                "NRSEGUROCONTRATO"  => $nrsegurocontrato
            );
            $this->contratoFactory->salvarHistoricoSeguro($params);
            $this->connection->commit();
            return true;
        }catch(\Exception $e){
            $this->connection->rollback();
            throw $e;
        }
    }
    
    public function validarMedicaoServico($nrnegociacaocontrato, $nrtipoorcamento) {
        $nrorg = $this->environment->getNrOrg();
        
        $params = array(
            "NRTIPOORCAMENTO"      => $nrtipoorcamento,
            "NRORG"                => $nrorg,
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato
        );
        $dataset = $this->contratoFactory->validarMedicaoServico($params);
        return (int)$dataset[0]["QTD"] > 0;
    }
    
    public function salvarAlteraSituAssina($widassinatura, $widsituacao, $nrorg, $operador) {
        
        try{
            $idalteraemmassa     = $widsituacao["IDALTERAEMMASSA"];
            $situacaoNova        = $widsituacao["IDSITUACAO"];
            $dsjustaltsitumanual = $widsituacao["DSJUSTALTSITUMANUAL"];
            $dsjustificarecusa   = $widsituacao["DSJUSTIFICARECUSA"];
            
            if ($idalteraemmassa == true ) {
                
                foreach ($widassinatura as $assina) {
                    
                    $nrassdigitalcontr = $assina['NRASSDIGITALCONTR'];
                    $nrseqcontrato   = $assina['NRSEQCONTRATO'];
                    
                    $params = array(
                        "IDSITUACAO"          => $situacaoNova,
                        "OPERADOR"            => $operador,
                        "DSJUSTALTSITUMANUAL" => $dsjustaltsitumanual,
                        "DSJUSTIFICARECUSA"   => $dsjustificarecusa,
                        "NRORG"               => $nrorg,
                        "NRASSDIGITALCONTR"   => $nrassdigitalcontr,
                        "NRSEQCONTRATO"       => $nrseqcontrato
                    );
                    
                    $this->contratoFactory->salvarAlteraSituAssina($params);
                        
                }
            }
            else {
                
                $nrassdigitalcontr = $widassinatura['NRASSDIGITALCONTR'];
                $nrseqcontrato   = $widassinatura['NRSEQCONTRATO'];
                
                $params = array(
                    "IDSITUACAO"          => $situacaoNova,
                    "OPERADOR"            => $operador,
                    "DSJUSTALTSITUMANUAL" => $dsjustaltsitumanual,
                    "DSJUSTIFICARECUSA"   => $dsjustificarecusa,
                    "NRORG"               => $nrorg,
                    "NRASSDIGITALCONTR"   => $nrassdigitalcontr,
                    "NRSEQCONTRATO"       => $nrseqcontrato
                );
                
                $this->contratoFactory->salvarAlteraSituAssina($params);
            }

            return 'OK';
        
        }
         catch(\Exception $e) {
            return $e;
        }
    }
    
    public function validaAlteracaoEscopo($contrato, $nrtipoorcamento, $nrseqmodcontra, $nrorg, $operador){
        $retorno = "OK";
        
        /* 1 - O contrato deve estar 'Pendente'*/
        $params = array(
            "NRSEQCONTRATO" => $contrato,
            "NRORG"         => $nrorg
        );
        
        $dadosContrato = $this->contratoFactory->getDadosContrato($params);
        $situacao = $dadosContrato[0]["IDSITUACAOCONTRATO"];
        $escopoAntigo = $dadosContrato[0]["NRTIPOORCAMENTO"];
        
        if ($situacao != 'P') {
            $retorno = 'Operação bloqueada! <br><br> Só é permitido alterar o escopo de faturamento de um contrato que esteja com a situação "Pendente".';
        }
        else if ($nrtipoorcamento == $escopoAntigo) {
            $retorno = 'Operação bloqueada! <br><br> O escopo de faturamento selecionado para alteração já é o escopo atual do contrato.';
        }
        else {
            $params = array(
                "NRSEQMODCONTRA"  => $nrseqmodcontra,
                "NRTIPOORCAMENTO" => $nrtipoorcamento,
                "NRORG"           => $nrorg
            );
            $dataset = $this->contratoFactory->getEscopoEstaRelacionadoAoModeloContrato($params);
            
            if ((int)$dataset[0]["EXISTE"] <= 0) {
                $retorno = 'Operação bloqueada! <br><br> O escopo de faturamento selecionado não está relacionado ao modelo de contrato utilizado neste contrato.';
            }
            else {

                $params = array(
                    "NRTIPOORCAMENTO" => $nrtipoorcamento,
                    "NRORG"           => $nrorg
                );
                
                $filtroServ = $this->contratoFactory->verificaFiltroServEscopo($params); 
                
                if ($filtroServ == 'S') {
                    $params = array(
                        "NRSEQCONTRATO"   => $contrato,
                        "NRTIPOORCAMENTO" => $nrtipoorcamento,
                        "NRORG"           => $nrorg
                    );
                    
                    $valida = $this->contratoFactory->verificaServEscopo($params);   
                    
                    if ($valida > 0) {
                        $retorno = 'Operação bloqueada! <br><br> Existem serviços vinculados ao contrato que não estão vinculados ao novo escopo de faturamento selecionado.';
                    }
                    else {
                        //Pega os itens do contrato para saber o código dos serviços
                        $params = array(
                            "NRSEQCONTRATO" => $contrato,
                            "NRORG"         => $nrorg
                        );
                        $itensContrato = $this->contratoFactory->getItensContratos($params);
                        if (count($itensContrato) > 0) {
                            
                            $arrServicos = array();
                            foreach ($itensContrato as $item) {
                                if (!in_array($item["CDSERVORCA"], $arrServicos)) {
                                    array_push($arrServicos, $item["CDSERVORCA"]);
                                }
                            }
                            
                            $servicos = implode(",", $arrServicos);
                            
                            //busca a parametrização de negpciação de valores com o novo escopo
                            $params = array(
                                "NRSEQMODCONTRA" => $nrseqmodcontra,
                                "NRSEQCONTRATO"  => $contrato,
                                "NRORG"          => $nrorg
                            );
                            $itensNegociacao = $this->contratoFactory->getParametrosFaturamentoItensNegociacaoContrato($params, $nrtipoorcamento, $servicos);
                            
                            $bloquearPorTipoMedicao = false;
                            foreach ($itensNegociacao as $itemNeg) {
                                foreach ($itensContrato as $itemCont) {
                                    if (($itemNeg["IDTPFATURA"] == "X" || $itemCont["IDTPFATURA"] == "X") && $itemNeg["IDTPFATURA"] != $itemCont["IDTPFATURA"]) {
                                        $bloquearPorTipoMedicao = true;
                                        break 2;
                                    }
                                }
                            }
                            
                            if ($bloquearPorTipoMedicao) {
                                $retorno = 'Operação bloqueada! <br><br> Não é possível alterar o Escopo de Faturamento deste contrato pois o parâmetro "Tipo de Faturamento" de um dos itens está sendo alterado de/para "Periódico (Valor Apurado por Medição)". <br>Para modificar de/para um escopo que fatura por medição, será necessário excluir todos os itens do contrato antes.';
                            }
                        }
                    }
                }
            }
        }
        
        return $retorno;
    }
    
    public function atualizarEscopoMedidasVariaveisContrato($nrseqcontrato, $nrtipoorcamento, $nrorg) {
        $params = array(
            "NRTIPOORCAMENTO" => $nrtipoorcamento,
            "NRSEQCONTRATO"   => $nrseqcontrato,
            "NRORG"           => $nrorg
        );
        
        $this->contratoFactory->atualizarEscopoMedidasVariaveisContrato($params);
    }

    public function inserirDocumentos($seqModContrato, $seqContrato, $nrorg, $cdoperador){
    
        $paramsModeloDocContr = array(
            "NRSEQMODCONTRA" => $seqModContrato,
        );
        
        $modeloDocContr = $this->contratoFactory->getModeloDocContr($paramsModeloDocContr);

        foreach ($modeloDocContr as $doc) {
            $nome    = $doc["NMARQUIVO"];
            $caminho = $doc["DSCAMINHOARQ"];
            $tipo    = $doc["DSTIPO"];
            $tamanho = $doc["VRTAMANHO"];
 
            if (!empty($caminho)) {
                $arquivoDoc = $this->smDocumentosService->getDocumentoFileServer($this->fileServerBaseUrl . $caminho, $nrorg);
                if ($arquivoDoc !== false) {
                    $arquivoDoc = base64_encode($arquivoDoc);

                    $docNovo = $this->anexaContratoDoc($arquivoDoc, $nome, $tipo, $tamanho);
                     
                    $nomeNovo    = $docNovo["name"];
                    $caminhoNovo = $docNovo["path"];
                    $tamanhoNovo = $docNovo["size"] / 1024;
                    $tipoNovo    = $docNovo["type"];

                    $nrseqcontdoc = $this->newCode->getCodeByTableName("NRSEQCONTDOC", $nrorg, 1, 10, true);
                    $paramsIns = array(
                        "NRSEQCONTDOC"        => $nrseqcontdoc,
                        "NRSEQCONTRATO"       => $seqContrato,
                        "NRSEQMODDOCFCT"      => $doc["NRSEQMODDOCFCT"],
                        "NRORG"               => $nrorg,
                        "CDOPERADOR"          => $cdoperador,
                        "IDATIVO"             => "S",
                        "NMARQUIVO"           => $nomeNovo,
                        "DSCAMINHOARQ"        => $caminhoNovo,
                        "DSTIPO"              => $tipoNovo,
                        "VRTAMANHO"           => $tamanhoNovo,
                        "IDSITUACAOCONTRATO"  => $doc["IDSITUACAOCONTRATO"],
                        "VRTAMANHOLOGO"       => $doc["VRTAMANHOLOGO"]
                    );

                    $this->contratoFactory->inserirModeloDocumento($paramsIns);

                    $situacoes = explode(",", $doc["IDSITUACAOCONTRATO"]);
                    $this->inserirSituacaoDocumentoContrato($situacoes, $nrorg, $cdoperador);
                    $this->inserirAnexosIdioma($doc, $nrseqcontdoc, $nomeNovo, $caminhoNovo, $tamanhoNovo, $tipoNovo, $nrorg, $cdoperador);
                }
            }
        }
    }

    public function anexaContratoDoc($arquivoDoc, $nome, $tipo, $tamanho){
    
        $fileData = array(
           'b64File' => 'data:'.$tipo.';base64,'.$arquivoDoc,
           'name' => $nome,
           'size' => $tamanho * 1024,
           'type' => $tipo,
           'webkitRelativePath' => ''
       );

       $row = new Row(array('FILE' => array($fileData)));
       $this->zhFileUploader->uploadFilesInRow($row, 'FILE', 'anexo_documento_proposta');
       
       return $row["FILE"][0];
   }

   public function inserirSituacaoDocumentoContrato(array $situacoes, $nrorg, $cdoperador) {
        $params = [
            "NRCONTRATODOCSITU"  => null,
            "IDSITUACAOCONTRATO" => null,
            "IDATIVO"             => "S",
            "NRORG"               => $nrorg,
            "NRORGINCLUSAO"       => $nrorg,
            "CDOPERINCLUSAO"      => $cdoperador
        ];

        foreach ($situacoes as $situacao) {
            $params["NRCONTRATODOCSITU"] = $this->newCode->getCodeByTableName("FCT_CONTRATODOCSITU", $nrorg, 1, 10, true);
            $params["IDSITUACAOCONTRATO"] = $situacao;
            $this->contratoFactory->inserirSituacaoDocumentoContrato($params);
        }
    }

    public function inserirAnexosIdioma($doc, $nrseqcontdoc, $nomeArqivoOrcaDoc, $caminhoArqivoOrcaDoc, $tamanhoArqivoOrcaDoc, $tipoArqivoOrcaDoc, $nrorg, $cdoperador) {
        $paramsAux = array (
            "NRSEQMODDOCFCT" => $doc["NRSEQMODDOCFCT"]
        );
        $anexosIdioma = $this->contratoFactory->getAnexosModeloDocumentoPorIdioma($paramsAux);
        foreach ($anexosIdioma as $anexo) {
            if (!empty($anexo["DSCAMINHOARQ"])) {
                if ($anexo["DSCAMINHOARQ"] == $doc["DSCAMINHOARQ"]) {
                    $nomeAnexo    = $nomeArqivoOrcaDoc;
                    $caminhoAnexo = $caminhoArqivoOrcaDoc;
                    $tipoAnexo    = $tipoArqivoOrcaDoc;
                    $tamanhoAnexo = $tamanhoArqivoOrcaDoc;
                }
                else {
                    $arquivoDocIdioma = $this->smDocumentosService->getDocumentoFileServer($this->fileServerBaseUrl . $anexo["DSCAMINHOARQ"], $nrorg);
                    if ($arquivoDocIdioma !== false) {
                        $arquivoDocIdioma = base64_encode($arquivoDocIdioma);

                        $anexoNovo = $this->anexaContratoDoc($arquivoDocIdioma, $anexo["NMARQUIVO"], $anexo["DSTIPO"], $anexo["VRTAMANHO"]);
                        $nomeAnexo    = $anexoNovo["name"];
                        $caminhoAnexo = $anexoNovo["path"];
                        $tipoAnexo    = $anexoNovo["type"];
                        $tamanhoAnexo = $anexoNovo["size"] / 1024;
                    }
                }
                
                $nrcontratodocidioma = $this->newCode->getCodeByTableName("FCT_ORCAMENTODOCIDIOMA", $nrorg, 1, 10, true);
                $params = array(
                    "NRCONTRATODOCIDIOMA"  => $nrcontratodocidioma,
                    "NRSEQCONTDOC"         => $nrseqcontdoc,
                    "CDIDIOM"              => $anexo["CDIDIOM"],
                    "NMARQUIVO"            => $nomeAnexo,
                    "DSCAMINHOARQ"         => $caminhoAnexo,
                    "DSTIPO"               => $tipoAnexo,
                    "VRTAMANHO"            => $tamanhoAnexo,
                    "IDATIVO"              => "S",
                    "NRORG"                => $nrorg,
                    "NRORGINCLUSAO"        => $nrorg,
                    "CDOPERINCLUSAO"       => $cdoperador
                );

                $this->contratoFactory->inserirAnexosDocumentoContratoPorIdioma($params);
            }
        } 
    }

    public function getQuantidadeItensMoedaDiferenteContrato($nrseqcontrato)
    {
        $params = [
            "NRSEQCONTRATO" => $nrseqcontrato
        ];
        $dataset = $this->contratoFactory->getQuantidadeItensMoedaDiferenteContrato($params);
        return (int)$dataset[0]["QTD"];
    }


    public function validaItensLoteFatura($contrato, $utilizaLote, $nrorg)
    {
        $params = array(
            "NRSEQCONTRATO"   => $contrato,
            "NRORG"           => $nrorg
        );

        $validaLote = $this->contratoFactory->validaItensLoteFatura($params);

        if (($utilizaLote == 'N') && ($validaLote > 0)){

            $retorno = 'Operação bloqueada! <br><br> O campo "Utiliza Lote no Agrupamento" não pode ser alterado para "Não" pois existem itens que possuem "Lote para Faturamento" cadastrado.' ;
        }
        else {
            $retorno = 'OK';
        }

        return $retorno;
    }

    public function confirmInsElementoContr($contrato, $escopo, $modelo, $moeda, $idMantemDescAcres, $dados, $nrorg, $cdoperador) {
        $this->connection->beginTransaction();
        try {
            /* Se mantem os descontos, devem ser reciadas as negociações de valores mantendo tudo, se não, apenas insere tudo de novo.*/
            if ($idMantemDescAcres == 'S') {
                /*  1 - Recebe os dados anteriores para correções na criação dos elementos e para manter os descontos já realizados anteriormente.*/
                $itensContrato   = $this->getItensContratos($contrato, $nrorg);
                $descontos = $this->getDescontosContrato($contrato, $nrorg);

                $params = array(
                    "NRSEQCONTRATO"  => $contrato,
                    "NRORG"          => $nrorg
                );
                $negociacoes  = $this->contratoFactory->getParametrosFaturaNegociacoesContrato($params);
                $parcelas     = $this->contratoFactory->getParcelasContrato($params);

                /* 2 - Exclui os dados antigos do contrato */
            
                $this->excluirNegociacaoDeValoresContrato($contrato, $nrorg);

                /* 3 - Insere os Elementos novos */
                $this->insereElementoContr($contrato, $escopo, $modelo, $moeda, $dados, $nrorg, $cdoperador, $idMantemDescAcres, $itensContrato, $negociacoes , $parcelas, $descontos);
            }
            else {
                $this->insereElementoContr($contrato, $escopo, $modelo, $moeda, $dados, $nrorg, $cdoperador);
            }

            $this->connection->commit();
            return 'OK';
        }
        catch(\Exception $e) {
            $this->connection->rollback();
            return $e->getMessage();
        }
    }

    public function insereElementoContr($contrato, $escopo, $modelo, $moeda, $dados, $nrorg, $cdoperador, $idMantemDescAcres = 'N', $itensContrato = null, $negociacoes = null, $parcelas = null, $descontos = null) {

        try {
            /*  Separa os Elementos das composições */
            $elementos = array();
            $composicoes = array();
            foreach($dados as $dado){
                if($dado["TIPO"] == 'C') {
                    array_push($composicoes, $dado);
                }
                else {
                    array_push($elementos, $dado);
                }
            }

            $elementosApareceProp = array();
            $elementosNaoApareceprop = array();
            foreach($elementos as $elemento){
               if ($elemento["IDAPARECEPROPOSTA"] == 'S') {
                array_push($elementosApareceProp, $elemento);
               }
               else {
                array_push($elementosNaoApareceprop, $elemento);
               }
            }
           
            foreach ($composicoes as $composicao) {

                /*  Verifica se a composição ja existe no relacionamento das composições do contrato, se não existir, insere.*/
                $params =  array(
                    "NRSEQCONTRATO"    => $contrato,
                    "NRCOMPSERVICO"    => $composicao["NRCOMPSERVICO"],
                    "NRCOMPSERVICOPAI" => $composicao["NRCOMPSERVICOPAI"],
                    "NRORG"            => $nrorg
                );
                
                $validaComp = $this->contratoFactory->validaExisteComposicaoContrato($params);
                
                if (count($validaComp) > 0){

                    $params =  array(
                        "OPERADOR"       => $cdoperador,
                        "NRORG"          => $nrorg,
                        "NRCOMPSERVCONT" => $validaComp[0]["NRCOMPSERVCONT"]
                    );
    
                    $this->contratoFactory->updateIdMarcadoComposicaoContrato($params);  
                }
                else {
                    $nrcompservcontrato = $this->newCode->getCodeByTableName("FCT_COMPSERVCONTRATO", $nrorg, 1, 10, true);
                    $params = array(
                        "NRCOMPSERVCONT"      => $nrcompservcontrato,
                        "NRSEQCONTRATO"       => $contrato,
                        "NRCOMPSERVICO"       => $composicao["NRCOMPSERVICO"],
                        "NMCOMPSERVICO"       => isset($composicao["NMSERVORCA"]) ? $composicao["NMSERVORCA"] : $composicao["NMELEMENTO"],
                        "NRCOMPSERVICOPAI"    => $composicao["NRCOMPSERVICOPAI"],
                        "IDCOMPOBRIGATORIA"   => $composicao["IDSERVOBRIGCOMP"],
                        "IDESCOLHIDO"         => "S",
                        "IDATIVO"             => "S",
                        "NRORG"               => $nrorg,
                        "CDOPERINCLUSAO"      => $cdoperador,
                        "NRORGINCLUSAO"       => $nrorg,
                        "CDCENTCUST"          => $composicao["CDCENTCUST"]
                    );
                    
                    $this->contratoFactory->inserirComposicoesContrato($params);
                }
            }    

            foreach ($elementosApareceProp as $elemento) {

                $elementoRaiz = null;

                if (isset($elemento["IDELEMENTORAIZ"])){
                    $elementoRaiz = $elemento["IDELEMENTORAIZ"];
                    $NmelementoRaiz = null;
                }
                else {

                    $params =  array(
                        "IDELEMENTO" => $elemento["IDELEMENTO"]
                    );
                    
                    $eleraizAux =  $this->contratoFactory->getElementoRaiz($params);

                    if (count($eleraizAux) > 0) {
                        $elementoRaiz = $eleraizAux[0]['IDELEMENTO'];
                        $NmelementoRaiz = $eleraizAux[0]['NMSERVORCA'];
                    }
                }

                /* Recebe servicos e medidas do elemento */
                $params =  array(
                    "NRTIPOORCAMENTO" => $escopo,
                    "NRORG"           => $nrorg
                );

                $dadosMedAux = $this->contratoFactory->getServicosMedidasElementos($params, $elementoRaiz);

                if (count($dadosMedAux) > 0){
                    
                    $dadosMed = $this->validaTipoMedida($dadosMedAux, $elementosApareceProp);

                    foreach ($dadosMed as $dadomed){
                        $qtmedidavariavel = 1;
                        $vrPreco = 0;
                        $franquia = 0;

                        $params =  array(
                            "CDTPMEDIDASERV"     => $dadomed["CDTPMEDIDASERV"],
                            "CDTPMEDIDAVARIAVEL" => $dadomed["CDTPMEDIDAVARIAVEL"],
                            "NRTIPOORCAMENTO"    => $escopo,
                            "NRMOEDA"            => $moeda,
                            "CDSERVORCA"         => $dadomed["CDSERVORCARELAC"],
                            "NRORG"              => $nrorg
                        );
                    
                        $precoFranq = $this->contratoFactory->getPrecoEFranquiaElemento($params);

                        if (count($precoFranq) == 0){
                            throw new \Exception("Operação bloqueda!<br><br> Não foi encontrado preço definido para o serviço '".$dadomed["NMSERVORCARELAC"]."' na tabela de preços vinculada ao contrato.");   
                        }
                        else {
                            $vrPreco = $precoFranq[0]["PRECO"];
                            $franquia = $precoFranq[0]["QTFRANQUIA"];
                        }

                        /* Verifica se a medida ja existe no relacionamento dos elementos do contrato, se não existir, insere. */
                        $this->insereMedidaContrato($contrato, $escopo, $elementoRaiz, $dadomed, $qtmedidavariavel, $franquia, $nrorg, $cdoperador);
                        
                        /*  Verifica se o elemento ja existe no relacionamento dos elementos do contrato, se não existir, insere.*/
                        if ($elemento["CDTPMEDIDAVARIAVEL"] == $dadomed["CDTPMEDIDAVARIAVEL"]){
                            $this->insereElementosContrato($contrato, $escopo, $elemento, $dadomed, $vrPreco, $qtmedidavariavel, $nrorg, $cdoperador);
                        }

                        /*  Chama a função para inserir os itens*/
                        $this->preparaInsItensElementosContr($elemento, $dadomed, $contrato, $escopo, $moeda, $vrPreco, $elementoRaiz, $qtmedidavariavel, $nrorg, $cdoperador);
                    }
                }
            }

            $params = array(
                "NRSEQCONTRATO"  => $contrato,
                "NRORG"          => $nrorg
            );

            $servicos = $this->contratoFactory->getServicosContrato($params);

            $this->insereElementosNaoApareceProp($elementosNaoApareceprop, $contrato, $escopo, $modelo, $moeda, $dados, $nrorg, $cdoperador, $idMantemDescAcres, $itensContrato, $servicos);
           
            if (count($servicos) > 0 ){

                foreach ($servicos as $servico) {
                    $params = array(
                        "NRSEQCONTRATO"  => $contrato,
                        "CDSERVORCA"     => $servico["CDSERVORCA"],
                        "NRORG"          => $nrorg
                    );
        
                    $this->contratoFactory->atualizarValorItemPai($params);
                }  
                
                /* Insere negociações do contrato*/
                $this->inserirNegociacaoElemContrato($contrato, $escopo, $modelo, $nrorg, $cdoperador, $idMantemDescAcres, $itensContrato, $negociacoes, $parcelas, $descontos, $servicos);
            }
                
        }
        catch(\Exception $e) {
           throw new \Exception($e->getMessage());
        }
    }

    public function insereMedidaContrato($contrato, $escopo, $elementoRaiz, $dadomed, $qtmedidavariavel, $franquia, $nrorg, $cdoperador){

        $params =  array(
            "NRSEQCONTRATO"      => $contrato,
            "CDTPMEDIDAVARIAVEL" => $dadomed["CDTPMEDIDAVARIAVEL"],
            "IDELEMENTORAIZ"     => $elementoRaiz,
            "NRTIPOORCAMENTO"    => $escopo,
            "CDSERVORCA"         => $dadomed["CDSERVORCARELAC"],
            "NRORG"              => $nrorg
        );
        $validaMed = $this->contratoFactory->validaExisteMedidaContrato($params);

        if ($validaMed == 0){
    
            $nrmedidacontrato = $this->newCode->getCodeByTableName("FCT_RELACMEDIDACONTRATO", $nrorg, 1, 10, true);
            $params = array(
                "NRMEDIDACONTRATO"   => $nrmedidacontrato,
                "NRSEQCONTRATO"      => $contrato,
                "CDTPMEDIDAVARIAVEL" => $dadomed["CDTPMEDIDAVARIAVEL"],
                "QTMEDIDAVARIAVEL"   => $qtmedidavariavel,
                "NRORG"              => $nrorg,
                "NRORGINCLUSAO"      => $nrorg,
                "CDOPERINCLUSAO"     => $cdoperador,
                "IDATIVO"            => "S",
                "IDELEMENTORAIZ"     => $elementoRaiz,
                "QTFRANQUIA"         => $franquia,
                "NRTIPOORCAMENTO"    => $escopo,
                "IDAPARECEPROPOSTA"  => "S"
            );

            $this->contratoFactory->inserirTipoDeMedidaContrato($params);
        }
    }

    public function insereElementosContrato($contrato, $escopo, $elemento, $dadomed, $vrPreco, $qtmedidavariavel, $nrorg, $cdoperador) {

        $params =  array(
            "NRSEQCONTRATO"   => $contrato,
            "NRTIPOORCAMENTO" => $escopo,
            "NRCOMPSERVICO"   => $elemento["NRCOMPSERVICO"],
            "CDSERVORCA"      => $dadomed["CDSERVORCARELAC"],
            "IDELEMENTO"      => $elemento["IDELEMENTO"],
            "IDELEMENTOPAI"   => $elemento["IDELEMENTOPAI"],
            "NRORG"           => $nrorg
        );

        $validaEle = $this->contratoFactory->validaExisteElementoContrato($params);
        
        if (count($validaEle) > 0){

            $params =  array(
                "OPERADOR"       => $cdoperador,
                "NRORG"          => $nrorg,
                "NRTRABSERVCONT" => $validaEle[0]["NRTRABSERVCONT"]
            );

            $this->contratoFactory->updateIdMarcadoElementoContrato($params);    
        }
        else {
            $nrtrabservcont = $this->newCode->getCodeByTableName("FCT_TRABSERVCONTRATO", $nrorg, 1, 10, true);
            $params = array(
                "NRTRABSERVCONT"    => $nrtrabservcont,
                "NRSEQCONTRATO"     => $contrato,
                "NRTIPOORCAMENTO"   => $escopo,
                "NRCOMPSERVICO"     => $elemento["NRCOMPSERVICO"],
                "NRITCOMPSERVICO"   => $elemento["NRITCOMPSERVICO"],
                "IDELEMENTO"        => $elemento["IDELEMENTO"],
                "IDELEMENTOPAI"     => $elemento["IDELEMENTOPAI"],
                "IDTIPOELEMENTO"    => ($elemento["IDTIPOELEMENTO"] != null) ? $elemento["IDTIPOELEMENTO"] : "M",  
                "IDESCOLHIDO"       => isset($elemento["IDESCOLHIDO"]) ? $elemento["IDESCOLHIDO"] : "S",
                "CDSERVORCA"        => $dadomed["CDSERVORCARELAC"],
                "QTSERVORCA"        => 1,
                "CDTPMEDIDASERV"    => $dadomed["CDTPMEDIDAVARIAVEL"],
                "QTMEDSERVORCA"     => 1,
                "VRUNITSERVORCA"    => $vrPreco,
                "VRTOTSERVORCA"     => $vrPreco,
                "IDATIVO"           => "S",
                "NRORG"             => $nrorg,
                "CDOPERINCLUSAO"    => $cdoperador,
                "NRORGINCLUSAO"     => $nrorg,
                "IDSERVOBRIGCOMP"   => $elemento["IDSERVOBRIGCOMP"],
                "QTMEDIDAVARIAVEL"  => $qtmedidavariavel,
                "QTMEDIDACALC"      => 1,
                "IDAPARECEPROPOSTA" => "S",
                "CDCENTCUST"        => $elemento["CDCENTCUST"]
            );
            
            $this->contratoFactory->inserirElementosContrato($params);
        }   
    }

    public function insereElementosNaoApareceProp($elementos, $contrato, $escopo, $modelo, $moeda, $dados, $nrorg, $cdoperador, $idMantemDescAcres, $itensContrato, $servicos){
        foreach ($elementos as $elemento) {

            $elementoRaiz = null;

            if (isset($elemento["IDELEMENTORAIZ"])){
                $elementoRaiz = $elemento["IDELEMENTORAIZ"];
                $NmelementoRaiz = null;
            }
            else {

                $params =  array(
                    "IDELEMENTO" => $elemento["IDELEMENTO"]
                );
                
                $eleraizAux =  $this->contratoFactory->getElementoRaiz($params);

                if (count($eleraizAux) > 0) {
                    $elementoRaiz = $eleraizAux[0]['IDELEMENTO'];
                    $NmelementoRaiz = $eleraizAux[0]['NMSERVORCA'];
                }
            }

            /*  Verifica se a medida ja existe no relacionamento dos elementos do contrato, se não existir, insere. */
            $params =  array(
            "NRSEQCONTRATO"      => $contrato,
            "CDTPMEDIDAVARIAVEL" => $elemento["CDTPMEDIDAVARIAVEL"],
            "IDELEMENTORAIZ"     => $elementoRaiz,
            "NRTIPOORCAMENTO"    => $escopo,
            "CDSERVORCA"         => null,
            "NRORG"              => $nrorg
            );
            $validaMed = $this->contratoFactory->validaExisteMedidaContrato($params);

            if ($validaMed == 0){
        
                $nrmedidacontrato = $this->newCode->getCodeByTableName("FCT_RELACMEDIDACONTRATO", $nrorg, 1, 10, true);
                $params = array(
                    "NRMEDIDACONTRATO"   => $nrmedidacontrato,
                    "NRSEQCONTRATO"      => $contrato,
                    "CDTPMEDIDAVARIAVEL" => $elemento["CDTPMEDIDAVARIAVEL"],
                    "QTMEDIDAVARIAVEL"   => 1,
                    "NRORG"              => $nrorg,
                    "NRORGINCLUSAO"      => $nrorg,
                    "CDOPERINCLUSAO"     => $cdoperador,
                    "IDATIVO"            => "S",
                    "IDELEMENTORAIZ"     => $elementoRaiz,
                    "QTFRANQUIA"         => 0,
                    "NRTIPOORCAMENTO"    => $escopo,
                    "IDAPARECEPROPOSTA"  => $elemento["IDAPARECEPROPOSTA"]
                );

                $this->contratoFactory->inserirTipoDeMedidaContrato($params);
            }

            /*  Verifica se o elemento ja existe no relacionamento dos elementos do contrato, se não existir, insere.*/
            $params =  array(
                "NRSEQCONTRATO"   => $contrato,
                "NRTIPOORCAMENTO" => $escopo,
                "NRCOMPSERVICO"   => $elemento["NRCOMPSERVICO"],
                "CDSERVORCA"      => null,
                "IDELEMENTO"      => $elemento["IDELEMENTO"],
                "IDELEMENTOPAI"   => $elemento["IDELEMENTOPAI"],
                "NRORG"           => $nrorg
            );

            $validaEle = $this->contratoFactory->validaExisteElementoContrato($params);
            
            if (count($validaEle) > 0){

                $params =  array(
                    "OPERADOR"       => $cdoperador,
                    "NRORG"          => $nrorg,
                    "NRTRABSERVCONT" => $validaEle[0]["NRTRABSERVCONT"]
                );

                $this->contratoFactory->updateIdMarcadoElementoContrato($params);    
            }
            else {
                $nrtrabservcont = $this->newCode->getCodeByTableName("FCT_TRABSERVCONTRATO", $nrorg, 1, 10, true);
                $params = array(
                    "NRTRABSERVCONT"    => $nrtrabservcont,
                    "NRSEQCONTRATO"     => $contrato,
                    "NRTIPOORCAMENTO"   => $escopo,
                    "NRCOMPSERVICO"     => $elemento["NRCOMPSERVICO"],
                    "NRITCOMPSERVICO"   => $elemento["NRITCOMPSERVICO"],
                    "IDELEMENTO"        => $elemento["IDELEMENTO"],
                    "IDELEMENTOPAI"     => $elemento["IDELEMENTOPAI"],
                    "IDTIPOELEMENTO"    => ($elemento["IDTIPOELEMENTO"] != null) ? $elemento["IDTIPOELEMENTO"] : "M",  
                    "IDESCOLHIDO"       => isset($elemento["IDESCOLHIDO"]) ? $elemento["IDESCOLHIDO"] : "S",
                    "CDSERVORCA"        => null,
                    "QTSERVORCA"        => 1,
                    "CDTPMEDIDASERV"    => $elemento["CDTPMEDIDAVARIAVEL"],
                    "QTMEDSERVORCA"     => 1,
                    "VRUNITSERVORCA"    => 0,
                    "VRTOTSERVORCA"     => 0,
                    "IDATIVO"           => "S",
                    "NRORG"             => $nrorg,
                    "CDOPERINCLUSAO"    => $cdoperador,
                    "NRORGINCLUSAO"     => $nrorg,
                    "IDSERVOBRIGCOMP"   => $elemento["IDSERVOBRIGCOMP"],
                    "QTMEDIDAVARIAVEL"  => 1,
                    "QTMEDIDACALC"      => 1,
                    "IDAPARECEPROPOSTA" => $elemento["IDAPARECEPROPOSTA"],
                    "CDCENTCUST"        => $elemento["CDCENTCUST"]
                );
                
                $this->contratoFactory->inserirElementosContrato($params);
            }  

            foreach($servicos as $servico) {

                $dadosMedida = array(
                    "CDTPMEDIDASERV" => $servico["CDTPMEDIDASERV"],
                    "CDTPMEDIDAVARIAVEL" => $elemento["CDTPMEDIDAVARIAVEL"],
                    "CDSERVORCARELAC" => $servico["CDSERVORCA"],
                    "NMSERVORCARELAC" => $servico["NMITEMCONTRATO"]
                );

                /*  Chama a função para inserir os itens*/
                $this->preparaInsItensElementosContr($elemento, $dadosMedida, $contrato, $escopo, $moeda, 0, $elementoRaiz, 1, $nrorg, $cdoperador);
            }
  
        }
    }

    public function preparaInsItensElementosContr ($elemento, $dadomed, $contrato, $escopo, $moeda, $vrPreco, $elementoRaiz, $qtmedidavariavel, $nrorg, $cdoperador) {

            $params =  array(
                "NRSEQCONTRATO"         => $contrato,
                "CDSERVORCA"            => $dadomed["CDSERVORCARELAC"],
                "CDTPMEDIDASERV"        => $dadomed["CDTPMEDIDASERV"],
                "CDTPMEDIDAVARIAVEL"    => $dadomed["CDTPMEDIDAVARIAVEL"],
                "NRORG" => $nrorg
            );

            $validaPrecBcont =  $this->contratoFactory->validaVarPrecBseServCont($params);
            
            if ($validaPrecBcont == 0) {
                
                $varPrecOrcamento = $this->contratoFactory->getVarPrecOrcamento($params);

                if (count($varPrecOrcamento) > 0){

                    foreach ($varPrecOrcamento as $variacao){
    
                        $nrvarprecbaseservcont = $this->newCode->getCodeByTableName("FCT_VARPRECBASESERVCONT", $nrorg, 1, 10, true);
    
                        $params =  array(
                            "NRVARPRECBASESERVCONT" => $nrvarprecbaseservcont,
                            "NRSEQCONTRATO"         => $contrato,
                            "CDSERVORCA"            => $variacao["CDSERVORCA"],
                            "CDTPMEDIDASERV"        => $variacao["CDTPMEDIDASERV"],
                            "CDTPMEDIDAVARIAVEL"    => $variacao["CDTPMEDIDAVARIAVEL"],
                            "QTMEDIDAINIVARIACAO"   => $variacao["QTMEDIDAINIVARIACAO"],
                            "QTMEDIDAFIMVARIACAO"   => $variacao["QTMEDIDAFIMVARIACAO"],
                            "QTFRANQUIA"            => $variacao["QTFRANQUIA"],
                            "VRPRECOVARIACAO"       => $variacao["VRPRECOVARIACAO"],
                            "IDMULTIPVARIACAO"      => $variacao["IDMULTIPVARIACAO"],
                            "NRORG"                 => $nrorg, 
                            "OPERADOR"              => $cdoperador
                        );
    
                        $this->contratoFactory->insVariacaoPrecoContrato($params);
    
                    } 
                }
                else {
                    $params =  array(
                        "NRTIPOORCAMENTO" => $escopo,
                        "NRMOEDA" => $moeda,
                        "CDSERVORCA" => $dadomed["CDSERVORCARELAC"],
                        "CDTPMEDIDASERV" => $dadomed["CDTPMEDIDASERV"],
                        "CDTPMEDIDAVARIAVEL" => $dadomed["CDTPMEDIDAVARIAVEL"],
                        "NRORG" => $nrorg
                    );
    
                    $variacoesPrec = $this->contratoFactory->getDadosVariacaoPreco($params);
    
                    foreach ($variacoesPrec as $variacao){
    
                        $nrvarprecbaseservcont = $this->newCode->getCodeByTableName("FCT_VARPRECBASESERVCONT", $nrorg, 1, 10, true);
    
                        $params =  array(
                            "NRVARPRECBASESERVCONT" => $nrvarprecbaseservcont,
                            "NRSEQCONTRATO"         => $contrato,
                            "CDSERVORCA"            => $dadomed["CDSERVORCARELAC"],
                            "CDTPMEDIDASERV"        => $dadomed["CDTPMEDIDASERV"],
                            "CDTPMEDIDAVARIAVEL"    => $dadomed["CDTPMEDIDAVARIAVEL"],
                            "QTMEDIDAINIVARIACAO"   => $variacao["QTMEDIDAINIVARIACAO"],
                            "QTMEDIDAFIMVARIACAO"   => $variacao["QTMEDIDAFIMVARIACAO"],
                            "QTFRANQUIA"            => $variacao["QTFRANQUIA"],
                            "VRPRECOVARIACAO"       => $variacao["VRPRECOVARIACAO"],
                            "IDMULTIPVARIACAO"      => $variacao["IDMULTIPVARIACAO"],
                            "NRORG"                 => $nrorg, 
                            "OPERADOR"              => $cdoperador
                        );
    
                        $this->contratoFactory->insVariacaoPrecoContrato($params);
                    } 
                }

                $params =  array(
                    "NRTIPOORCAMENTO" => $escopo,
                    "NRMOEDA" => $moeda,
                    "CDSERVORCA" => $dadomed["CDSERVORCARELAC"],
                    "CDTPMEDIDASERV" => $dadomed["CDTPMEDIDASERV"],
                    "CDTPMEDIDAVARIAVEL" => $dadomed["CDTPMEDIDAVARIAVEL"],
                    "NRORG" => $nrorg
                );

                $variacoesPrec = $this->contratoFactory->getDadosVariacaoPreco($params);

                foreach ($variacoesPrec as $variacao){

                    $nrvarprecbaseservcont = $this->newCode->getCodeByTableName("FCT_VARPRECBASESERVCONT", $nrorg, 1, 10, true);

                    $params =  array(
                        "NRVARPRECBASESERVCONT" => $nrvarprecbaseservcont,
                        "NRSEQCONTRATO"         => $contrato,
                        "CDSERVORCA"            => $dadomed["CDSERVORCARELAC"],
                        "CDTPMEDIDASERV"        => $dadomed["CDTPMEDIDASERV"],
                        "CDTPMEDIDAVARIAVEL"    => $dadomed["CDTPMEDIDAVARIAVEL"],
                        "QTMEDIDAINIVARIACAO"   => $variacao["QTMEDIDAINIVARIACAO"],
                        "QTMEDIDAFIMVARIACAO"   => $variacao["QTMEDIDAFIMVARIACAO"],
                        "QTFRANQUIA"            => $variacao["QTFRANQUIA"],
                        "VRPRECOVARIACAO"       => $variacao["VRPRECOVARIACAO"],
                        "IDMULTIPVARIACAO"      => $variacao["IDMULTIPVARIACAO"],
                        "NRORG"                 => $nrorg, 
                        "OPERADOR"              => $cdoperador
                    );

                    $this->contratoFactory->insVariacaoPrecoContrato($params);

                }
            }

            /* Verifica se existe item pai */
            $params =  array(
                "CDSERVORCA"   => $dadomed["CDSERVORCARELAC"],
                "NRSEQCONTRATO"   => $contrato,
                "NRORG" => $nrorg
            );

            $retItemPai = $this->contratoFactory->verificaItemPaiInserido($params);
            
            if ( count($retItemPai) > 0){ /* Neste caso, o item pai já está inserido, então insere o elemento como item filho e atualiza o valor do item pai*/
                $itemPai = $retItemPai[0]['NRITEMOCONTRATO'];
                
                /* Valida se o item já está inserido */
                $params =  array(
                    "NRSEQCONTRATO"      => $contrato,
                    "CDSERVORCA"         => $dadomed["CDSERVORCARELAC"],
                    "IDELEMENTO"         => $elementoRaiz,
                    "CDTPMEDIDAVARIAVEL" => $dadomed["CDTPMEDIDAVARIAVEL"],
                    "NRORG"              => $nrorg
                );
    
                $validaItem = $this->contratoFactory->validaExisteItemContratoElemento($params);

                if ($validaItem == 0){
                    /*Insere Elemento vinculado ao item pai */
                    $item = array(
                        "NRITEMCONTRATOPAI"      => $itemPai,
                        "NRSEQCONTRATO"          => $contrato,
                        "CDSERVORCA"             => $dadomed["CDSERVORCARELAC"],
                        "NMITEMCONTRATO"         => isset($elemento["NMELEMENTO"]) ? $elemento["NMELEMENTO"] : $elemento["NMSERVORCA"],
                        "IDELEMENTO"             => $elementoRaiz,
                        "CDTPMEDIDASERV"         => $dadomed["CDTPMEDIDASERV"],
                        "VRUNITITEMCONT"         => $vrPreco,
                        "VRUNITITEMCONTTBLPRECO" => $vrPreco,
                        "VRTOTITEMCONT"          => $qtmedidavariavel*$vrPreco,
                        "CDTPMEDIDAVARIAVEL"     => $dadomed["CDTPMEDIDAVARIAVEL"],
                        "IDAPARECEPROPOSTA"      => isset($elemento["IDAPARECEPROPOSTA"]) ? $elemento["IDAPARECEPROPOSTA"] : "S",
                        "NRMOEDA"                => $moeda,
                        "QTMEDIDA"               => $qtmedidavariavel
                    );

                    $itemIns = $this->insereItensElementosContr($item, $nrorg, $cdoperador);
                
                    /*Atualiza valor Item Pai*/ 

                    $params =  array(
                        "PRECO"           =>  $vrPreco,
                        "NRITEMOCONTRATO" => $itemPai,
                        "NRORG"           => $nrorg
                    );

                    $this->contratoFactory->updateValorItemPai($params);

                }
            }
            else{ /* Neste caso, o item pai não está inserido, então insere o item pai e o elemento como item filho ambos com o valor da tabela de preços*/

                /*Insere Item pai */
                $item = array(
                    "NRITEMCONTRATOPAI"      => null,
                    "NRSEQCONTRATO"          => $contrato,
                    "CDSERVORCA"             => $dadomed["CDSERVORCARELAC"],
                    "NMITEMCONTRATO"         => $dadomed["NMSERVORCARELAC"],
                    "IDELEMENTO"             => null,
                    "CDTPMEDIDASERV"         => $dadomed["CDTPMEDIDASERV"],
                    "VRUNITITEMCONT"         => $vrPreco,
                    "VRUNITITEMCONTTBLPRECO" => $vrPreco,
                    "VRTOTITEMCONT"          => $qtmedidavariavel*$vrPreco,
                    "CDTPMEDIDAVARIAVEL"     => $dadomed["CDTPMEDIDAVARIAVEL"],
                    "IDAPARECEPROPOSTA"      => isset($elemento["IDAPARECEPROPOSTA"]) ? $elemento["IDAPARECEPROPOSTA"] : "S",
                    "NRMOEDA"                => $moeda,
                    "QTMEDIDA"               => $qtmedidavariavel
                );

                $itemIns = $this->insereItensElementosContr($item, $nrorg, $cdoperador);

                /*Insere Elemento vinculado ao item pai */
                $item = array(
                    "NRITEMCONTRATOPAI"      => $itemIns,
                    "NRSEQCONTRATO"          => $contrato,
                    "CDSERVORCA"             => $dadomed["CDSERVORCARELAC"],
                    "NMITEMCONTRATO"         => $elemento["NMELEMENTO"],
                    "IDELEMENTO"             => $elementoRaiz,
                    "CDTPMEDIDASERV"         => $dadomed["CDTPMEDIDASERV"],
                    "VRUNITITEMCONT"         => $vrPreco,
                    "VRUNITITEMCONTTBLPRECO" => $vrPreco,
                    "VRTOTITEMCONT"          => $qtmedidavariavel*$vrPreco,
                    "CDTPMEDIDAVARIAVEL"     => $dadomed["CDTPMEDIDAVARIAVEL"],
                    "IDAPARECEPROPOSTA"      => isset($elemento["IDAPARECEPROPOSTA"]) ? $elemento["IDAPARECEPROPOSTA"] : "S",
                    "NRMOEDA"                => $moeda,
                    "QTMEDIDA"               => $qtmedidavariavel
                );

                $itemIns = $this->insereItensElementosContr($item, $nrorg, $cdoperador);
            }

    }

    public function insereItensElementosContr($item, $nrorg, $cdoperador) {

        $nritemocontrato = $this->newCode->getCodeByTableName("FCT_ITEMCONTRATO", $nrorg, 1, 10, true);
        $params = array(
            "NRORG"                  => $nrorg,
            "NRITEMOCONTRATO"        => $nritemocontrato,
            "NRITEMCONTRATOPAI"      => $item["NRITEMCONTRATOPAI"],
            "NRSEQCONTRATO"          => $item["NRSEQCONTRATO"],
            "CDSERVORCA"             => $item["CDSERVORCA"],
            "NMITEMCONTRATO"         => $item["NMITEMCONTRATO"],
            "IDELEMENTO"             => $item["IDELEMENTO"],
            "QTITEMCONTRATO"         => 1,
            "CDTPMEDIDASERV"         => $item["CDTPMEDIDASERV"],
            "QTMEDIDACONTR"          => $item["QTMEDIDA"],
            "QTPARCELASFATU"         => null,
            "NRDIAVENCPARCELASFATU"  => null,
            "VRUNITITEMCONT"         => $item["VRUNITITEMCONT"],
            "VRUNITITEMCONTTBLPRECO" => $item["VRUNITITEMCONTTBLPRECO"],
            "VRTOTITEMCONT"          => $item["VRTOTITEMCONT"],
            "CDTPMEDIDAVARIAVEL"     => $item["CDTPMEDIDAVARIAVEL"],
            "NRITEMORCAMENTO"        => null,
            "CDPRODUTO"              => null,
            "SGUNIDADE"              => null,
            "IDUNIDTEMPOSERV"        => null,
            "QTTEMPOSERV"            => null,
            "DTINICFATCONTR"         => null,
            "IDITEMATIVO"            => 'S',
            "IDMULTMEDVRTOT"         => 'S',
            "IDADICITEMCONT"         => 'N',
            "IDADICCOBRCONT"         => 'N',
            "IDFATURAITEM"           => 'SIM',
            "VRDESCONTO"             => 0,
            "IDTPDESCONTO"           => 'S',
            "QTMEDIDACALCULADA"      => $item["QTMEDIDA"],
            "IDAPARECEPROPOSTA"      => $item["IDAPARECEPROPOSTA"],
            "NRMOEDA"                => $item["NRMOEDA"]
        );

        $this->contratoFactory->inserirItensContrato($params);

        return $nritemocontrato;
    }


    /**
     * Insere a negociação de valores apos uma edição nos elementos ou 
     * tipo de medida do contrato
    **/
    public function inserirNegociacaoElemContrato($contrato, $escopo, $modelo, $nrorg, $cdoperador, $idMantemDescAcres, $itensContrato, $negociacoes, $parcelas, $descontos, $servicosAux){

        /* 1 - Verifica se deseja manter os descontos,  se sim, grava.*/ 
        if(($idMantemDescAcres == 'S') && (count($descontos) == 0)) {
            $descontos = $this->getDescontosContrato($contrato, $nrorg);
        }

        /* 2 - Recebe os dados das negociações anteriores e parcelas anteriores para ajustes de valores*/

        $params = array(
            "NRSEQCONTRATO"  => $contrato,
            "NRORG"          => $nrorg
        );
        if ($negociacoes == null) {
            $negociacoes = $this->contratoFactory->getParametrosFaturaNegociacoesContrato($params);
        }
        
        if ($parcelas == null) {
            $parcelas = $this->contratoFactory->getParcelasContrato($params);
        }
        /* 3 - Exclui as negociações anteriores */
        $this->excluirNegociacaoDeValoresContrato($contrato, $nrorg);

        /* 4 - Recria as negociações de valores */
        $servicos = "";

        foreach ($servicosAux as $servico){
            $servicos .= $servico['CDSERVORCA'].',';
        }

        $servicos = substr($servicos, 0, strlen($servicos) - 1);

        $params = array(
            "NRSEQMODCONTRA" => $modelo,
            "NRSEQCONTRATO"  => $contrato,
            "NRORG"          => $nrorg
        );
        $itensNegociacao = $this->contratoFactory->getParametrosFaturamentoItensNegociacaoContrato($params, $escopo, $servicos);
        $cdNegociacoesInseridas = array();
        $itemAnterior           = array();
        
        if(count($itensNegociacao) == 0)
            throw new \Exception('Operação bloqueada. <br/><br/>Não foi possível inserir a Negociação de Valores. Certifique-se que o modelo de contrato esteja ligado a um escopo de faturamento, que os parâmetros de faturamento estejam cadastrados e tente novamente.');
        
        foreach($itensNegociacao as $item) {
            if ($item["CDFILIALFATURA"] == null) 
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Unidade para Faturamento" não foi encontrado para o item "' . $item["NMITEMORCAMENTO"] . '". Favor conferir a parametrização de faturamento do Escopo.');
            
            if ($item["CDTIPOOPERFATURA"] == null)
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Tipo de Operação da Nota Fiscal" não foi encontrado para o item "' . $item["NMITEMORCAMENTO"] . '". Favor conferir a parametrização de faturamento do Escopo.');
            
            if ($item["CDSERIENF"] == null) 
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Série da Nota Fiscal" não foi encontrado para o item "' . $item["NMITEMORCAMENTO"] . '". Favor conferir a parametrização de faturamento do Escopo.');
    
            $competencia = array();
            if ($item["IDTPFATURA"] != "P") {
                $params = array(
                    "NRTIPOORCAMENTO" => $item["NRTIPOORCAMENTO"],
                    "CDSERVORCA"      => $item["CDSERVORCA"],
                    "NRORG"           => $nrorg,
                );
                $competencia = $this->propostaFactory->getCompetenciaItemNegociacao($params);
            }
            
            $item["COMPETENCIA"] = print_r($competencia, true);
            if ($this->propostaService->itensNegociacaoSaoDiferentes($item, $itemAnterior)) {
                $nrnegociacaocontrato     = $this->inserirDadosNegociacaoContrato($item, $item["NRPARCFATURA"], $nrorg, $cdoperador, null);
                $cdNegociacoesInseridas[] = $nrnegociacaocontrato;
                foreach ($competencia as $comp) 
                    $this->inserirCompetenciaNegociacaoContrato($comp, $nrnegociacaocontrato, $nrorg, $cdoperador);
            }
            $this->inserirItemNegociacaoContrato($item, $nrnegociacaocontrato, $item, null, $nrorg, $cdoperador);
            $params = array(
                "NRSEQCONTRATO"     => $contrato,
                "NRITEMCONTRATOPAI" => $item["NRITEMOCONTRATO"],
                "NRORG"             => $nrorg
            );
            $itensFilhos = $this->contratoFactory->getItensFilhosItemContrato($params);
            foreach ($itensFilhos as $itemFilho) {
                $this->inserirItemNegociacaoContrato($itemFilho, $nrnegociacaocontrato, $item, null, $nrorg, $cdoperador);
            }
            
            $itemAnterior = $item;
        }
        
        foreach ($cdNegociacoesInseridas as $cod) {
            $this->atualizarValoresNegociacaoContrato($cod, $nrorg, $cdoperador);
        }

        /* 5 - Se for marcado para manter os descontos, recria os descontos */

        if(($idMantemDescAcres == 'S') && (count($descontos) > 0 )) {

            $this->recriarDescontosNegociacaoElemContrato($contrato, $descontos, $negociacoes, $nrorg, $cdoperador, $itensContrato);
        }
        
        $this->atualizarParcelasContratoContReneg($negociacoes, $contrato, $parcelas, $nrorg);
    }

    /**
     * Verifica se não houve alteração no valor das parcelas
    **/
    public function atualizarParcelasContratoContReneg($negociacoes, $nrseqcontrato, $parcelas, $nrorg) {
      
        foreach($negociacoes as $negociacao) {
            if ($negociacao["IDTPFATURA"] == 'P'){
                
                $qtParc = 0;
                foreach($parcelas as $parcela){
                    
                    if ($qtParc == 0){
                        $qtDiaFat = $parcela['QTDIASFATURAMENTO'];
                    }
                    else {
                        if ($parcela['QTDIASFATURAMENTO'] < $qtDiaFatAnte ){
                            $qtDiaFat = $parcela['QTDIASFATURAMENTO'];
                        }
                        else {
                            $qtDiaFat = $qtDiaFatAnte;
                        }
                    }

                    $diaVenc = $parcela['NRDIAVENCIMENTO']; 

                    $qtParc = $qtParc+1;
                    $qtDiaFatAnte = $parcela['QTDIASFATURAMENTO'];
                }

                $params = array(
                    "NRSEQCONTRATO"    => $nrseqcontrato,
                    "IDTPFATURA"       => $negociacao["IDTPFATURA"],
                    "CDSERIENF"        => $negociacao["CDSERIENF"],
                    "CDTIPOOPERFATURA" => $negociacao["CDTIPOOPERFATURA"],
                    "CDFILIALFATURA"   => $negociacao["CDFILIALFATURA"],
                    "NRORG"            => $nrorg
                );
                
                $newnegociacao = $this->contratoFactory->getNovaNegociacaoCorrespondente($params);

                if (count($newnegociacao) > 0) {
                    if ($qtParc > 0){
                        $this->parcelarNegociacaoPorIgual($newnegociacao[0]["NRNEGOCIACAOCONTRATO"], null, $qtParc, $qtDiaFat, $diaVenc, null, $newnegociacao[0]["VRTOTITEMCOMDESC"]);
                    }
                }
            }
        }
    }

    public function recriarDescontosNegociacaoElemContrato($contrato, $descontosContrato, $negociacoes, $nrorg, $cdoperador, $itensContrato){

        foreach($itensContrato as $item) {
            $novoItem  = $this->getNovoItemCorrespondente($item["IDELEMENTO"], $item["CDSERVORCA"], $item["CDTPMEDIDAVARIAVEL"], $contrato, $nrorg);
            if(!empty($novoItem)) {
                $nrnewitemcontrato    = $novoItem["NRITEMOCONTRATO"];
                $nrnewitemcontratopai = $novoItem["NRITEMCONTRATOPAI"];
            }
            else {
                $nrnewitemcontrato    = null;
                $nrnewitemcontratopai = null;    
            }
            
            if($item["IDELEMENTO"]) {

                if(!empty($novoItem)) {
                    $qtmedidacont   = $novoItem["QTMEDIDACALCULADA"];
                    $dadosTblPreco  = $this->getIdMultiplicavariacaoItem($item["CDSERVORCA"], $item["CDTPMEDIDASERV"], $item["CDTPMEDIDAVARIAVEL"], $qtmedidacont, $nrorg);
                    
                    $vrtblpreco = $dadosTblPreco["VRPRECOVARIACAO"];
                    if($dadosTblPreco["IDMULTIPVARIACAO"] == "S") $vrtblpreco *= $this->getSomatorioMedidaServico($item["CDSERVORCA"], $item["IDELEMENTO"], $contrato, $nrorg); 
                    
                    $vrunititem = $item["VRUNITITEMCONT"];
                    $vrtotalitemcont = ($dadosTblPreco == 'N') ? $vrunititem : $vrunititem * $qtmedidacont;
                    $params = array(
                        "NRORG"                  => $nrorg,
                        "NRITEMOCONTRATO"        => $nrnewitemcontrato,
                        "QTMEDIDACONTR"          => $qtmedidacont,
                        "VRUNITITEMCONTTBLPRECO" => $vrtblpreco,
                        "VRUNITITEMCONT"         => $vrunititem,
                        "VRTOTITEMCONT"          => $vrtotalitemcont
                    );
                    
                    $this->contratoFactory->atualizarValorItensOrcamento($params);
                    
                    $params = array (
                        "NRSEQCONTRATO"  => $contrato,
                        "CDSERVORCA"     => $item["CDSERVORCA"],
                        "NRORG"          => $nrorg
                    );
                    $this->contratoFactory->atualizarValorItemPai($params);
                    $this->atualizarValorItensNegociacaoValores($contrato, $nrnewitemcontrato, $vrtotalitemcont, $nrnewitemcontratopai, $nrorg, $item["CDOPERINCLUSAO"]);
                }    
            }

            foreach($descontosContrato["NEGOCIACAO"] as &$desconto) {
                if($desconto["TIPODESCONTO"] == "ITENS" && $desconto["NRITEMOCONTRATO"] == $item["NRITEMOCONTRATO"]) {
                    if($nrnewitemcontrato) $desconto["NRITEMOCONTRATO"] = $nrnewitemcontrato; 
                    else unset($desconto);
                }
            }
        }

        foreach($negociacoes as $negociacao) {
            $params = array(
                "NRSEQCONTRATO"    => $contrato,
                "IDTPFATURA"       => $negociacao["IDTPFATURA"],
                "CDSERIENF"        => $negociacao["CDSERIENF"],
                "CDTIPOOPERFATURA" => $negociacao["CDTIPOOPERFATURA"],
                "CDFILIALFATURA"   => $negociacao["CDFILIALFATURA"],
                "NRORG"            => $nrorg
            );
            
            $newnegociacao = $this->contratoFactory->getNovaNegociacaoCorrespondente($params);
            foreach($descontosContrato as $key=>$descontos) {
                foreach($descontos as $row) {
                    if($row["NRNEGOCIACAOCONTRATO"] == $negociacao["NRNEGOCIACAOCONTRATO"]) {
                        if(count($newnegociacao) < 1) {
                            unset($row);
                        } else { 
                            if($key != "PORPERIODO") {
                                $vrpercdesc = $row["VRPERCDESCITEM"];
                                $vrdesconto = $row["VRDESCITEM"];
                            
                                $sqlAux = "VRPERCDESCITEM   = $vrpercdesc,
                                            VRDESCITEM       = VRTOTITEM * $vrpercdesc / 100,
                                            IDTPDESCONTO     = '" . $row['IDTPDESCONTO'] . "',
                                            VRTOTITEMCOMDESC = VRTOTITEM - (VRTOTITEM * $vrpercdesc / 100)";
                                
                                if($row["TIPODESCONTO"] == "ITENS") {
                                    $params = array(
                                        "NRNEGOCIACAOCONTRATO" => $newnegociacao[0]["NRNEGOCIACAOCONTRATO"],
                                        "NRITEMOCONTRATO"      => $row["NRITEMOCONTRATO"],
                                        "NRORG"                => $nrorg
                                    );
                                    $this->contratoFactory->atualizarItensNegociaco($params, $sqlAux);
                                } else {
                                    $params = array(
                                        "NRNEGOCIACAOCONTRATO" => $newnegociacao[0]["NRNEGOCIACAOCONTRATO"],
                                        "NRORG"                => $nrorg
                                    );
                                    $this->contratoFactory->atualizarNegociaco($params, $sqlAux);
                                }
                            } else {
                                $nrdescontoporperiodo = $this->newCode->getCodeByTableName("FCT_DESCPERIODONEGOCONT", $nrorg, 1, 10, true);
                                $vrdescitem = $newnegociacao[0]["VRTOTITEMCOMDESC"] * $row["VRPERCDESCITEM"] / 100;
                                $vrpercdesc = $row["VRPERCDESCITEM"];
                                $params = array(
                                    "NRDESCPERIODONEGOCONT" => $nrdescontoporperiodo,
                                    "IDATIVO"               => 'S',
                                    "NRORG"                 => $nrorg,
                                    "VRPERCDESCITEM"        => $vrpercdesc,
                                    "VRDESCITEM"            => $vrdescitem,
                                    "VRTOTITEMCOMDESC"      => $newnegociacao[0]["VRTOTITEMCOMDESC"] - $vrdescitem,
                                    "NRNEGOCIACAOCONTRATO"  => $newnegociacao[0]["NRNEGOCIACAOCONTRATO"],
                                    "QTMESESDESC"           => $row["QTMESESDESC"],
                                    "DTFINALVALIDADEDESC"   => $row["DTFINALVALIDADEDESC"],
                                    "DTINCLUSAO"            => $row["DTINCLUSAO"],
                                    "NRORGINCLUSAO"         => $row["NRORGINCLUSAO"],
                                    "CDOPERINCLUSAO"        => $row["CDOPERINCLUSAO"],
                                    "DTULTATU"              => $row["DTULTATU"],
                                    "NRORGULTATU"           => $row["NRORGULTATU"],
                                    "CDOPERULTATU"          => $row["CDOPERULTATU"],
                                    "NRORDEMAPLICADESC"     => $row["NRORDEMAPLICADESC"],
                                    "IDTPDESCONTO"          => $row["IDTPDESCONTO"]
                                );
                                $this->contratoFactory->inserirDescontoPorPeriodo($params);
                            }
                        }
                    }
                }
            }
        }
    }

    public function excluirElementoContr($contrato, $escopo, $modelo, $moeda, $idMantemDescAcres, $dados, $dadosMarcadosAux, $nrorg, $cdoperador) {

         /* Rotina será alterada para
            
             1 - Exlcuir somente os dados que não estão sendo utilizados mais
             2 - Para os dados marcados, deve apenas ser verificado se a medida variável deve ser atualizada, se sim, será atualizada apenas ela.*/
        $this->connection->beginTransaction();
        try {

            /* Recebe os dados a serem excluídos e separa os mesmos em Composições e Elementos. */
            $dadosExcluidos = $this->recebeElementosExclusaoContr($dados, $dadosMarcadosAux);

            /* Corrige as medidas dos elementos que estiverem diferente da medida do contrato */
            $dadosMarcados = $this->corrigeMedidasContrato($dadosMarcadosAux, $contrato, $nrorg);
            
            $elementos = array();
            $composicoes = array();
            foreach($dadosExcluidos as $dado){
                if($dado["TIPO"] == 'C') {
                    array_push($composicoes, $dado);
                }
                else {
                    array_push($elementos, $dado);
                }
            }

            /* Recebe os Elementos Raiz e tipos de medida que devem permanecer no contrato. */
            $elementosRaiz = $this->recebeElementosETpMedidaPermaneceContr($dadosMarcados, 'E');
            $stringElementos = $this->criaStringElementosETpMedida($elementosRaiz);
            
            $tiposMedida = $this->recebeElementosETpMedidaPermaneceContr($dadosMarcados, 'M');
            $stringTpMedida = $this->criaStringElementosETpMedida($tiposMedida);

            $elemeTpMedida = $this->concatenaElementosETpMedidaPermaneceContr($elementosRaiz, $tiposMedida, $dadosMarcados); 
            $stringElemETpMedida = $this->criaStringElementosETpMedida($elemeTpMedida);

            /* Exclui dados que não serão mais utilizados */

            /* Composições */
            foreach($composicoes as $composicao) {

                $params = array(
                    "NRSEQCONTRATO" => $contrato,
                    "NRCOMPSERVICO" => $composicao["NRCOMPSERVICO"],
                    "NRORG"         => $nrorg
                );

                $this->contratoFactory->excluirComposicoesRenegContrato($params);
            }

            /* Elementos */
            foreach($elementos as $elemento) {

                $params = array(
                    "NRSEQCONTRATO"   => $contrato,
                    "NRCOMPSERVICO"   => $elemento["NRCOMPSERVICO"],
                    "IDELEMENTO"      => $elemento["IDELEMENTO"],
                    "IDELEMENTOPAI"   => $elemento["IDELEMENTOPAI"],
                    "NRORG"           => $nrorg
                );

                $this->contratoFactory->excluirElementosRenegContrato($params);
            }

            $params = array(
                "NRSEQCONTRATO" => $contrato,
                "NRORG"         => $nrorg
            );

            $negociacoes = $this->contratoFactory->getNegociacaoRenegContrato($params);

            if(count($dadosExcluidos) > 0) {
                $params = array(
                    "NRSEQCONTRATO" => $contrato,
                    "NRORG"         => $nrorg
                );

                /* Tipos de Medida */
                $this->contratoFactory->excluirTipoMedidaRenegContrato($params,  $stringElemETpMedida);

                /* Itens e Negociações */
                $itensExclusao = $this->contratoFactory->getItensRenegContrato($params, $stringElemETpMedida);
                foreach ($itensExclusao as $itensE){
                    /* -> Exclui Itens da Negociação */
                    foreach ($negociacoes as $negocia){

                        $params = array(
                            "NRNEGOCIACAOCONTRATO" => $negocia["NRNEGOCIACAOCONTRATO"],
                            "NRITEMOCONTRATO"      => $itensE["NRITEMOCONTRATO"],
                            "NRORG"                => $nrorg
                        );

                        $this->contratoFactory->excluirItensNegoRenegContrato($params); 
                    }

                    /* -> Exclui Itens */
                    $params = array(
                        "NRITEMOCONTRATO" => $itensE["NRITEMOCONTRATO"],
                        "NRORG"           => $nrorg
                    );

                    $this->contratoFactory->excluirItensRenegContrato($params); 
                }
            }
             /* Atualiza Medidas e valores Dados Marcados, sendo:
                Se mantem valores, somente a medida, se não , medida e valores */

            $retorno = $this->AtualizaMedidasEValoresReneg($contrato, $nrorg, $cdoperador, $elementosRaiz, $negociacoes, $escopo, $modelo, $moeda, $dadosMarcados, $idMantemDescAcres);
          
            $this->connection->commit();
            return $retorno;
        }
        catch(\Exception $e) {
            $this->connection->rollback();
            return $e->getMessage();
        }
    }
    
    public function recebeElementosExclusaoContr($dados, $dadosMarcados) {
        $dadosExcluidos = $dados;
        foreach($dadosMarcados as $dadoM){
            foreach($dadosExcluidos as $chave => $dadoE){

                if($dadoM["IDARVORE"] == $dadoE["IDARVORE"]) {
                    unset($dadosExcluidos[$chave]);
                }
            }
        }

        return $dadosExcluidos;
    }

    public function corrigeMedidasContrato($dadosMarcados, $contrato, $nrorg){
        $dadosMarcadosAux = array();
        $elementos = array();

        foreach($dadosMarcados as $dado){
            if($dado["TIPO"] == 'E') {
                $params =  array(
                    "IDELEMENTO" => $dado["IDELEMENTO"]
                );
                
                $eleraizAux = $this->contratoFactory->getElementoRaiz($params);

                if (count($eleraizAux) > 0) {
                    $eleRaiz = $eleraizAux[0]['IDELEMENTO'];
                }

                $params =  array(
                    "NRSEQCONTRATO" => $contrato,
                    "IDELEMENTORAIZ" => $eleRaiz,
                    "NRORG" => $nrorg
                );

                $dadosMedida = $this->contratoFactory->getMedVariavelRelacMedidaContrato($params);
                if (count($dadosMedida) == 1){
                    if($dadosMedida[0]['CDTPMEDIDAVARIAVEL'] !=  $dado["CDTPMEDIDAVARIAVEL"]){

                        $params =  array(
                            "MEDIDACERTA" => $dadosMedida[0]['CDTPMEDIDAVARIAVEL'], 
                            "NRSEQCONTRATO" => $contrato,
                            "IDARVORE" => $dado["IDARVORE"],
                            "NRORG" => $nrorg
                        );

                        $this->contratoFactory->updateConsertaMedVariavelTrabServContrato($params);
                        $dado["CDTPMEDIDAVARIAVEL"] = $dadosMedida[0]['CDTPMEDIDAVARIAVEL'];
                    }
                } 
            }
            
            $dadosMarcadosAux[] = $dado; 
        }
        return $dadosMarcadosAux;
    }

    public function recebeElementosETpMedidaPermaneceContr($dadosMarcados, $tipo) {
        
        $dados = array();
        /* $tipo - E para Elemento e M para Medida, que é passado fixo na chamada da função. 
           Não tem nada a ver com o $dadoM["TIPO"] */
        if ($tipo == 'E'){
            foreach($dadosMarcados as $dadoM) {
                if(($dadoM["TIPO"] == 'E') && (($dadoM["IDTIPOELEMENTO"] == 'P') || ($dadoM["IDTIPOELEMENTO"] == 'G') )){
                    $dados[] =  $dadoM["IDELEMENTO"];
                }
            }
        } 
        else {
            $medidaAnte = null;
            foreach($dadosMarcados as $dadoM) {
                if(($dadoM["TIPO"] == 'E') && ($dadoM["CDTPMEDIDAVARIAVEL"] != null)){
                    if ($medidaAnte != $dadoM["CDTPMEDIDAVARIAVEL"]) {
                        $dados[] =  $dadoM["CDTPMEDIDAVARIAVEL"];
                    }

                    $medidaAnte = $dadoM["CDTPMEDIDAVARIAVEL"];
                }
            } 
        }

        return $dados;
    }

    public function concatenaElementosETpMedidaPermaneceContr($elementosRaiz, $tiposMedida, $dadosMarcados) {
        $dados = array();
        $eleRaiz = null;
        $dadosAnte = null;
        foreach ($dadosMarcados as $dadosM){

            $params =  array(
                "IDELEMENTO" => $dadosM["IDELEMENTO"]
            );
            
            $eleraizAux = $this->contratoFactory->getElementoRaiz($params);

            if (count($eleraizAux) > 0) {
                $eleRaiz = $eleraizAux[0]['IDELEMENTO'];
            }

            foreach($elementosRaiz as $elemento) {
                foreach($tiposMedida as $medidas) {
                    if (($eleRaiz == $elemento) && ($dadosM["CDTPMEDIDAVARIAVEL"] ==  $medidas)) {
                        if ($dadosAnte != $elemento.'-'.$medidas) {
                            $dados[] = $elemento.'-'.$medidas;
                        }
                        $dadosAnte = $elemento.'-'.$medidas;
                    }
                }
            }
        }
        return $dados;
    }

    public function criaStringElementosETpMedida($dados) {
        $stringCorreta = '';
        foreach($dados as $dado) {
            $stringCorreta = $stringCorreta."'".$dado."', ";
        }
        $stringCorreta = substr($stringCorreta, 0, (strlen($stringCorreta) - 2));

        return $stringCorreta;
    }

    public function AtualizaMedidasEValoresReneg($contrato, $nrorg, $cdoperador, $elementosRaiz, $negociacoes, $escopo, $modelo, $moeda, $dadosMarcados, $idMantemDescAcres){

        $this->atualizaMedidasItensContratoReneg($contrato, $escopo, $modelo, $moeda, $nrorg, $cdoperador);

        if ($idMantemDescAcres == 'N') {

            $elementosAlteraAux = array();
            $elementosAltera = array();

            foreach($dadosMarcados as $dado){
                if($dado["TIPO"] == 'E') {
                    array_push($elementosAlteraAux, $dado);
                }  
            }

            foreach($elementosAlteraAux as $elemento){
                if ($elemento["IDAPARECEPROPOSTA"] == 'S') {
                 array_push($elementosAltera, $elemento);
                }
             }

            $this->atualizaValoresItensContratoReneg($contrato, $nrorg, $elementosRaiz, $elementosAltera, $escopo, $moeda, $cdoperador);
        }

        $retorno = $this->atualizaItensPaiENegociacao($contrato, $nrorg, $negociacoes);

        return $retorno;
               
    }

    public function atualizaItensPaiENegociacao($contrato, $nrorg, $negociacoes) {
        
        $retorno = 'OK'; 
        
        /* Atualiza item pai e valores negociação*/

         $params = array(
            "NRSEQCONTRATO" => $contrato,
            "NRORG"         => $nrorg
        );

        $itensPai = $this->contratoFactory->getItensPaiRenegContrato($params);

        foreach($itensPai as $itemP){
            $params = array(
                "NRSEQCONTRATO"     => $contrato,
                "NRITEMCONTRATOPAI" => $itemP["NRITEMOCONTRATO"],
                "NRORG"             => $nrorg
            );

            $vrTotal = $this->contratoFactory->getVrItensPaiRenegContrato($params);

            $params = array(
                "VRTOTAL"           => $vrTotal,
                "NRSEQCONTRATO"     => $contrato,
                "NRITEMOCONTRATO"   => $itemP["NRITEMOCONTRATO"],
                "NRORG"             => $nrorg
            );

            $this->contratoFactory->updateItemPaiRenegContrato($params);
        }

        foreach ($negociacoes as $negocia){

            $params = array(
                "NRNEGOCIACAOCONTRATO" => $negocia["NRNEGOCIACAOCONTRATO"],
                "NRORG"                => $nrorg
            );

            $itensPaiNeg = $this->contratoFactory->getItensNegoPaiRenegContrato($params); 

            $vrTotItComDescSum = 0;
            
            foreach ($itensPaiNeg as $itPaiN){
                $params = array(
                    "NRNEGOCIACAOCONTRATO" => $negocia["NRNEGOCIACAOCONTRATO"],
                    "NRITEMCONTRATOPAI"    => $itPaiN["NRITEMOCONTRATO"],
                    "NRORG"                => $nrorg
                );

                $itPaiNeg = $this->contratoFactory->getVrItensNegoPaiRenegContrato($params);

                $params = array(
                    "VRTOTITEM"            => $itPaiNeg["VRTOTITEM"],
                    "VRTOTITEMCOMDESC"     => $itPaiNeg["VRTOTITEMCOMDESC"],
                    "NRNEGOCIACAOCONTRATO" => $negocia["NRNEGOCIACAOCONTRATO"],
                    "NRITEMOCONTRATO"       => $itPaiN["NRITEMOCONTRATO"],
                    "NRORG"                => $nrorg
                );

                $this->contratoFactory->updateVrItensNegoPaiRenegContrato($params);

                $vrTotItComDescSum = $vrTotItComDescSum+$itPaiNeg["VRTOTITEMCOMDESC"];
            }

            $params = array(
                "VRTOTAL"              => $vrTotItComDescSum,
                "NRNEGOCIACAOCONTRATO" => $negocia["NRNEGOCIACAOCONTRATO"],
                "NRORG"                => $nrorg
            );

            $this->contratoFactory->updateVrNegociacaoRenegContrato($params);

            if ($negocia["IDTPFATURA"] != 'P') {

                /* Verificar Desconto por periodo */

                $params = array(
                    "NRNEGOCIACAOCONTRATO" => $negocia["NRNEGOCIACAOCONTRATO"],
                    "NRORG"                => $nrorg
                );

                $descPeriodo = $this->contratoFactory->getDadosDescontoPeriodoRenegContrato($params);

                foreach ($descPeriodo as $descP) {

                    $paramsUpd = array(
                        "VRTOTAL"               => $vrTotItComDescSum,
                        "NRDESCPERIODONEGOCONT" => $descP["NRDESCPERIODONEGOCONT"],
                        "NRNEGOCIACAOCONTRATO"  => $negocia["NRNEGOCIACAOCONTRATO"],
                        "NRORG"                 => $nrorg
                    );  

                    $this->contratoFactory->updateDescontoPeriodoRenegContrato($paramsUpd);
                }
            }
            else {
                /* Verificar parcelamento */

                $params = array(
                    "NRNEGOCIACAOCONTRATO" => $negocia["NRNEGOCIACAOCONTRATO"],
                    "NRORG"                => $nrorg
                );

                $parcelas = $this->contratoFactory->getDadosParcelamentoRenegContrato($params);

                foreach ($parcelas as $parc) {
                    if ($parc["QTPARCELAS"] != null) {
                        $this->parcelarNegociacaoPorIgual($negocia["NRNEGOCIACAOCONTRATO"], null, $parc["QTPARCELAS"], $parc["QTDIASFAT"], $parc["DIAVENC"], null, $vrTotItComDescSum);
                        $retorno = 'OK_PARC';
                    }
                }  
            }
        }
        return $retorno;
    }

    public function atualizaMedidasItensContratoReneg($contrato, $escopo, $modelo, $moeda, $nrorg, $cdoperador){

        $params =  array(
            "NRSEQCONTRATO" => $contrato,
            "NRORG"         => $nrorg
        );

        $dadosAlteracoes = $this->contratoFactory->getAlteracoesMedidaElementosContr($params);

        foreach ($dadosAlteracoes as $dados){
            $params =  array(
                "IDELEMENTO" => $dados["ELEMENTOTRAB"]
            );
            
            $eleraizAux =  $this->contratoFactory->getElementoRaiz($params);

            if (count($eleraizAux) > 0) {
                $elementoRaiz = $eleraizAux[0]['IDELEMENTO'];
                $NmelementoRaiz = $eleraizAux[0]['NMSERVORCA'];
            }

            $params =  array(
                "NRSEQCONTRATO" => $contrato,
                "CDTPMEDIDAANTIGA" => $dados['MEDIDATRAB'],
                "IDELEMENTO"    =>  $elementoRaiz,
                "NRORG"         => $nrorg
            );

            $valida = $this->contratoFactory->validaAlteracoesMedidaElementosContr($params);

            if ($valida > 0) {
                $this->inserirMedidasEItensEItNegociacao($contrato, $escopo, $modelo, $moeda, $nrorg, $cdoperador, $elementoRaiz, $NmelementoRaiz, $dados['MEDIDASERV']);
            }
            else {
               
                $paramsUpd =  array(
                    "CDTPMEDIDAVARIAVEL" => $dados['MEDIDASERV'],
                    "NRSEQCONTRATO" => $contrato,
                    "IDELEMENTO"    => $elementoRaiz,
                    "MEDIDAANTIGA"  => $dados['MEDIDATRAB'],
                    "NRORG"         => $nrorg
                );
                
                $this->contratoFactory->updateMedidasElementoContrato($paramsUpd);
                $this->contratoFactory->updateMedidaItemContrato($paramsUpd);
                if ($dados['CDSERVORCA'] != null){
                    $this->verificaVariacaoPreco($contrato, $escopo, $moeda, $nrorg, $cdoperador, $dados, 'N');
                }
            }
        }

        foreach ($dadosAlteracoes as $dados){
            $paramsUpd =  array(
                "CDTPMEDIDAVARIAVEL" => $dados['MEDIDASERV'],
                "NRSEQCONTRATO" => $contrato,
                "IDELEMENTO"    => $dados["ELEMENTOTRAB"],
                "MEDIDAANTIGA"  => $dados['MEDIDATRAB'],
                "NRORG"         => $nrorg
            );
            
            $this->contratoFactory->updateElementoContrato($paramsUpd);
        }

        /* Excluir Variações de Preço não utilizadas */
        $params = array(
            "NRSEQCONTRATO" => $contrato,
            "NRORG"         => $nrorg
        );

        $this->contratoFactory->excluirVariacaoPrecoRenegContrato($params);
    }

    public function inserirMedidasEItensEItNegociacao($contrato, $escopo, $modelo, $moeda, $nrorg, $cdoperador, $elementoRaiz, $NmelementoRaiz, $medidaNova){

        $params =  array(
            "NRTIPOORCAMENTO" => $escopo,
            "MEDIDANOVA"      => $medidaNova,
            "NRORG"           => $nrorg
        );

        $dadosMed = $this->contratoFactory->getServicosMedidasElementosRenegCont($params, $elementoRaiz);

        if (count($dadosMed) > 0){

            foreach ($dadosMed as $dadomed){
                $qtmedidavariavel = 1;
                $vrPreco = 0;
                $franquia = 0;

                $params =  array(
                    "CDTPMEDIDASERV"     => $dadomed["CDTPMEDIDASERV"],
                    "CDTPMEDIDAVARIAVEL" => $dadomed["CDTPMEDIDAVARIAVEL"],
                    "NRTIPOORCAMENTO"    => $escopo,
                    "NRMOEDA"            => $moeda,
                    "CDSERVORCA"         => $dadomed["CDSERVORCARELAC"],
                    "NRORG"              => $nrorg
                );
            
                $precoFranq = $this->contratoFactory->getPrecoEFranquiaElemento($params);

                if (count($precoFranq) == 0){
                    throw new \Exception("Operação bloqueda!<br><br> Não foi encontrado preço definido para o serviço '".$dadomed["NMSERVORCARELAC"]."' na tabela de preços vinculada ao contrato.");   
                }
                else {
                    $vrPreco = $precoFranq[0]["PRECO"];
                    $franquia = $precoFranq[0]["QTFRANQUIA"];
                }

                /* Verifica se a medida ja existe no relacionamento dos elementos do contrato, se não existir, insere. */
                $this->insereMedidaContrato($contrato, $escopo, $elementoRaiz, $dadomed, $qtmedidavariavel, $franquia, $nrorg, $cdoperador);
                
                /*  Chama a função para inserir os itens*/
                $this->preparaInsItensElementosContrRenegCont($dadomed, $contrato, $escopo, $modelo, $moeda, $vrPreco, $elementoRaiz, $NmelementoRaiz, $qtmedidavariavel, $nrorg, $cdoperador);
            }
        }

    }

    public function preparaInsItensElementosContrRenegCont ($dadomed, $contrato, $escopo, $modelo, $moeda, $vrPreco, $elementoRaiz, $NmelementoRaiz, $qtmedidavariavel, $nrorg, $cdoperador) {

        $params =  array(
            "NRSEQCONTRATO"         => $contrato,
            "CDSERVORCA"            => $dadomed["CDSERVORCARELAC"],
            "CDTPMEDIDASERV"        => $dadomed["CDTPMEDIDASERV"],
            "CDTPMEDIDAVARIAVEL"    => $dadomed["CDTPMEDIDAVARIAVEL"],
            "NRORG" => $nrorg
        );

        $validaPrecBcont =  $this->contratoFactory->validaVarPrecBseServCont($params);
        
        if ($validaPrecBcont == 0) {
            
            $varPrecOrcamento = $this->contratoFactory->getVarPrecOrcamento($params);

            if (count($varPrecOrcamento) > 0){

                foreach ($varPrecOrcamento as $variacao){

                    $nrvarprecbaseservcont = $this->newCode->getCodeByTableName("FCT_VARPRECBASESERVCONT", $nrorg, 1, 10, true);

                    $params =  array(
                        "NRVARPRECBASESERVCONT" => $nrvarprecbaseservcont,
                        "NRSEQCONTRATO"         => $contrato,
                        "CDSERVORCA"            => $variacao["CDSERVORCA"],
                        "CDTPMEDIDASERV"        => $variacao["CDTPMEDIDASERV"],
                        "CDTPMEDIDAVARIAVEL"    => $variacao["CDTPMEDIDAVARIAVEL"],
                        "QTMEDIDAINIVARIACAO"   => $variacao["QTMEDIDAINIVARIACAO"],
                        "QTMEDIDAFIMVARIACAO"   => $variacao["QTMEDIDAFIMVARIACAO"],
                        "QTFRANQUIA"            => $variacao["QTFRANQUIA"],
                        "VRPRECOVARIACAO"       => $variacao["VRPRECOVARIACAO"],
                        "IDMULTIPVARIACAO"      => $variacao["IDMULTIPVARIACAO"],
                        "NRORG"                 => $nrorg, 
                        "OPERADOR"              => $cdoperador
                    );

                    $this->contratoFactory->insVariacaoPrecoContrato($params);

                } 
            }
            else {
                $params =  array(
                    "NRTIPOORCAMENTO" => $escopo,
                    "NRMOEDA" => $moeda,
                    "CDSERVORCA" => $dadomed["CDSERVORCARELAC"],
                    "CDTPMEDIDASERV" => $dadomed["CDTPMEDIDASERV"],
                    "CDTPMEDIDAVARIAVEL" => $dadomed["CDTPMEDIDAVARIAVEL"],
                    "NRORG" => $nrorg
                );

                $variacoesPrec = $this->contratoFactory->getDadosVariacaoPreco($params);

                foreach ($variacoesPrec as $variacao){

                    $nrvarprecbaseservcont = $this->newCode->getCodeByTableName("FCT_VARPRECBASESERVCONT", $nrorg, 1, 10, true);

                    $params =  array(
                        "NRVARPRECBASESERVCONT" => $nrvarprecbaseservcont,
                        "NRSEQCONTRATO"         => $contrato,
                        "CDSERVORCA"            => $dadomed["CDSERVORCARELAC"],
                        "CDTPMEDIDASERV"        => $dadomed["CDTPMEDIDASERV"],
                        "CDTPMEDIDAVARIAVEL"    => $dadomed["CDTPMEDIDAVARIAVEL"],
                        "QTMEDIDAINIVARIACAO"   => $variacao["QTMEDIDAINIVARIACAO"],
                        "QTMEDIDAFIMVARIACAO"   => $variacao["QTMEDIDAFIMVARIACAO"],
                        "QTFRANQUIA"            => $variacao["QTFRANQUIA"],
                        "VRPRECOVARIACAO"       => $variacao["VRPRECOVARIACAO"],
                        "IDMULTIPVARIACAO"      => $variacao["IDMULTIPVARIACAO"],
                        "NRORG"                 => $nrorg, 
                        "OPERADOR"              => $cdoperador
                    );

                    $this->contratoFactory->insVariacaoPrecoContrato($params);
                } 
            }

            $params =  array(
                "NRTIPOORCAMENTO" => $escopo,
                "NRMOEDA" => $moeda,
                "CDSERVORCA" => $dadomed["CDSERVORCARELAC"],
                "CDTPMEDIDASERV" => $dadomed["CDTPMEDIDASERV"],
                "CDTPMEDIDAVARIAVEL" => $dadomed["CDTPMEDIDAVARIAVEL"],
                "NRORG" => $nrorg
            );

            $variacoesPrec = $this->contratoFactory->getDadosVariacaoPreco($params);

            foreach ($variacoesPrec as $variacao){

                $nrvarprecbaseservcont = $this->newCode->getCodeByTableName("FCT_VARPRECBASESERVCONT", $nrorg, 1, 10, true);

                $params =  array(
                    "NRVARPRECBASESERVCONT" => $nrvarprecbaseservcont,
                    "NRSEQCONTRATO"         => $contrato,
                    "CDSERVORCA"            => $dadomed["CDSERVORCARELAC"],
                    "CDTPMEDIDASERV"        => $dadomed["CDTPMEDIDASERV"],
                    "CDTPMEDIDAVARIAVEL"    => $dadomed["CDTPMEDIDAVARIAVEL"],
                    "QTMEDIDAINIVARIACAO"   => $variacao["QTMEDIDAINIVARIACAO"],
                    "QTMEDIDAFIMVARIACAO"   => $variacao["QTMEDIDAFIMVARIACAO"],
                    "QTFRANQUIA"            => $variacao["QTFRANQUIA"],
                    "VRPRECOVARIACAO"       => $variacao["VRPRECOVARIACAO"],
                    "IDMULTIPVARIACAO"      => $variacao["IDMULTIPVARIACAO"],
                    "NRORG"                 => $nrorg, 
                    "OPERADOR"              => $cdoperador
                );

                $this->contratoFactory->insVariacaoPrecoContrato($params);

            }
        }

        /* Verifica se existe item pai */
        $params =  array(
            "CDSERVORCA"   => $dadomed["CDSERVORCARELAC"],
            "NRSEQCONTRATO"   => $contrato,
            "NRORG" => $nrorg
        );

        $retItemPai = $this->contratoFactory->verificaItemPaiInserido($params);
        
        if ( count($retItemPai) > 0){ /* Neste caso, o item pai já está inserido, então insere o elemento como item filho e atualiza o valor do item pai*/
            $itemPai = $retItemPai[0]['NRITEMOCONTRATO'];
            
            /* Valida se o item já está inserido */
            $params =  array(
                "NRSEQCONTRATO"      => $contrato,
                "CDSERVORCA"         => $dadomed["CDSERVORCARELAC"],
                "IDELEMENTO"         => $elementoRaiz,
                "CDTPMEDIDAVARIAVEL" => $dadomed["CDTPMEDIDAVARIAVEL"],
                "NRORG"              => $nrorg
            );

            $validaItem = $this->contratoFactory->validaExisteItemContratoElemento($params);

            if ($validaItem == 0){
                /*Insere Elemento vinculado ao item pai */
                $item = array(
                    "NRITEMCONTRATOPAI"      => $itemPai,
                    "NRSEQCONTRATO"          => $contrato,
                    "CDSERVORCA"             => $dadomed["CDSERVORCARELAC"],
                    "NMITEMCONTRATO"         => $NmelementoRaiz,
                    "IDELEMENTO"             => $elementoRaiz,
                    "CDTPMEDIDASERV"         => $dadomed["CDTPMEDIDASERV"],
                    "VRUNITITEMCONT"         => $vrPreco,
                    "VRUNITITEMCONTTBLPRECO" => $vrPreco,
                    "VRTOTITEMCONT"          => $qtmedidavariavel*$vrPreco,
                    "CDTPMEDIDAVARIAVEL"     => $dadomed["CDTPMEDIDAVARIAVEL"],
                    "IDAPARECEPROPOSTA"      => "S",
                    "NRMOEDA"                => $moeda,
                    "QTMEDIDA"               => $qtmedidavariavel
                );

                $itemIns = $this->insereItensElementosContr($item, $nrorg, $cdoperador);

                $this->inserirItemNegociacaoContratoRenegCont($contrato, $modelo, $escopo, $nrorg, $cdoperador, $itemIns, $itemPai, $vrPreco, $dadomed["CDSERVORCARELAC"]);
            
                /*Atualiza valor Item Pai*/ 

                $params =  array(
                    "PRECO"           =>  $vrPreco,
                    "NRITEMOCONTRATO" => $itemPai,
                    "NRORG"           => $nrorg
                );

                $this->contratoFactory->updateValorItemPai($params);

            }
        }
        else{ /* Neste caso, o item pai não está inserido, então insere o item pai e o elemento como item filho ambos com o valor da tabela de preços*/

            /*Insere Item pai */
            $item = array(
                "NRITEMCONTRATOPAI"      => null,
                "NRSEQCONTRATO"          => $contrato,
                "CDSERVORCA"             => $dadomed["CDSERVORCARELAC"],
                "NMITEMCONTRATO"         => $dadomed["NMSERVORCARELAC"],
                "IDELEMENTO"             => null,
                "CDTPMEDIDASERV"         => $dadomed["CDTPMEDIDASERV"],
                "VRUNITITEMCONT"         => $vrPreco,
                "VRUNITITEMCONTTBLPRECO" => $vrPreco,
                "VRTOTITEMCONT"          => $qtmedidavariavel*$vrPreco,
                "CDTPMEDIDAVARIAVEL"     => $dadomed["CDTPMEDIDAVARIAVEL"],
                "IDAPARECEPROPOSTA"      => "S",
                "NRMOEDA"                => $moeda,
                "QTMEDIDA"               => $qtmedidavariavel
            );

            $itemPai = $this->insereItensElementosContr($item, $nrorg, $cdoperador);

            /*Insere Elemento vinculado ao item pai */
            $item = array(
                "NRITEMCONTRATOPAI"      => $itemPai,
                "NRSEQCONTRATO"          => $contrato,
                "CDSERVORCA"             => $dadomed["CDSERVORCARELAC"],
                "NMITEMCONTRATO"         => $NmelementoRaiz,
                "IDELEMENTO"             => $elementoRaiz,
                "CDTPMEDIDASERV"         => $dadomed["CDTPMEDIDASERV"],
                "VRUNITITEMCONT"         => $vrPreco,
                "VRUNITITEMCONTTBLPRECO" => $vrPreco,
                "VRTOTITEMCONT"          => $qtmedidavariavel*$vrPreco,
                "CDTPMEDIDAVARIAVEL"     => $dadomed["CDTPMEDIDAVARIAVEL"],
                "IDAPARECEPROPOSTA"      => "S",
                "NRMOEDA"                => $moeda,
                "QTMEDIDA"               => $qtmedidavariavel
            );

            $itemIns = $this->insereItensElementosContr($item, $nrorg, $cdoperador);

            $this->inserirItemNegociacaoContratoRenegCont($contrato, $modelo, $escopo, $nrorg, $cdoperador, $itemIns, $itemPai, $vrPreco, $dadomed["CDSERVORCARELAC"]);
        }

    }

    public function inserirItemNegociacaoContratoRenegCont($contrato, $modelo, $escopo, $nrorg, $cdoperador, $itemIns, $itemPai, $vrPreco, $servico){

        $params = array(
            "NRSEQMODCONTRA" => $modelo,
            "NRSEQCONTRATO"  => $contrato,
            "NRORG"          => $nrorg
        );
        $dadosNegociacao = $this->contratoFactory->getParametrosFaturamentoItensNegociacaoContrato($params, $escopo, $servico);

        $params = array(
            "NRITEMCONTRATOPAI" => $itemPai,
            "NRORG"             => $nrorg
        );
        $nrnegociacaocontrato = $this->contratoFactory->recebeNegociacaoItemPaiRenegCont($params);

        $nritnegociacaocontrato = $this->newCode->getCodeByTableName("FCT_ITNEGOCIACAOCONTRATO", $nrorg, 1, 10, true);
        $params = array(
            "NRITNEGOCIACAOCONTRATO" => $nritnegociacaocontrato,
            "NRNEGOCIACAOCONTRATO"   => $nrnegociacaocontrato,
            "NRITEMOCONTRATO"        => $itemIns,
            "NRITEMCONTRATOPAI"      => $itemPai,
            "VRTOTITEM"              => $vrPreco,
            "CDSERVORCA"             => $servico,
            "CDPRODFATURA"           => $dadosNegociacao[0]["CDPRODFATURA"],
            "NRPARCFATURA"           => $dadosNegociacao[0]["NRPARCFATURA"],
            "VRTOTITEMCOMDESC"       => $vrPreco,
            "NRITEMORCAMENTO"        => null,
            "IDATIVO"                => "S",
            "NRITEMORCAMENTOPAI"     => null,
            "VRPERCDESCITEM"         => null,
            "VRDESCITEM"             => null,
            "NRORG"                  => $nrorg,
            "NRORGINCLUSAO"          => $nrorg,
            "CDOPERINCLUSAO"         => $cdoperador,
            "NRITNEGOCIACAOPROPOSTA" => null
        );

        $this->contratoFactory->inserirItemNegociacaoContrato($params);
    }

    public function atualizaValoresItensContratoReneg($contrato, $nrorg, $elementosRaiz, $elementosAltera, $escopo, $moeda, $cdoperador){

        foreach ($elementosRaiz as $elemento){
           
            $params =  array(
                "NRTIPOORCAMENTO" => $escopo,
                "NRORG"           => $nrorg
            );

            $dadosMedAux = $this->contratoFactory->getServicosMedidasElementos($params, $elemento);

            if (count($dadosMedAux) > 0){
                
                $dadosMed = $this->validaTipoMedida($dadosMedAux, $elementosAltera);

                foreach ($dadosMed as $dadomed){
                    $vrPreco = 0;
                    $franquia = 0;

                    $params =  array(
                        "CDTPMEDIDASERV"     => $dadomed["CDTPMEDIDASERV"],
                        "CDTPMEDIDAVARIAVEL" => $dadomed["CDTPMEDIDAVARIAVEL"],
                        "NRTIPOORCAMENTO"    => $escopo,
                        "NRMOEDA"            => $moeda,
                        "CDSERVORCA"         => $dadomed["CDSERVORCARELAC"],
                        "NRORG"              => $nrorg
                    );
                
                    $precoFranq = $this->contratoFactory->getPrecoEFranquiaElemento($params);

                    if (count($precoFranq) == 0){
                        throw new \Exception("Operação bloqueda!<br><br> Não foi encontrado preço definido para o serviço '".$dadomed["NMSERVORCARELAC"]."' na tabela de preços vinculada ao contrato.");   
                    }
                    else {
                        $vrPreco = $precoFranq[0]["PRECO"];
                        $franquia = $precoFranq[0]["QTFRANQUIA"];
                    }

                    $paramsUpd =  array(
                        "VRPRECO"       => $vrPreco,
                        "NRSEQCONTRATO" => $contrato,
                        "CDSERVORCA"    => $dadomed["CDSERVORCARELAC"],
                        "IDELEMENTO"    => $elemento,
                        "CDTPMEDIDAVARIAVEL" => $dadomed['CDTPMEDIDAVARIAVEL'],
                        "NRORG"         => $nrorg
                    );

                    $this->contratoFactory->updateValoresItemContratoRenegCont($paramsUpd);

                    $params =  array(
                        "NRSEQCONTRATO"      => $contrato,
                        "CDTPMEDIDAVARIAVEL" => $dadomed["CDTPMEDIDAVARIAVEL"],  
                        "IDELEMENTO"         => $elemento, 
                        "NRORG"              => $nrorg
                    );
    
                    $dadosItem = $this->contratoFactory->getVrtItemContratoAlteraMedida($params);
    
                    foreach($dadosItem as $dados){

                        $params =  array(
                            "VRTOTAL"         => $dados["VRTOTITEMCONT"],
                            "NRITEMOCONTRATO" => $dados["NRITEMOCONTRATO"],  
                            "NRORG"           => $nrorg
                        );
    
                        $this->contratoFactory->updateQTMedidaItemNegociacaoRenegCont($params);
                    }
                }
            }
        }
    }
    
    public function verificaVariacaoPreco($contrato, $escopo, $moeda, $nrorg, $cdoperador, $dados, $atualizapreco, $preco = null, $franquia = null) {

        $params =  array(
            "NRSEQCONTRATO"      => $contrato,
            "CDTPMEDIDAVARIAVEL" => isset($dados['MEDIDASERV']) ? $dados['MEDIDASERV'] : $dados['CDTPMEDIDAVARIAVEL'],  
            "CDSERVORCA"         => isset($dados['CDSERVORCA']) ? $dados['CDSERVORCA'] : $dados['CDSERVORCARELAC'],
            "NRORG"              => $nrorg
        );

        $valida = $this->contratoFactory->validaExisteVariacaoPrecContr($params);

        if ($valida == 0){

            $params =  array(
                "CDTPMEDIDAVARIAVEL" => isset($dados['MEDIDASERV']) ? $dados['MEDIDASERV'] : $dados['CDTPMEDIDAVARIAVEL'],  
                "CDSERVORCA"         => isset($dados['CDSERVORCA']) ? $dados['CDSERVORCA'] : $dados['CDSERVORCARELAC'],
                "NRTIPOORCAMENTO"    => $escopo,
                "NRMOEDA"            => $moeda,
                "NRORG"              => $nrorg
            );

            $variacoesPrec = $this->contratoFactory->getdadosVariacaoPrecoContr($params);

            foreach($variacoesPrec as $variacao){

                $nrvarprecbaseservcont = $this->newCode->getCodeByTableName("FCT_VARPRECBASESERVCONT", $nrorg, 1, 10, true);

                $params =  array(
                    "NRVARPRECBASESERVCONT" => $nrvarprecbaseservcont,
                    "NRSEQCONTRATO"         => $contrato,
                    "CDSERVORCA"            => isset($dados['CDSERVORCA']) ? $dados['CDSERVORCA'] : $dados['CDSERVORCARELAC'],
                    "CDTPMEDIDASERV"        => $variacao["CDTPMEDIDASERV"],
                    "CDTPMEDIDAVARIAVEL"    => $variacao["CDTPMEDIDAVARIAVEL"],
                    "QTMEDIDAINIVARIACAO"   => $variacao["QTMEDIDAINIVARIACAO"],
                    "QTMEDIDAFIMVARIACAO"   => $variacao["QTMEDIDAFIMVARIACAO"],
                    "QTFRANQUIA"            => $variacao["QTFRANQUIA"],
                    "VRPRECOVARIACAO"       => $variacao["VRPRECOVARIACAO"],
                    "IDMULTIPVARIACAO"      => $variacao["IDMULTIPVARIACAO"],
                    "NRORG"                 => $nrorg, 
                    "OPERADOR"              => $cdoperador
                );

                $this->contratoFactory->insVariacaoPrecoContrato($params);
            }
        }
    }

    public function editarTpMedidaElementoContr($contrato, $dadosTpMedida, $nrorg) {

        $this->connection->beginTransaction();
        try {
            
            foreach ($dadosTpMedida as $dadosMedida){

                $params =  array(
                    "QTMEDIDAVARIAVEL"   => $dadosMedida["QTMEDIDAVARIAVEL"],
                    "CDTPMEDIDAVARIAVEL" => $dadosMedida["CDTPMEDIDAVARIAVEL"],  
                    "NRSEQCONTRATO"      => $contrato,
                    "IDELEMENTORAIZ"     => $dadosMedida["IDELEMENTORAIZ"], 
                    "NRORG"              => $nrorg
                );

                $this->contratoFactory->updateQtMedidasElementoContrato($params);
                $this->contratoFactory->updateQtMedidaItemContrato($params);

                $params =  array(
                    "NRSEQCONTRATO"      => $contrato,
                    "CDTPMEDIDAVARIAVEL" => $dadosMedida["CDTPMEDIDAVARIAVEL"],  
                    "IDELEMENTO"         => $dadosMedida["IDELEMENTORAIZ"], 
                    "NRORG"              => $nrorg
                );

                $dadosItem = $this->contratoFactory->getVrtItemContratoAlteraMedida($params);

                foreach($dadosItem as $dados){
                    $params =  array(
                        "VRTOTAL"         => $dados["VRTOTITEMCONT"],
                        "NRITEMOCONTRATO" => $dados["NRITEMOCONTRATO"],  
                        "NRORG"           => $nrorg
                    );

                    $this->contratoFactory->updateQTMedidaItemNegociacaoRenegCont($params);
                }
            }
            $params = array(
                "NRSEQCONTRATO" => $contrato,
                "NRORG"         => $nrorg
            );

            $negociacoes = $this->contratoFactory->getNegociacaoRenegContrato($params);

            $retorno = $this->atualizaItensPaiENegociacao($contrato, $nrorg, $negociacoes);

            $this->connection->commit();
            return $retorno;
        }
        catch(\Exception $e) {
            $this->connection->rollback();
            return $e->getMessage();
        }
    }

    public function validaTipoMedida($dadosMed, $elementosApareceProp){
        $dadosMedAux = $dadosMed;

        foreach ($elementosApareceProp as $elementos){
            foreach ($dadosMedAux as $chave => $dados) {
                if ($dados['CDTPMEDIDAVARIAVEL'] == $elementos['CDTPMEDIDAVARIAVEL']) {
                    unset($dadosMedAux[$chave]);
                }
            }
        }
        
        foreach ($dadosMed as $ch => $dadosM) {
            foreach ($dadosMedAux as  $dados){
                if ($dadosM['CDTPMEDIDAVARIAVEL'] == $dados['CDTPMEDIDAVARIAVEL']) {
                    unset($dadosMed[$ch]);
                }
            }
        }

        return $dadosMed;
    }

    public function validaAgrupamento($nrParcFatura, $nrTipoOrcamento, $nrorg) {

        $retorno = array();

        try {
            $params =  array(
                "NRPARCFATURA"    => $nrParcFatura,
                "NRTIPOORCAMENTO" => $nrTipoOrcamento,
                "NRORG"           => $nrorg
            );

            $valida = $this->contratoFactory->validaAgrupamento($params);

            if (count($valida) == 1){
                $retorno['QUANT'] = 1;
                $retorno['NRAGRUPAMENTO'] = $valida[0]['NRAGRUPAMENTO'];
            }
            else if (count($valida) == 0){
                $retorno['QUANT'] = 0;
                $retorno['NRAGRUPAMENTO'] = NULL;
            }
            else { 
                $retorno['QUANT'] = count($valida);
                $retorno['NRAGRUPAMENTO'] = NULL;
            }
            
            return $retorno;
        }
        catch(\Exception $e) {
            return $e->getMessage();
        }
    }

    public function vinculaContratoNoAgrupamento($nrSeqContrato, $nrAgrupamento, $nrorg, $cdoperador) {

        try {

            $params =  array(
                "NRSEQCONTRATO"     => $nrSeqContrato,
                "NRAGRUPAMENTO"     => $nrAgrupamento,
                "NRORG"             => $nrorg
            );

            $valida = $this->contratoFactory->validaVinculoContratoNoAgrupamento($params);

            if ($valida == 0) {
                $novoCodigo = $this->newCode->getCodeByTableName("FCT_RELACAGRUPAMENTOCONT", $nrorg, 1, 10, true);

                $params =  array(
                    "NRAGRUPAMENTOCONT" => $novoCodigo,
                    "NRAGRUPAMENTO"     => $nrAgrupamento,
                    "NRSEQCONTRATO"     => $nrSeqContrato,
                    "NRORG"             => $nrorg,
                    "OPERADOR"          => $cdoperador
                );

                $this->contratoFactory->vinculaContratoNoAgrupamento($params);
            }      
        }
        catch(\Exception $e) {
            return $e->getMessage();
        }
    }
   

}
?>
 
 